@@ -21,6 +21,8 @@
 
 #ifdef Q_OS_WIN
 #include <QSettings>
+#include <stdlib.h>
+#include <time.h>
 #endif // ifdef Q_OS_WIN
 #include <QCommandLineParser>
 #include <QDir>
@@ -34,6 +36,8 @@
 #include <QSystemTrayIcon>
 #include <QTimer>
 
+#include <bctoolbox/charconv.h>
+
 #include "config.h"
 #include "cli/Cli.hpp"
 #include "components/Components.hpp"
@@ -42,6 +46,7 @@
 #include "providers/AvatarProvider.hpp"
 #include "providers/ImageProvider.hpp"
 #include "providers/ExternalImageProvider.hpp"
+#include "providers/QRCodeProvider.hpp"
 #include "providers/ThumbnailProvider.hpp"
 #include "translator/DefaultTranslator.hpp"
 #include "utils/Utils.hpp"
@@ -141,11 +146,14 @@ static inline bool autoStartEnabled () {
 // -----------------------------------------------------------------------------
 
 static inline bool installLocale (App &app, QTranslator &translator, const QLocale &locale) {
-	return translator.load(locale, Constants::LanguagePath) && app.installTranslator(&translator);
+	bool ok = translator.load(locale, Constants::LanguagePath) && app.installTranslator(&translator);
+	if(ok)
+		QLocale::setDefault(locale);
+	return ok;
 }
 
 static inline string getConfigPathIfExists (const QCommandLineParser &parser) {
-	QString filePath = parser.value("config");
+	QString filePath = parser.isSet("config") ? parser.value("config") : "";
 	string configPath;
 	if(!QUrl(filePath).isRelative()){
 		configPath = Utils::appStringToCoreString(FileDownloader::synchronousDownload(filePath, Utils::coreStringToAppString(Paths::getConfigDirPath(false)), true));
@@ -197,12 +205,33 @@ App::App (int &argc, char *argv[]) : SingleApplication(argc, argv, true, Mode::U
 	
 	setWindowIcon(QIcon(Constants::WindowIconPath));
 	
+	char * tz = getenv("TZ");
+	if(!tz){// If not set, set the environement variable for uses of mktime from the SDK.
+#ifdef Q_OS_WIN
+		_putenv(("TZ="+QTimeZone::systemTimeZoneId().toStdString()).c_str());
+		_tzset();
+#else
+		setenv("TZ", QTimeZone::systemTimeZoneId().toStdString().c_str(), 1);
+		tzset();
+#endif
+	}
+	bctbx_set_default_encoding(Constants::LinphoneLocaleEncoding);// Use UTF-8 for internals. Linphone uses UTF-8 so there will be no loss on data with less precise encodings. Qt will do the rest.
+	
+	
 	createParser();
+	mParser->parse(this->arguments());
+// Get configuration for translators
+	shared_ptr<linphone::Config> config = Utils::getConfigIfExists (QString::fromStdString(getConfigPathIfExists(*mParser)));
+	
+	// Init locale.
+	mTranslator = new DefaultTranslator(this);
+	mDefaultTranslator = new DefaultTranslator(this);
+	initLocale(config);
+	Logger::init(config);
+	
+	createParser();// Recreate parser in order to use translations from config.
 	mParser->process(*this);
 	
-	// Initialize logger.
-	shared_ptr<linphone::Config> config = Utils::getConfigIfExists (QString::fromStdString(getConfigPathIfExists(*mParser)));
-	Logger::init(config);
 	if (mParser->isSet("verbose"))
 		Logger::getInstance()->setVerbose(true);
 	
@@ -210,11 +239,6 @@ App::App (int &argc, char *argv[]) : SingleApplication(argc, argv, true, Mode::U
 	for (const auto &locale : QDir(Constants::LanguagePath).entryList())
 		mAvailableLocales << QLocale(locale);
 	
-	// Init locale.
-	mTranslator = new DefaultTranslator(this);
-	mDefaultTranslator = new DefaultTranslator(this);
-	initLocale(config);
-	
 	if (mParser->isSet("help")) {
 		mParser->showHelp();
 	}
@@ -235,12 +259,19 @@ App::App (int &argc, char *argv[]) : SingleApplication(argc, argv, true, Mode::U
 
 App::~App () {
 	qInfo() << QStringLiteral("Destroying app...");
-	if( mEngine )
-		mEngine->deleteLater();// Let to Qt the time to delete its data
+}
+
+void App::stop(){
+	qInfo() << QStringLiteral("Stopping app...");
+	if( mEngine ){
+		delete mEngine;
+		processEvents(QEventLoop::AllEvents);
+	}
+	CoreManager::uninit();
+	processEvents(QEventLoop::AllEvents);	// Process all needed events on engine deletion.
 	if( mParser)
 		delete mParser;
 }
-
 // -----------------------------------------------------------------------------
 
 QStringList App::cleanParserKeys(QCommandLineParser * parser, QStringList keys){
@@ -343,13 +374,16 @@ void App::initContentApp () {
 	// Change colors if necessary.
 	mColorListModel->useConfig(config);
 	mImageListModel->useConfig(config);
+// There is no more database for callback. Setting it in the configuration before starting the core will do migration.
+// When the migration is done by SDK, further migrations on call logs will do nothing. It is safe to use .
+	config->setString("storage", "call_logs_db_uri", Paths::getCallHistoryFilePath());
 	
 	// Init core.
 	CoreManager::init(this, Utils::coreStringToAppString(configPath));
 	
 	
 	// Init engine content.
-	mEngine = new QQmlApplicationEngine();
+	mEngine = new QQmlApplicationEngine(this);
 	
 	// Provide `+custom` folders for custom components and `5.9` for old components.
 	{
@@ -370,6 +404,7 @@ void App::initContentApp () {
 	mEngine->addImageProvider(AvatarProvider::ProviderId, new AvatarProvider());
 	mEngine->addImageProvider(ImageProvider::ProviderId, new ImageProvider());
 	mEngine->addImageProvider(ExternalImageProvider::ProviderId, new ExternalImageProvider());
+	mEngine->addImageProvider(QRCodeProvider::ProviderId, new QRCodeProvider());
 	mEngine->addImageProvider(ThumbnailProvider::ProviderId, new ThumbnailProvider());
 	
 	mEngine->rootContext()->setContextProperty("applicationName", APPLICATION_NAME);
@@ -394,6 +429,8 @@ void App::initContentApp () {
 	mEngine->rootContext()->setContextProperty("Colors", mColorListModel->getQmlData());
 	mEngine->rootContext()->setContextProperty("Images", mImageListModel->getQmlData());
 	
+	mEngine->rootContext()->setContextProperty("qtIsNewer_5_15_0", QT_VERSION >= QT_VERSION_CHECK(5, 15, 0) );
+	
 	registerTypes();
 	registerSharedTypes();
 	registerToolTypes();
@@ -401,7 +438,6 @@ void App::initContentApp () {
 	
 	// Enable notifications.
 	mNotifier = new Notifier(mEngine);
-	
 	// Load main view.
 	qInfo() << QStringLiteral("Loading main view...");
 	mEngine->load(QUrl(Constants::QmlViewMainWindow));
@@ -447,6 +483,10 @@ bool App::event (QEvent *event) {
 		}
 		
 		Cli::executeCommand(url);
+	}else if(event->type() == QEvent::ApplicationStateChange){
+		auto state = static_cast<QApplicationStateChangeEvent*>(event);
+		if( state->applicationState() == Qt::ApplicationActive)
+			smartShowWindow(getMainWindow());
 	}
 	
 	return SingleApplication::event(event);
@@ -600,17 +640,18 @@ static inline void registerSharedToolType (const char *name) {
 void App::registerTypes () {
 	qInfo() << QStringLiteral("Registering types...");
 	
-	qRegisterMetaType<shared_ptr<linphone::ProxyConfig>>();
+	qRegisterMetaType<shared_ptr<linphone::Account>>();
 	qRegisterMetaType<ChatRoomModel::EntryType>();
 	qRegisterMetaType<shared_ptr<linphone::SearchResult>>();
 	qRegisterMetaType<std::list<std::shared_ptr<linphone::SearchResult> > >();
-	qRegisterMetaType<std::shared_ptr<ChatMessageModel>>();
-	qRegisterMetaType<std::shared_ptr<ChatRoomModel>>();
-	qRegisterMetaType<std::shared_ptr<ParticipantListModel>>();
-	qRegisterMetaType<std::shared_ptr<ParticipantDeviceModel>>();
-	qRegisterMetaType<std::shared_ptr<ChatMessageModel>>();
-	qRegisterMetaType<std::shared_ptr<ChatNoticeModel>>();
-	qRegisterMetaType<std::shared_ptr<ChatCallModel>>();
+	qRegisterMetaType<QSharedPointer<ChatMessageModel>>();
+	qRegisterMetaType<QSharedPointer<ChatRoomModel>>();
+	qRegisterMetaType<QSharedPointer<ParticipantListModel>>();
+	qRegisterMetaType<QSharedPointer<ParticipantDeviceModel>>();
+	qRegisterMetaType<QSharedPointer<ChatMessageModel>>();
+	qRegisterMetaType<QSharedPointer<ChatNoticeModel>>();
+	qRegisterMetaType<QSharedPointer<ChatCallModel>>();
+	qRegisterMetaType<QSharedPointer<ConferenceInfoModel>>();
 	//qRegisterMetaType<std::shared_ptr<ChatEvent>>();
 	LinphoneEnums::registerMetaTypes();
 	
@@ -618,10 +659,11 @@ void App::registerTypes () {
 	registerType<AuthenticationNotifier>("AuthenticationNotifier");
 	registerType<CallsListProxyModel>("CallsListProxyModel");
 	registerType<Camera>("Camera");
-	registerType<CameraPreview>("CameraPreview");
 	registerType<ChatRoomProxyModel>("ChatRoomProxyModel");
 	registerType<ConferenceHelperModel>("ConferenceHelperModel");
-	registerType<ConferenceModel>("ConferenceModel");
+	registerType<ConferenceProxyModel>("ConferenceProxyModel");
+	registerType<ConferenceInfoModel>("ConferenceInfoModel");
+	registerType<ConferenceInfoProxyModel>("ConferenceInfoProxyModel");
 	registerType<ContactsListProxyModel>("ContactsListProxyModel");
 	registerType<ContactsImporterListProxyModel>("ContactsImporterListProxyModel");
 	registerType<ContentProxyModel>("ContentProxyModel");
@@ -633,13 +675,14 @@ void App::registerTypes () {
 	registerType<SipAddressesProxyModel>("SipAddressesProxyModel");
 	registerType<SearchSipAddressesModel>("SearchSipAddressesModel");
 	registerType<SearchSipAddressesProxyModel>("SearchSipAddressesProxyModel");
-	
+	registerType<TimeZoneProxyModel>("TimeZoneProxyModel");
 	
 	registerType<ColorProxyModel>("ColorProxyModel");
 	registerType<ImageColorsProxyModel>("ImageColorsProxyModel");
 	registerType<ImageProxyModel>("ImageProxyModel");
 	registerType<TimelineProxyModel>("TimelineProxyModel");
 	registerType<ParticipantProxyModel>("ParticipantProxyModel");
+	registerType<ParticipantDeviceProxyModel>("ParticipantDeviceProxyModel");
 	registerType<SoundPlayer>("SoundPlayer");
 	registerType<TelephoneNumbersModel>("TelephoneNumbersModel");
 	
@@ -659,6 +702,7 @@ void App::registerTypes () {
 	registerUncreatableType<ColorModel>("ColorModel");
 	registerUncreatableType<ImageModel>("ImageModel");
 	registerUncreatableType<ConferenceHelperModel::ConferenceAddModel>("ConferenceAddModel");
+	registerUncreatableType<ConferenceModel>("ConferenceModel");
 	registerUncreatableType<ContactModel>("ContactModel");
 	registerUncreatableType<ContactsImporterModel>("ContactsImporterModel");
 	registerUncreatableType<ContentModel>("ContentModel");
@@ -677,7 +721,6 @@ void App::registerTypes () {
 	registerUncreatableType<ParticipantListModel>("ParticipantListModel");
 	registerUncreatableType<ParticipantDeviceModel>("ParticipantDeviceModel");
 	registerUncreatableType<ParticipantDeviceListModel>("ParticipantDeviceListModel");
-	registerUncreatableType<ParticipantDeviceProxyModel>("ParticipantDeviceProxyModel");
 	registerUncreatableType<ParticipantImdnStateModel>("ParticipantImdnStateModel");
 	registerUncreatableType<ParticipantImdnStateListModel>("ParticipantImdnStateListModel");
 	
@@ -810,7 +853,7 @@ void App::initLocale (const shared_ptr<linphone::Config> &config) {
 	}
 	
 	// Try to use system locale.
-	QLocale sysLocale = QLocale::system();
+	QLocale sysLocale = QLocale(QLocale::system().name());// Use Locale from name because Qt has a bug where it didn't use the QLocale::language (aka : translator.language != lolcale.language) on Mac.
 	if (installLocale(*this, *mTranslator, sysLocale)) {
 		mLocale = sysLocale.name();
 		return;
@@ -955,6 +998,7 @@ void App::setAutoStart (bool enabled) {
 void App::openAppAfterInit (bool mustBeIconified) {
 	qInfo() << QStringLiteral("Open " APPLICATION_NAME " app.");
 	auto coreManager = CoreManager::getInstance();
+	coreManager->getSettingsModel()->updateCameraMode();
 	// Create other windows.
 	mCallsWindow = createSubWindow(mEngine, Constants::QmlViewCallsWindow);
 	mSettingsWindow = createSubWindow(mEngine, Constants::QmlViewSettingsWindow);
@@ -977,7 +1021,7 @@ void App::openAppAfterInit (bool mustBeIconified) {
 #endif // ifndef __APPLE__
 	
 	// Display Assistant if it does not exist proxy config.
-	if (coreManager->getCore()->getAccountList().empty())
+	if (coreManager->getAccountList().empty())
 		QMetaObject::invokeMethod(mainWindow, "setView", Q_ARG(QVariant, Constants::AssistantViewName), Q_ARG(QVariant, QString("")), Q_ARG(QVariant, QString("")));
 	
 #ifdef ENABLE_UPDATE_CHECK
@@ -1047,6 +1091,6 @@ void App::checkForUpdate() {
 void App::checkForUpdates(bool force) {
 	if(force || CoreManager::getInstance()->getSettingsModel()->isCheckForUpdateEnabled())
 		CoreManager::getInstance()->getCore()->checkForUpdate(
-					Utils::appStringToCoreString(getStrippedApplicationVersion())
+					Utils::appStringToCoreString(applicationVersion())
 					);
 }
