@@ -24,8 +24,11 @@
 
 #include "app/App.hpp"
 #include "components/call/CallModel.hpp"
+#include "components/chat-room/ChatRoomInitializer.hpp"
 #include "components/conference/ConferenceAddModel.hpp"
 #include "components/conference/ConferenceHelperModel.hpp"
+#include "components/conference/ConferenceModel.hpp"
+#include "components/conferenceInfo/ConferenceInfoModel.hpp"
 #include "components/core/CoreHandlers.hpp"
 #include "components/core/CoreManager.hpp"
 #include "components/participant/ParticipantModel.hpp"
@@ -36,7 +39,7 @@
 
 #include "CallsListModel.hpp"
 
-#include "utils/hacks/ChatRoomInitializer.hpp"
+
 
 // =============================================================================
 
@@ -44,61 +47,37 @@ using namespace std;
 
 namespace {
 // Delay before removing call in ms.
-constexpr int DelayBeforeRemoveCall = 3000;
+constexpr int DelayBeforeRemoveCall = 6000;
 }
 
-static inline int findCallIndex (QList<CallModel *> &list, const shared_ptr<linphone::Call> &call) {
-	auto it = find_if(list.begin(), list.end(), [call](CallModel *callModel) {
-			return call == callModel->getCall();
-});
-	
-	Q_ASSERT(it != list.end());
-	
-	return int(distance(list.begin(), it));
+static inline int findCallIndex (QList<QSharedPointer<QObject>> &list, const shared_ptr<linphone::Call> &call) {
+	auto it = find_if(list.begin(), list.end(), [call](QSharedPointer<QObject> callModel) {
+			return call == callModel.objectCast<CallModel>()->getCall();
+	});
+	return it == list.end() ? -1 : int(distance(list.begin(), it));
 }
 
-static inline int findCallIndex (QList<CallModel *> &list, const CallModel &callModel) {
+static inline int findCallIndex (QList<QSharedPointer<QObject>> &list, const CallModel &callModel) {
 	return ::findCallIndex(list, callModel.getCall());
 }
 
 // -----------------------------------------------------------------------------
 
-CallsListModel::CallsListModel (QObject *parent) : QAbstractListModel(parent) {
+CallsListModel::CallsListModel (QObject *parent) : ProxyListModel(parent) {
 	mCoreHandlers = CoreManager::getInstance()->getHandlers();
 	QObject::connect(
 				mCoreHandlers.get(), &CoreHandlers::callStateChanged,
 				this, &CallsListModel::handleCallStateChanged
 				);
-}
-
-int CallsListModel::rowCount (const QModelIndex &) const {
-	return mList.count();
-}
-
-QHash<int, QByteArray> CallsListModel::roleNames () const {
-	QHash<int, QByteArray> roles;
-	roles[Qt::DisplayRole] = "$call";
-	return roles;
-}
-
-QVariant CallsListModel::data (const QModelIndex &index, int role) const {
-	int row = index.row();
-	
-	if (!index.isValid() || row < 0 || row >= mList.count())
-		return QVariant();
-	
-	if (role == Qt::DisplayRole)
-		return QVariant::fromValue(mList[row]);
-	
-	return QVariant();
+	connect(this, &CallsListModel::countChanged, this, &CallsListModel::canMergeCallsChanged);
 }
 
 CallModel *CallsListModel::findCallModelFromPeerAddress (const QString &peerAddress) const {
 	std::shared_ptr<linphone::Address> address = Utils::interpretUrl(peerAddress);
-	auto it = find_if(mList.begin(), mList.end(), [address](CallModel *callModel) {
-			return callModel->getRemoteAddress()->weakEqual(address);
+	auto it = find_if(mList.begin(), mList.end(), [address](QSharedPointer<QObject> callModel) {
+			return callModel.objectCast<CallModel>()->getRemoteAddress()->weakEqual(address);
 	});
-	return it != mList.end() ? *it : nullptr;
+	return it != mList.end() ? it->objectCast<CallModel>().get() : nullptr;
 }
 
 // -----------------------------------------------------------------------------
@@ -117,9 +96,11 @@ void CallsListModel::launchAudioCall (const QString &sipAddress, const QString&
 	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = true;
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	
-	shared_ptr<linphone::Address> address = core->interpretUrl(Utils::appStringToCoreString(sipAddress));
-	if (!address)
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(sipAddress);
+	if (!address){
+		qCritical() << "The calling address is not an interpretable SIP address: " << sipAddress;
 		return;
+	}
 	
 	shared_ptr<linphone::CallParams> params = core->createCallParams(nullptr);
 	params->enableVideo(false);
@@ -129,17 +110,18 @@ void CallsListModel::launchAudioCall (const QString &sipAddress, const QString&
 		iterator.next();
 		params->addCustomHeader(Utils::appStringToCoreString(iterator.key()), Utils::appStringToCoreString(iterator.value()));
 	}
-	params->setProxyConfig(core->getDefaultProxyConfig());
+	if(core->getDefaultAccount())
+		params->setAccount(core->getDefaultAccount());
 	CallModel::setRecordFile(params, Utils::coreStringToAppString(address->getUsername()));
-	shared_ptr<linphone::ProxyConfig> currentProxyConfig = core->getDefaultProxyConfig();
-	if(currentProxyConfig){
-		if(!CoreManager::getInstance()->getSettingsModel()->getWaitRegistrationForCall() || currentProxyConfig->getState() == linphone::RegistrationState::Ok)
+	shared_ptr<linphone::Account> currentAccount = core->getDefaultAccount();
+	if(currentAccount){
+		if(!CoreManager::getInstance()->getSettingsModel()->getWaitRegistrationForCall() || currentAccount->getState() == linphone::RegistrationState::Ok)
 			CallModel::prepareTransfert(core->inviteAddressWithParams(address, params), prepareTransfertAddress);
 		else{
 			QObject * context = new QObject();
 			QObject::connect(CoreManager::getInstance()->getHandlers().get(), &CoreHandlers::registrationStateChanged,context,
-							 [address,core,params,currentProxyConfig,prepareTransfertAddress, context](const std::shared_ptr<linphone::ProxyConfig> &proxyConfig, linphone::RegistrationState state) mutable {
-				if(context && proxyConfig==currentProxyConfig && state==linphone::RegistrationState::Ok){
+							 [address,core,params,currentAccount,prepareTransfertAddress, context](const std::shared_ptr<linphone::Account> &account, linphone::RegistrationState state) mutable {
+				if(context && account==currentAccount && state==linphone::RegistrationState::Ok){
 					CallModel::prepareTransfert(core->inviteAddressWithParams(address, params), prepareTransfertAddress);
 					context->deleteLater();
 					context = nullptr;
@@ -166,18 +148,19 @@ void CallsListModel::launchSecureAudioCall (const QString &sipAddress, LinphoneE
 		iterator.next();
 		params->addCustomHeader(Utils::appStringToCoreString(iterator.key()), Utils::appStringToCoreString(iterator.value()));
 	}
-	params->setProxyConfig(core->getDefaultProxyConfig());
+	if(core->getDefaultAccount())
+		params->setAccount(core->getDefaultAccount());
 	CallModel::setRecordFile(params, Utils::coreStringToAppString(address->getUsername()));
-	shared_ptr<linphone::ProxyConfig> currentProxyConfig = core->getDefaultProxyConfig();
+	shared_ptr<linphone::Account> currentAccount = core->getDefaultAccount();
 	params->setMediaEncryption(LinphoneEnums::toLinphone(encryption));
-	if(currentProxyConfig){
-		if(!CoreManager::getInstance()->getSettingsModel()->getWaitRegistrationForCall() || currentProxyConfig->getState() == linphone::RegistrationState::Ok)
+	if(currentAccount){
+		if(!CoreManager::getInstance()->getSettingsModel()->getWaitRegistrationForCall() || currentAccount->getState() == linphone::RegistrationState::Ok)
 			CallModel::prepareTransfert(core->inviteAddressWithParams(address, params), prepareTransfertAddress);
 		else{
 			QObject * context = new QObject();
 			QObject::connect(CoreManager::getInstance()->getHandlers().get(), &CoreHandlers::registrationStateChanged,context,
-							 [address,core,params,currentProxyConfig,prepareTransfertAddress, context](const std::shared_ptr<linphone::ProxyConfig> &proxyConfig, linphone::RegistrationState state) mutable {
-				if(context && proxyConfig==currentProxyConfig && state==linphone::RegistrationState::Ok){
+							 [address,core,params,currentAccount,prepareTransfertAddress, context](const std::shared_ptr<linphone::Account> &account, linphone::RegistrationState state) mutable {
+				if(context && account==currentAccount && state==linphone::RegistrationState::Ok){
 					CallModel::prepareTransfert(core->inviteAddressWithParams(address, params), prepareTransfertAddress);
 					context->deleteLater();
 					context = nullptr;
@@ -188,8 +171,8 @@ void CallsListModel::launchSecureAudioCall (const QString &sipAddress, LinphoneE
 		CallModel::prepareTransfert(core->inviteAddressWithParams(address, params), prepareTransfertAddress);
 }
 
-void CallsListModel::launchVideoCall (const QString &sipAddress, const QString& prepareTransfertAddress) const {
-	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = true;
+void CallsListModel::launchVideoCall (const QString &sipAddress, const QString& prepareTransfertAddress, const bool& autoSelectAfterCreation, QVariantMap options) const {
+	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = autoSelectAfterCreation;
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	if (!core->videoSupported()) {
 		qWarning() << QStringLiteral("Unable to launch video call. (Video not supported.) Launching audio call...");
@@ -202,41 +185,25 @@ void CallsListModel::launchVideoCall (const QString &sipAddress, const QString&
 		return;
 	
 	shared_ptr<linphone::CallParams> params = core->createCallParams(nullptr);
-	params->enableVideo(true);
-	params->setProxyConfig(core->getDefaultProxyConfig());
-	CallModel::setRecordFile(params, Utils::coreStringToAppString(address->getUsername()));
-	CallModel::prepareTransfert(core->inviteAddressWithParams(address, params), prepareTransfertAddress);
-}
+	
+	auto layout = options.contains("layout") ? LinphoneEnums::toLinphone((LinphoneEnums::ConferenceLayout)options["layout"].toInt()) : linphone::ConferenceLayout::Grid;
+	bool enableMicro =options.contains("micro") ? options["micro"].toBool() : true;
+	bool enableVideo = options.contains("video") ? options["video"].toBool() : true;
+	bool enableCamera = options.contains("camera") ? options["camera"].toBool() : true;
+	bool enableSpeaker = options.contains("audio") ? options["audio"].toBool() : true;
 
-ChatRoomModel* CallsListModel::launchSecureChat (const QString &sipAddress) const {
-	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = true;
-	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	shared_ptr<linphone::Address> address = core->interpretUrl(Utils::appStringToCoreString(sipAddress));
-	if (!address)
-		return nullptr;
+	params->setConferenceVideoLayout(layout);
+	params->enableMic(enableMicro);
+	params->enableVideo(enableVideo);
+	params->setVideoDirection(enableCamera ? linphone::MediaDirection::SendRecv : linphone::MediaDirection::RecvOnly);
+	if(core->getDefaultAccount())
+		params->setAccount(core->getDefaultAccount());
+	CallModel::setRecordFile(params, Utils::coreStringToAppString(address->getUsername()));
 	
-	std::shared_ptr<linphone::ChatRoomParams> params = core->createDefaultChatRoomParams();
-	std::list <shared_ptr<linphone::Address> > participants;
-	std::shared_ptr<const linphone::Address> localAddress;
-	participants.push_back(address);
-	auto proxy = core->getDefaultProxyConfig();
-	params->enableEncryption(true);
-	
-	params->setSubject("Dummy Subject");
-	params->enableEncryption(true);
-	
-	std::shared_ptr<linphone::ChatRoom> chatRoom = core->createChatRoom(params, localAddress, participants);
-	if( chatRoom != nullptr){
-		auto timelineList = CoreManager::getInstance()->getTimelineListModel();
-		timelineList->update();
-		auto timeline = timelineList->getTimeline(chatRoom, false);
-		if(!timeline){
-			timeline = timelineList->getTimeline(chatRoom, true);
-			timelineList->add(timeline);
-		}
-		return timeline->getChatRoomModel();
-	}
-	return nullptr;
+	auto call = core->inviteAddressWithParams(address, params);
+	call->setSpeakerMuted(!enableSpeaker);
+	qInfo() << "Launch " << (enableVideo ? "video" : "audio") << " call; camera: " << enableCamera<< " speaker:" << enableSpeaker << ", micro:" << params->micEnabled() << ", layout:" << (int)layout;
+	CallModel::prepareTransfert(call, prepareTransfertAddress);
 }
 
 QVariantMap CallsListModel::launchChat(const QString &sipAddress, const int& securityLevel) const{
@@ -259,6 +226,7 @@ ChatRoomModel* CallsListModel::createChat (const QString &participantAddress) co
 	
 	params->setBackend(linphone::ChatRoomBackend::Basic);
 	
+	qInfo() << "Create ChatRoom with " <<participantAddress;
 	std::shared_ptr<linphone::ChatRoom> chatRoom = core->createChatRoom(params, localAddress, participants);
 	
 	if( chatRoom != nullptr){
@@ -269,7 +237,7 @@ ChatRoomModel* CallsListModel::createChat (const QString &participantAddress) co
 	return nullptr;
 }
 
-ChatRoomModel* CallsListModel::createChat (const CallModel * model) const{
+ChatRoomModel* CallsListModel::createChat (CallModel * model){
 	if(model){
 		return model->getChatRoomModel();
 	}
@@ -288,14 +256,25 @@ bool CallsListModel::createSecureChat (const QString& subject, const QString &pa
 	std::list <shared_ptr<linphone::Address> > participants;
 	std::shared_ptr<const linphone::Address> localAddress;
 	participants.push_back(address);
-	auto proxy = core->getDefaultProxyConfig();
 	params->enableEncryption(true);
 	
 	params->setSubject(Utils::appStringToCoreString(subject));
 	params->enableEncryption(true);
 	params->enableGroup(true);
 	
+	qInfo() << "Create secure ChatRoom: " << subject << ", from " << QString::fromStdString(localAddress->asString()) << " and with " <<participantAddress;;
 	std::shared_ptr<linphone::ChatRoom> chatRoom = core->createChatRoom(params, localAddress, participants);
+// Still needed?
+//	if( chatRoom != nullptr){
+//		auto timelineList = CoreManager::getInstance()->getTimelineListModel();
+//		timelineList->update();
+//		auto timeline = timelineList->getTimeline(chatRoom, false);
+//		if(!timeline){
+//			timeline = timelineList->getTimeline(chatRoom, true);
+//			timelineList->add(timeline);
+//		}
+//		return timeline->getChatRoomModel();
+//	}
 	return chatRoom != nullptr;
 }
 
@@ -310,10 +289,10 @@ QVariantMap CallsListModel::createChatRoom(const QString& subject, const int& se
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	std::shared_ptr<linphone::ChatRoom> chatRoom;
 	QList< std::shared_ptr<linphone::Address>> admins;
-	std::shared_ptr<TimelineModel> timeline;
+	QSharedPointer<TimelineModel> timeline;
 	auto timelineList = CoreManager::getInstance()->getTimelineListModel();
 	QString localAddressStr = (localAddress ? Utils::coreStringToAppString(localAddress->asStringUriOnly()) : "local");
-	qInfo() << "ChatRoom creation of " << subject << " at " << securityLevel << " security, from " << localAddressStr << " and with " << participants;
+	qInfo() << "Create ChatRoom: " << subject << " at " << securityLevel << " security, from " << localAddressStr << " and with " << participants;
 	
 	std::shared_ptr<linphone::ChatRoomParams> params = core->createDefaultChatRoomParams();
 	std::list <shared_ptr<linphone::Address> > chatRoomParticipants;
@@ -331,13 +310,12 @@ QVariantMap CallsListModel::createChatRoom(const QString& subject, const int& se
 		}
 		if( address)
 			chatRoomParticipants.push_back( address );
+		else
+			qWarning() << "Failed to add participant to conference, bad address : " << (participant ? participant->getSipAddress() : p.toString());
 	}
-	auto proxy = core->getDefaultProxyConfig();
 	params->enableEncryption(securityLevel>0);
 	
-	if( securityLevel>0){
-		params->enableEncryption(true);
-	}else
+	if( securityLevel<=0)
 		params->setBackend(linphone::ChatRoomBackend::Basic);
 	params->enableGroup( subject!="" );
 	
@@ -347,21 +325,29 @@ QVariantMap CallsListModel::createChatRoom(const QString& subject, const int& se
 			chatRoom = core->searchChatRoom(params, localAddress
 											, nullptr
 											, chatRoomParticipants);
+			if(chatRoom && ChatRoomModel::isTerminated(chatRoom))
+				chatRoom = nullptr;
 			params->setSubject(subject != ""?Utils::appStringToCoreString(subject):"Dummy Subject");
+			
 			if(!chatRoom)
 				chatRoom = core->searchChatRoom(params, localAddress
 												, nullptr
 												, chatRoomParticipants);
+				if(chatRoom && ChatRoomModel::isTerminated(chatRoom))
+					chatRoom = nullptr;
 		}else
 			params->setSubject(subject != ""?Utils::appStringToCoreString(subject):"Dummy Subject");
 		if( !chatRoom) {
 			chatRoom = core->createChatRoom(params, localAddress, chatRoomParticipants);
-			if(chatRoom != nullptr && admins.size() > 0)
-				ChatRoomInitializer::setAdminsAsync(params->getSubject(), params->getBackend(), params->groupEnabled(), admins );
-			timeline = timelineList->getTimeline(chatRoom, false);
+			if(chatRoom != nullptr && admins.size() > 0){
+				auto initializer = ChatRoomInitializer::create(chatRoom);
+				initializer->setAdminsData(admins);
+				ChatRoomInitializer::start(initializer);
+			}
+			timeline = timelineList->getTimeline(chatRoom, true);
 		}else{
 			if(admins.size() > 0){
-				ChatRoomInitializer::setAdminsSync(chatRoom, admins);
+				ChatRoomInitializer::create(chatRoom)->setAdmins(admins);
 			}
 			timeline = timelineList->getTimeline(chatRoom, true);
 		}
@@ -369,9 +355,7 @@ QVariantMap CallsListModel::createChatRoom(const QString& subject, const int& se
 			CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = false;
 			result["chatRoomModel"] = QVariant::fromValue(timeline->getChatRoomModel());
 			if(selectAfterCreation) {// The timeline here will not receive the first creation event. Set Selected if needed
-				QTimer::singleShot(200, [timeline](){// Delay process in order to let GUI time for Timeline building/linking before doing actions
-					timeline->setSelected(true);
-				});
+				timeline->delaySelected();
 			}
 		}
 	}
@@ -382,12 +366,107 @@ QVariantMap CallsListModel::createChatRoom(const QString& subject, const int& se
 	return result;
 }
 
+void CallsListModel::prepareConferenceCall(ConferenceInfoModel * model){
+	if(model->getConferenceInfoState() != LinphoneEnums::ConferenceInfoStateCancelled) {
+		auto app = App::getInstance();
+		app->smartShowWindow(app->getCallsWindow());
+		emit callConferenceAsked(model);
+	}
+}
+
+int CallsListModel::addAllToConference(){
+	return CoreManager::getInstance()->getCore()->addAllToConference();
+}
+
+void CallsListModel::mergeAll(){
+	auto core = CoreManager::getInstance()->getCore();
+	auto currentCalls = CoreManager::getInstance()->getCore()->getCalls();
+	shared_ptr<linphone::Conference> conference = core->getConference();
+	
+	// Search a managable conference from calls
+	if(!conference){
+		for(auto call : currentCalls){
+			auto dbConference = call->getConference();
+			if(dbConference && dbConference->getMe()->isAdmin()){
+				conference = dbConference;
+				break;
+			}
+		}
+	}
+  
+	auto currentCall = CoreManager::getInstance()->getCore()->getCurrentCall();
+	bool enablingVideo = false;
+	if( currentCall )
+		enablingVideo = currentCall->getCurrentParams()->videoEnabled();
+	if(!conference){
+		auto parameters = core->createConferenceParams(conference);
+		
+		if(!CoreManager::getInstance()->getSettingsModel()->getVideoConferenceEnabled()) {
+			parameters->enableVideo(false);
+			parameters->setConferenceFactoryAddress(nullptr);// Do a local conference
+			parameters->setSubject("Local meeting");
+		}else{
+			parameters->enableVideo(enablingVideo);
+			parameters->setSubject("Meeting");
+		}
+		conference = core->createConferenceWithParams(parameters);
+	}
+	
+	list<shared_ptr<linphone::Address>> allLinphoneAddresses;
+	list<shared_ptr<linphone::Address>> newCalls;
+	list<shared_ptr<linphone::Call>> runningCallsToAdd;
+	
+	for(auto call : currentCalls){
+		if(!call->getConference()){
+			runningCallsToAdd.push_back(call);
+		}
+	}
+ 
+// 1) Add running calls
+	if( runningCallsToAdd.size() > 0){
+		conference->addParticipants(runningCallsToAdd);
+	}
+  /*
+// 2) Put in pause and remove all calls that are not in the conference list
+	for(const auto &call : CoreManager::getInstance()->getCore()->getCalls()){
+      const std::string callAddress = call->getRemoteAddress()->asStringUriOnly();
+      auto address = allLinphoneAddresses.begin();
+      while(address != allLinphoneAddresses.end() && (*address)->asStringUriOnly() != callAddress)
+        ++address;
+      if(address == allLinphoneAddresses.end()){// Not in conference list :  put in pause and remove it from conference if it's the case
+        if( call->getParams()->getLocalConferenceMode() ){// Remove conference if it is not yet requested
+          CoreManager::getInstance()->getCore()->removeFromConference(call);
+        }else
+          call->pause();
+      }
+    }*/
+}
 // -----------------------------------------------------------------------------
 
 int CallsListModel::getRunningCallsNumber () const {
 	return CoreManager::getInstance()->getCore()->getCallsNb();
 }
 
+bool CallsListModel::canMergeCalls()const{
+	auto calls = CoreManager::getInstance()->getCore()->getCalls();
+	
+	bool mergableConference = false;
+	int mergableCalls = 0;
+	bool mergable = false;
+	for(auto itCall = calls.begin(); !mergable && itCall != calls.end() ; ++itCall ) {
+		auto conference = (*itCall)->getConference();
+		if(conference){
+			if( !mergableConference )
+				mergableConference = (conference  && conference->getMe()->isAdmin());
+		}else{
+			++mergableCalls;
+		}
+		mergable = (mergableConference && mergableCalls>0)	// A call can be merged into the conference
+					 || mergableCalls>1;// 2 calls can be merged
+	}
+	return mergable;
+}
+
 void CallsListModel::terminateAllCalls () const {
 	CoreManager::getInstance()->getCore()->terminateAllCalls();
 }
@@ -460,10 +539,13 @@ void CallsListModel::handleCallStateChanged (const shared_ptr<linphone::Call> &c
 		case linphone::Call::State::Error:{
 			if(call->dataExists("call-model")) {
 				CallModel * model = &call->getData<CallModel>("call-model");
-				model->callEnded();
+				model->endCall();
 			}
-			removeCall(call);
 		} break;
+		case linphone::Call::State::Released:
+			removeCall(call);
+		break;
+		
 		case linphone::Call::State::StreamsRunning: {
 			int index = findCallIndex(mList, call);
 			emit callRunning(index, &call->getData<CallModel>("call-model"));
@@ -474,60 +556,57 @@ void CallsListModel::handleCallStateChanged (const shared_ptr<linphone::Call> &c
 	}
 }
 
-bool CallsListModel::removeRow (int row, const QModelIndex &parent) {
-	return removeRows(row, 1, parent);
-}
-
-bool CallsListModel::removeRows (int row, int count, const QModelIndex &parent) {
-	int limit = row + count - 1;
-	
-	if (row < 0 || count < 0 || limit >= mList.count())
-		return false;
-	
-	beginRemoveRows(parent, row, limit);
-	
-	for (int i = 0; i < count; ++i)
-		mList.takeAt(row)->deleteLater();
-	
-	endRemoveRows();
-	
-	return true;
-}
-
 // -----------------------------------------------------------------------------
 
 void CallsListModel::addCall (const shared_ptr<linphone::Call> &call) {
-	if (call->getDir() == linphone::Call::Dir::Outgoing) {
-		QQuickWindow *callsWindow = App::getInstance()->getCallsWindow();
-		if (callsWindow) {
-			if (CoreManager::getInstance()->getSettingsModel()->getKeepCallsWindowInBackground()) {
-				if (!callsWindow->isVisible())
-					callsWindow->showMinimized();
-			} else
-				App::smartShowWindow(callsWindow);
+	int index = findCallIndex(mList, call);
+	if( index < 0){
+		QSharedPointer<CallModel> callModel = QSharedPointer<CallModel>::create(call);
+		qInfo() << QStringLiteral("Add call:") << callModel->getFullLocalAddress() << callModel->getFullPeerAddress();
+		App::getInstance()->getEngine()->setObjectOwnership(callModel.get(), QQmlEngine::CppOwnership);
+		
+		connect(callModel.get(), &CallModel::meAdminChanged, this, &CallsListModel::canMergeCallsChanged);
+		
+		add(callModel);
+		emit layoutChanged();
+		
+		if (call->getDir() == linphone::Call::Dir::Outgoing) {
+			QQuickWindow *callsWindow = App::getInstance()->getCallsWindow();
+			if (callsWindow) {
+				if (CoreManager::getInstance()->getSettingsModel()->getKeepCallsWindowInBackground()) {
+					if (!callsWindow->isVisible())
+						callsWindow->showMinimized();
+				} else
+					App::smartShowWindow(callsWindow);
+			}
 		}
 	}
+}
+
+
+void CallsListModel::addDummyCall () {
+	QQuickWindow *callsWindow = App::getInstance()->getCallsWindow();
+	if (callsWindow) {
+			App::smartShowWindow(callsWindow);
+	}
 	
-	CallModel *callModel = new CallModel(call);
+	QSharedPointer<CallModel> callModel = QSharedPointer<CallModel>::create(nullptr);
 	qInfo() << QStringLiteral("Add call:") << callModel->getFullLocalAddress() << callModel->getFullPeerAddress();
-	App::getInstance()->getEngine()->setObjectOwnership(callModel, QQmlEngine::CppOwnership);
+	App::getInstance()->getEngine()->setObjectOwnership(callModel.get(), QQmlEngine::CppOwnership);
 	
 	// This connection is (only) useful for `CallsListProxyModel`.
-	QObject::connect(callModel, &CallModel::isInConferenceChanged, this, [this, callModel](bool) {
+	QObject::connect(callModel.get(), &CallModel::isInConferenceChanged, this, [this, callModel](bool) {
 		int id = findCallIndex(mList, *callModel);
 		emit dataChanged(index(id, 0), index(id, 0));
 	});
+	connect(callModel.get(), &CallModel::meAdminChanged, this, &CallsListModel::canMergeCallsChanged);
 	
-	int row = mList.count();
-	
-	beginInsertRows(QModelIndex(), row, row);
-	mList << callModel;
-	endInsertRows();
+	add(callModel);
 	emit layoutChanged();
 }
 
 void CallsListModel::removeCall (const shared_ptr<linphone::Call> &call) {
-	CallModel *callModel;
+	CallModel *callModel = nullptr;
 	
 	try {
 		callModel = &call->getData<CallModel>("call-model");
@@ -537,16 +616,14 @@ void CallsListModel::removeCall (const shared_ptr<linphone::Call> &call) {
 		qWarning() << QStringLiteral("Unable to find call:") << call.get();
 		return;
 	}
-	
-	QTimer::singleShot(DelayBeforeRemoveCall, this, [this, callModel] {
-		removeCallCb(callModel);
-	});
+	if( callModel && callModel->getCallError() != ""){	// Wait some time to display an error on ending call.
+		QTimer::singleShot( DelayBeforeRemoveCall , this, [this, callModel] {
+				removeCallCb(callModel);
+		});
+	}else
+		remove(callModel);
 }
 
 void CallsListModel::removeCallCb (CallModel *callModel) {
-	qInfo() << QStringLiteral("Removing call:") << callModel;
-	
-	int index = mList.indexOf(callModel);
-	if (index == -1 || !removeRow(index))
-		qWarning() << QStringLiteral("Unable to remove call:") << callModel;
+	remove(callModel);
 }
