@@ -22,9 +22,11 @@
 #define CHAT_ROOM_MODEL_H_
 
 #include <linphone++/linphone.hh>
-#include <QAbstractListModel>
+#include "app/proxyModel/ProxyListModel.hpp"
 #include <QDateTime>
 
+#include "utils/LinphoneEnums.hpp"
+
 // =============================================================================
 // Fetch all N messages of a ChatRoom.
 // =============================================================================
@@ -37,70 +39,9 @@ class ContactModel;
 class ChatRoomModel;
 class ChatMessageModel;
 class ChatNoticeModel;
+class ChatRoomListener;
 
-class ChatRoomModelListener : public QObject, public linphone::ChatRoomListener {
-Q_OBJECT
-public:
-	ChatRoomModelListener(ChatRoomModel * model, QObject * parent = nullptr);
-	virtual ~ChatRoomModelListener(){}
-		
-	virtual void onIsComposingReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & remoteAddress, bool isComposing) override;
-	virtual void onMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message) override;
-	virtual void onNewEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onChatMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onChatMessageSending(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onChatMessageSent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onParticipantAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onParticipantRemoved(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onParticipantAdminStatusChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onStateChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, linphone::ChatRoom::State newState) override;
-	virtual void onSecurityEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onSubjectChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onUndecryptableMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message) override;
-	virtual void onParticipantDeviceAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onParticipantDeviceRemoved(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onConferenceJoined(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onConferenceLeft(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onEphemeralEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onEphemeralMessageTimerStarted(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onEphemeralMessageDeleted(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) override;
-	virtual void onConferenceAddressGeneration(const std::shared_ptr<linphone::ChatRoom> & chatRoom) override;
-	virtual void onParticipantRegistrationSubscriptionRequested(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & participantAddress) override;
-	virtual void onParticipantRegistrationUnsubscriptionRequested(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & participantAddress) override;
-	virtual void onChatMessageShouldBeStored(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message) override;
-	virtual void onChatMessageParticipantImdnStateChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message, const std::shared_ptr<const linphone::ParticipantImdnState> & state) override;
-
-signals:
-	void isComposingReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & remoteAddress, bool isComposing);
-	void messageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message);
-	void newEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void chatMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void chatMessageSending(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void chatMessageSent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantRemoved(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantAdminStatusChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void stateChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, linphone::ChatRoom::State newState);
-	void securityEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void subjectChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void undecryptableMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message);
-	void participantDeviceAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantDeviceRemoved(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void conferenceJoined(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void conferenceLeft(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void ephemeralEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void ephemeralMessageTimerStarted(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void ephemeralMessageDeleted(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void conferenceAddressGeneration(const std::shared_ptr<linphone::ChatRoom> & chatRoom);
-	void participantRegistrationSubscriptionRequested(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & participantAddress);
-	void participantRegistrationUnsubscriptionRequested(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & participantAddress);
-	void chatMessageShouldBeStored(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message);
-	void chatMessageParticipantImdnStateChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message, const std::shared_ptr<const linphone::ParticipantImdnState> & state);
-
-};
-
-class ChatRoomModel : public QAbstractListModel {
-	class MessageHandlers;
+class ChatRoomModel : public ProxyListModel {
 	
 	Q_OBJECT
 	
@@ -134,36 +75,35 @@ public:
 	Q_PROPERTY(bool isComposing READ getIsRemoteComposing NOTIFY isRemoteComposingChanged)
 	Q_PROPERTY(QList<QString> composers READ getComposers NOTIFY isRemoteComposingChanged)
 	Q_PROPERTY(bool isReadOnly READ isReadOnly NOTIFY isReadOnlyChanged)
+	Q_PROPERTY(bool updating READ isUpdating NOTIFY updatingChanged)
 	
 	Q_PROPERTY(QString sipAddress READ getFullPeerAddress NOTIFY fullPeerAddressChanged)
 	Q_PROPERTY(QString sipAddressUriOnly READ getPeerAddress NOTIFY fullPeerAddressChanged)
 	Q_PROPERTY(QString username READ getUsername NOTIFY usernameChanged)
 	Q_PROPERTY(QString avatar READ getAvatar NOTIFY avatarChanged)
 	Q_PROPERTY(int presenceStatus READ getPresenceStatus NOTIFY presenceStatusChanged)
-	Q_PROPERTY(int state READ getState NOTIFY stateChanged)
+	Q_PROPERTY(LinphoneEnums::ChatRoomState state READ getState NOTIFY stateChanged)
 	
 	Q_PROPERTY(long ephemeralLifetime READ getEphemeralLifetime WRITE setEphemeralLifetime NOTIFY ephemeralLifetimeChanged)
 	Q_PROPERTY(bool ephemeralEnabled READ isEphemeralEnabled WRITE setEphemeralEnabled NOTIFY ephemeralEnabledChanged)
 	Q_PROPERTY(bool canBeEphemeral READ canBeEphemeral NOTIFY canBeEphemeralChanged)
 	Q_PROPERTY(bool markAsReadEnabled READ markAsReadEnabled WRITE enableMarkAsRead NOTIFY markAsReadEnabledChanged)
 	
-	Q_PROPERTY(ParticipantListModel* participants READ getParticipants CONSTANT)
+	Q_PROPERTY(ParticipantListModel* participants READ getParticipantListModel CONSTANT)
 	
 	Q_PROPERTY(ChatMessageModel * reply READ getReply WRITE setReply NOTIFY replyChanged)
 	
 	Q_PROPERTY(bool entriesLoading READ isEntriesLoading WRITE setEntriesLoading NOTIFY entriesLoadingChanged)
 	
 	
-	static std::shared_ptr<ChatRoomModel> create(std::shared_ptr<linphone::ChatRoom> chatRoom);
-	ChatRoomModel (std::shared_ptr<linphone::ChatRoom> chatRoom, QObject * parent = nullptr);
-	~ChatRoomModel ();
+	static QSharedPointer<ChatRoomModel> create(const std::shared_ptr<linphone::ChatRoom>& chatRoom, const std::list<std::shared_ptr<linphone::CallLog>>& callLogs = std::list<std::shared_ptr<linphone::CallLog>>());
+	ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoom, const std::list<std::shared_ptr<linphone::CallLog>>& callLogs = std::list<std::shared_ptr<linphone::CallLog>>(), QObject * parent = nullptr);
 	
-	int rowCount (const QModelIndex &index = QModelIndex()) const override;
+	~ChatRoomModel ();
 	
 	QHash<int, QByteArray> roleNames () const override;
 	QVariant data (const QModelIndex &index, int role) const override;
 	
-	bool removeRow (int row, const QModelIndex &parent = QModelIndex());
 	bool removeRows (int row, int count, const QModelIndex &parent = QModelIndex()) override;
 	void removeAllEntries ();
 
@@ -179,12 +119,13 @@ public:
 	QString getUsername () const;
 	QString getAvatar () const;
 	int getPresenceStatus() const;
-	int getState() const;
+	LinphoneEnums::ChatRoomState getState() const;
 	bool isReadOnly() const;
 	bool isEphemeralEnabled() const;
 	long getEphemeralLifetime() const;
 	bool canBeEphemeral();
 	bool haveEncryption() const;
+	bool haveConferenceAddress() const;
 	bool markAsReadEnabled() const;
 	Q_INVOKABLE bool isSecure() const;
 	int getSecurityLevel() const;
@@ -192,12 +133,15 @@ public:
 	bool isConference() const;
 	bool isOneToOne() const;
 	bool isMeAdmin() const;
-	bool isCurrentProxy() const;						// Return true if this chat room is Me() is the current proxy
+	bool isCurrentAccount() const;						// Return true if this chat room is Me() is the current account
 	bool canHandleParticipants() const;
 	bool getIsRemoteComposing () const;
 	bool isEntriesLoading() const;
 	bool isBasic() const;
-	ParticipantListModel* getParticipants() const;
+	bool isUpdating() const;
+	
+	ParticipantListModel* getParticipantListModel() const;
+	std::list<std::shared_ptr<linphone::Participant>> getParticipants(const bool& withMe = true) const;
 	std::shared_ptr<linphone::ChatRoom> getChatRoom();
 	QList<QString> getComposers();
 	QString getParticipantAddress();	// return peerAddress if not secure else return the first participant SIP address.
@@ -223,20 +167,25 @@ public:
 	void clearFilesToSend();
 
 // Tools
-	
-	void deleteChatRoom();
+	void markAsToDelete();
+	Q_INVOKABLE void deleteChatRoom();
 	Q_INVOKABLE void leaveChatRoom ();
 	Q_INVOKABLE void updateParticipants(const QVariantList& participants);		
 	void sendMessage (const QString &message);
 	Q_INVOKABLE void forwardMessage(ChatMessageModel * model);
 	void compose ();
 	Q_INVOKABLE void resetMessageCount ();
-	Q_INVOKABLE void resetEntries();
 	void initEntries();
 	Q_INVOKABLE int loadMoreEntries();	// return new entries count
-	void callEnded(std::shared_ptr<linphone::Call> call);
+	void onCallEnded(std::shared_ptr<linphone::Call> call);
 	void updateNewMessageNotice(const int& count);
 	Q_INVOKABLE int loadTillMessage(ChatMessageModel * message);// Load all entries till message and return its index. -1 if not found.
+	static bool isTerminated(const std::shared_ptr<linphone::ChatRoom>& chatRoom);
+	bool exists(const std::shared_ptr<linphone::ChatMessage> message) const;
+	
+	void addBindingCall();	// If a call is binding to this chat room, we avoid cleaning data (Add=+1, remove=-1)
+	void removeBindingCall();
+	virtual void resetData() override;
 	
 	QDateTime mLastUpdateTime;
 	int mUnreadMessagesCount = 0;
@@ -252,19 +201,20 @@ public:
 	
 	void insertCall (const std::shared_ptr<linphone::CallLog> &callLog);
 	void insertCalls (const QList<std::shared_ptr<linphone::CallLog> > &calls);
-	std::shared_ptr<ChatMessageModel> insertMessageAtEnd (const std::shared_ptr<linphone::ChatMessage> &message);
+	QSharedPointer<ChatMessageModel> insertMessageAtEnd (const std::shared_ptr<linphone::ChatMessage> &message);
 	void insertMessages (const QList<std::shared_ptr<linphone::ChatMessage> > &messages);
 	void insertNotice (const std::shared_ptr<linphone::EventLog> &enventLog);
 	void insertNotices (const QList<std::shared_ptr<linphone::EventLog>> &eventLogs);
 	
-	
 	//--------------------		CHAT ROOM HANDLER
 	
 public slots:
 	virtual void onIsComposingReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & remoteAddress, bool isComposing);
 	virtual void onMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message);
+	virtual void onMessagesReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::ChatMessage>> & messages);
 	virtual void onNewEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
 	virtual void onChatMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
+	virtual void onChatMessagesReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::EventLog>> & eventLogs);
 	virtual void onChatMessageSending(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
 	virtual void onChatMessageSent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
 	virtual void onParticipantAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
@@ -297,7 +247,7 @@ signals:
 	void entriesLoadingChanged(const bool& loading);
 	void moreEntriesLoaded(const int& count);
 	
-	void allEntriesRemoved (std::shared_ptr<ChatRoomModel> model);
+	void allEntriesRemoved (QSharedPointer<ChatRoomModel> model);
 	void lastEntryRemoved ();
 	
 	void messageSent (const std::shared_ptr<linphone::ChatMessage> &message);
@@ -328,43 +278,44 @@ signals:
 	void markAsReadEnabledChanged();
 	void chatRoomDeleted();// Must be connected with DirectConnection mode
 	void replyChanged();
+	void updatingChanged();
 	
 // Chat Room listener callbacks	
 	
-	void securityEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantRemoved(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantDeviceAdded(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantDeviceRemoved(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantAdminStatusChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void participantRegistrationSubscriptionRequested(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & participantAddress);
-	void participantRegistrationUnsubscriptionRequested(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::Address> & participantAddress);
-	void conferenceJoined(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
-	void conferenceLeft(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void securityEvent(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void participantAdded(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void participantRemoved(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void participantDeviceAdded(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void participantDeviceRemoved(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void participantAdminStatusChanged(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void participantRegistrationSubscriptionRequested(const std::shared_ptr<const linphone::Address> & participantAddress);
+	void participantRegistrationUnsubscriptionRequested(const std::shared_ptr<const linphone::Address> & participantAddress);
+	void conferenceJoined(const std::shared_ptr<const linphone::EventLog> & eventLog);
+	void conferenceLeft(const std::shared_ptr<const linphone::EventLog> & eventLog);
 	
 private:
+
+	void connectTo(ChatRoomListener * listener);
 	
 	void handleCallStateChanged (const std::shared_ptr<linphone::Call> &call, linphone::Call::State state);
 	void handleCallCreated(const std::shared_ptr<linphone::Call> &call);// Count an event call
 	void handlePresenceStatusReceived(std::shared_ptr<linphone::Friend> contact);
-	//void handleIsComposingChanged (const std::shared_ptr<linphone::ChatRoom> &chatRoom);
-	//void handleMessageReceived (const std::shared_ptr<linphone::ChatMessage> &message);
 	
-	//bool mIsRemoteComposing = false;
-	std::shared_ptr<ChatNoticeModel> mUnreadMessageNotice;
-	QList<std::shared_ptr<ChatEvent> > mEntries;
-	std::shared_ptr<ParticipantListModel> mParticipantListModel;
-	std::shared_ptr<CoreHandlers> mCoreHandlers;
-	std::shared_ptr<MessageHandlers> mMessageHandlers;
-	QMap<std::shared_ptr<const linphone::Address>, QString> mComposers;	// Store all addresses that are composing with its username
 	std::shared_ptr<linphone::ChatRoom> mChatRoom;
-	std::shared_ptr<ChatRoomModelListener> mChatRoomModelListener;
+	std::shared_ptr<ChatRoomListener> mChatRoomListener;	// This need to be a shared_ptr because of adding it to linphone
+	std::shared_ptr<CoreHandlers> mCoreHandlers;					// This need to be a shared_ptr because of adding it to linphone
 	
-	std::shared_ptr<ChatMessageModel> mReplyModel;
+	QMap<std::shared_ptr<const linphone::Address>, QString> mComposers;	// Store all addresses that are composing with its username
 	
-	std::weak_ptr<ChatRoomModel> mSelf;
+	QSharedPointer<ParticipantListModel> mParticipantListModel;
+	QSharedPointer<ChatMessageModel> mReplyModel;
+	QSharedPointer<ChatNoticeModel> mUnreadMessageNotice;
+	int mBindingCalls = 0;
+	bool mPostModelChangedEvents = true;
+	
+	QWeakPointer<ChatRoomModel> mSelf;
 };
 
-Q_DECLARE_METATYPE(std::shared_ptr<ChatRoomModel>)
+Q_DECLARE_METATYPE(QSharedPointer<ChatRoomModel>)
 
 #endif // CHAT_ROOM_MODEL_H_
