@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010-2020 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
  * This file is part of linphone-desktop
  * (see https://www.linphone.org).
@@ -56,6 +56,11 @@ ChatRoomProxyModel::ChatRoomProxyModel (QObject *parent) : QSortFilterProxyModel
 	sort(0);
 }
 
+ChatRoomProxyModel::~ChatRoomProxyModel(){
+	setSourceModel(nullptr);
+	setChatRoomModel(nullptr);	// Do remove process like setting haveCall if is Call.
+}
+
 // -----------------------------------------------------------------------------
 
 #define GET_CHAT_MODEL() \
@@ -87,6 +92,7 @@ CREATE_PARENT_MODEL_FUNCTION_WITH_PARAM(forwardMessage, ChatMessageModel *)
 
 CREATE_PARENT_MODEL_FUNCTION_WITH_ID(removeRow)
 
+CREATE_PARENT_MODEL_FUNCTION(deleteChatRoom)
 
 #undef GET_CHAT_MODEL
 #undef CREATE_PARENT_MODEL_FUNCTION
@@ -180,27 +186,25 @@ bool ChatRoomProxyModel::lessThan (const QModelIndex &left, const QModelIndex &r
 // -----------------------------------------------------------------------------
 
 QString ChatRoomProxyModel::getPeerAddress () const {
-	return mChatRoomModel ? mChatRoomModel->getPeerAddress() : mPeerAddress;//QString("");
+	return mChatRoomModel ? mChatRoomModel->getPeerAddress() : mPeerAddress;
 }
 
 void ChatRoomProxyModel::setPeerAddress (const QString &peerAddress) {
 	mPeerAddress = peerAddress;
 	emit peerAddressChanged(mPeerAddress);
-	//reload();
 }
 
 QString ChatRoomProxyModel::getLocalAddress () const {
-	return mChatRoomModel ? mChatRoomModel->getLocalAddress() : mLocalAddress;//QString("");
+	return mChatRoomModel ? mChatRoomModel->getLocalAddress() : mLocalAddress;
 }
 
 void ChatRoomProxyModel::setLocalAddress (const QString &localAddress) {
 	mLocalAddress = localAddress;
 	emit localAddressChanged(mLocalAddress);
-	//reload();
 }
 
 QString ChatRoomProxyModel::getFullPeerAddress () const {
-	return mChatRoomModel ? mChatRoomModel->getFullPeerAddress() : mFullPeerAddress;//QString("");
+	return mChatRoomModel ? mChatRoomModel->getFullPeerAddress() : mFullPeerAddress;
 }
 
 void ChatRoomProxyModel::setFullPeerAddress (const QString &peerAddress) {
@@ -209,7 +213,7 @@ void ChatRoomProxyModel::setFullPeerAddress (const QString &peerAddress) {
 }
 
 QString ChatRoomProxyModel::getFullLocalAddress () const {
-	return mChatRoomModel ? mChatRoomModel->getFullLocalAddress() : mFullLocalAddress;//QString("");
+	return mChatRoomModel ? mChatRoomModel->getFullLocalAddress() : mFullLocalAddress;
 }
 
 void ChatRoomProxyModel::setFullLocalAddress (const QString &localAddress) {
@@ -243,6 +247,19 @@ QString ChatRoomProxyModel::getCachedText() const{
 	return gCachedText;
 }
 
+void ChatRoomProxyModel::setIsCall(const bool& isCall){
+	if(mIsCall != isCall) {
+		if(mChatRoomModel){
+			if(isCall){
+				mChatRoomModel->addBindingCall();
+			}else
+				mChatRoomModel->removeBindingCall();
+		}
+		mIsCall = isCall;
+		emit isCallChanged();
+	}
+}
+
 // -----------------------------------------------------------------------------
 
 void ChatRoomProxyModel::reload (ChatRoomModel *chatRoomModel) {
@@ -254,7 +271,14 @@ void ChatRoomProxyModel::reload (ChatRoomModel *chatRoomModel) {
 			QObject::disconnect(ChatRoomModel, &ChatRoomModel::messageSent, this, &ChatRoomProxyModel::handleMessageSent);
 			QObject::disconnect(ChatRoomModel, &ChatRoomModel::markAsReadEnabledChanged, this, &ChatRoomProxyModel::markAsReadEnabledChanged);
 			QObject::disconnect(ChatRoomModel, &ChatRoomModel::moreEntriesLoaded, this, &ChatRoomProxyModel::onMoreEntriesLoaded);
+			QObject::disconnect(ChatRoomModel, &ChatRoomModel::chatRoomDeleted, this, &ChatRoomProxyModel::chatRoomDeleted);
+			if(mIsCall)
+				mChatRoomModel->removeBindingCall();
 		}
+		if( mIsCall && chatRoomModel){
+			chatRoomModel->addBindingCall();
+		}
+		
 		mChatRoomModel = CoreManager::getInstance()->getTimelineListModel()->getChatRoomModel(chatRoomModel);
 		setSourceModel(mChatRoomModel.get());
 		if (mChatRoomModel) {
@@ -265,10 +289,10 @@ void ChatRoomProxyModel::reload (ChatRoomModel *chatRoomModel) {
 			QObject::connect(ChatRoomModel, &ChatRoomModel::messageSent, this, &ChatRoomProxyModel::handleMessageSent);		
 			QObject::connect(ChatRoomModel, &ChatRoomModel::markAsReadEnabledChanged, this, &ChatRoomProxyModel::markAsReadEnabledChanged);
 			QObject::connect(ChatRoomModel, &ChatRoomModel::moreEntriesLoaded, this, &ChatRoomProxyModel::onMoreEntriesLoaded);
+			QObject::connect(ChatRoomModel, &ChatRoomModel::chatRoomDeleted, this, &ChatRoomProxyModel::chatRoomDeleted);
 			mChatRoomModel->initEntries();// This way, we don't load huge chat rooms (that lead to freeze GUI)
 		}
 	}
-	//invalidate();
 }
 
 void ChatRoomProxyModel::resetMessageCount(){
@@ -305,9 +329,15 @@ ChatRoomModel *ChatRoomProxyModel::getChatRoomModel () const{
 }
 
 void ChatRoomProxyModel::setChatRoomModel (ChatRoomModel *chatRoomModel){
-	reload(chatRoomModel);
-	emit chatRoomModelChanged();
-	emit isRemoteComposingChanged();
+	if(chatRoomModel){
+		reload(chatRoomModel);
+		emit chatRoomModelChanged();
+		emit isRemoteComposingChanged();
+	}else{
+		if(mIsCall && mChatRoomModel)
+			mChatRoomModel->removeBindingCall();
+		mChatRoomModel = nullptr;
+	}
 }
 // -----------------------------------------------------------------------------
 
@@ -335,11 +365,13 @@ void ChatRoomProxyModel::handleIsRemoteComposingChanged () {
 	emit isRemoteComposingChanged();
 }
 
-void ChatRoomProxyModel::handleMessageReceived (const shared_ptr<linphone::ChatMessage> &) {
+void ChatRoomProxyModel::handleMessageReceived (const shared_ptr<linphone::ChatMessage> &message) {
 	
 	QWindow *window = getParentWindow(this);
-	if (window && window->isActive() && mChatRoomModel)
-		mChatRoomModel->resetMessageCount();
+	if (mChatRoomModel){
+		if(window && window->isActive())
+			mChatRoomModel->resetMessageCount();
+	}
 }
 
 void ChatRoomProxyModel::handleMessageSent (const shared_ptr<linphone::ChatMessage> &) {
