@@ -38,43 +38,41 @@ class ChatRoomProxyModel : public QSortFilterProxyModel {
 	Q_PROPERTY(QString localAddress READ getLocalAddress WRITE setLocalAddress NOTIFY localAddressChanged)
 	Q_PROPERTY(QString fullPeerAddress READ getFullPeerAddress WRITE setFullPeerAddress NOTIFY fullPeerAddressChanged)
 	Q_PROPERTY(QString fullLocalAddress READ getFullLocalAddress WRITE setFullLocalAddress NOTIFY fullLocalAddressChanged)
-	//Q_PROPERTY(int isSecure READ isSecure WRITE setIsSecure NOTIFY isSecureChanged)
 	Q_PROPERTY(ChatRoomModel *chatRoomModel READ getChatRoomModel WRITE setChatRoomModel NOTIFY chatRoomModelChanged)
-	//Q_PROPERTY(bool isSecure MEMBER mIsSecure NOTIFY isSecureChanged)
-	//Q_PROPERTY(bool isRemoteComposing READ getIsRemoteComposing NOTIFY isRemoteComposingChanged)
 	Q_PROPERTY(QList<QString> composers READ getComposers NOTIFY isRemoteComposingChanged)
-	//Q_PROPERTY(bool isSecure READ getIsSecure NOTIFY isSecureChanged)
 	Q_PROPERTY(QString cachedText READ getCachedText)
 	
 	Q_PROPERTY(QString filterText MEMBER mFilterText WRITE setFilterText NOTIFY filterTextChanged)
 	Q_PROPERTY(bool markAsReadEnabled READ markAsReadEnabled WRITE enableMarkAsRead NOTIFY markAsReadEnabledChanged)// Focus is at end of the list. Used to reset message count if not at end
 	
+	Q_PROPERTY(bool isCall MEMBER mIsCall WRITE setIsCall NOTIFY isCallChanged)
+	
 public:
 	ChatRoomProxyModel (QObject *parent = Q_NULLPTR);
+	~ChatRoomProxyModel();
 	
 	int getEntryTypeFilter ();
 	Q_INVOKABLE void setEntryTypeFilter (int type);
+	Q_INVOKABLE void setFilterText(const QString& text);
 	
 	Q_INVOKABLE QString getDisplayNameComposers()const;
 	Q_INVOKABLE QVariant getAt(int row);
 	
+	void setIsCall(const bool& isCall);
+	
 	
 	Q_INVOKABLE void loadMoreEntriesAsync ();
 	Q_INVOKABLE void loadMoreEntries ();
 	
 	Q_INVOKABLE void removeAllEntries ();
 	Q_INVOKABLE void removeRow (int index);
+	Q_INVOKABLE void deleteChatRoom();
 	
 	Q_INVOKABLE void sendMessage (const QString &message);
-	
 	Q_INVOKABLE void forwardMessage(ChatMessageModel * model);
-	
 	Q_INVOKABLE void compose (const QString& text);
-	
 	Q_INVOKABLE void resetMessageCount();
 	
-	Q_INVOKABLE void setFilterText(const QString& text);
-	
 	Q_INVOKABLE int loadTillMessage(ChatMessageModel * message);// Load all entries till message and return its index in displayed list (-1 if not found)
 	
 public slots:
@@ -90,11 +88,13 @@ signals:
 	//bool isSecureChanged(bool secure);
 	
 	void chatRoomModelChanged();
+	void chatRoomDeleted();
 	
 	void moreEntriesLoaded (int n);
 	
 	void entryTypeFilterChanged (int type);
 	void filterTextChanged();
+	void isCallChanged();
 	
 protected:
 	bool filterAcceptsRow (int sourceRow, const QModelIndex &sourceParent) const override;
@@ -116,9 +116,6 @@ private:
 	bool markAsReadEnabled() const;
 	void enableMarkAsRead(const bool& enable);
 	
-	//bool isSecure () const;
-	//void setIsSecure (const int &secure);
-	
 	ChatRoomModel *getChatRoomModel() const;
 	void setChatRoomModel (ChatRoomModel *chatRoomModel);
 	
@@ -143,10 +140,11 @@ private:
 	QString mFullLocalAddress;
 	static QString gCachedText;
 	bool mMarkAsReadEnabled;
+	bool mIsCall = false;
 	
 	QString mFilterText;
 	
-	std::shared_ptr<ChatRoomModel> mChatRoomModel;
+	QSharedPointer<ChatRoomModel> mChatRoomModel;
 	
 	static constexpr int EntriesChunkSize = 50;
 };
