@@ -92,7 +92,7 @@ static void removeBelcardPhoto (const shared_ptr<belcard::BelCard> &belcard, boo
 
 // -----------------------------------------------------------------------------
 
-VcardModel::VcardModel (shared_ptr<linphone::Vcard> vcard, bool isReadOnly) {
+VcardModel::VcardModel (shared_ptr<linphone::Vcard> vcard, bool isReadOnly) : QObject(nullptr) {
 	Q_CHECK_PTR(vcard);
 	mVcard = vcard;
 	mIsReadOnly = isReadOnly;
@@ -460,9 +460,12 @@ QVariantList VcardModel::getUrls () const {
 	return list;
 }
 
-bool VcardModel::addUrl (const QString &url) {
+bool VcardModel::addUrl (QString url) {
 	CHECK_VCARD_IS_WRITABLE(this);
-
+	QUrl urlParser(url);
+	if( urlParser.scheme() == ""){
+		url = "https://"+url;
+	}
 	shared_ptr<belcard::BelCard> belcard = mVcard->getVcard();
 	if (findBelCardValue(belcard->getURLs(), url))
 		return false;
