@@ -34,7 +34,7 @@ namespace linphone {
 class VcardModel : public QObject {
   friend class ContactModel; // Grant access to `mVcard`.
 
-  Q_OBJECT;
+  Q_OBJECT
 
   Q_PROPERTY(QString username READ getUsername WRITE setUsername NOTIFY vcardUpdated);
   Q_PROPERTY(QString avatar READ getAvatar WRITE setAvatar NOTIFY vcardUpdated);
@@ -88,7 +88,7 @@ public:
   Q_INVOKABLE void removeEmail (const QString &email);
   Q_INVOKABLE bool updateEmail (const QString &oldEmail, const QString &email);
 
-  Q_INVOKABLE bool addUrl (const QString &url);
+  Q_INVOKABLE bool addUrl (QString url);
   Q_INVOKABLE void removeUrl (const QString &url);
   Q_INVOKABLE bool updateUrl (const QString &oldUrl, const QString &url);
 
