@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
- 
- // VisualC++: Windows doesn't have to rewrite min max or else building std::max will fail
-#define NOMINMAX
 
 #include <QCoreApplication>
 #include <QDir>
@@ -34,7 +31,6 @@
 #include "components/calls/CallsListModel.hpp"
 #include "components/chat/ChatModel.hpp"
 #include "components/chat-room/ChatRoomModel.hpp"
-#include "components/chat-room/ChatRoomListModel.hpp"
 #include "components/contact/VcardModel.hpp"
 #include "components/contacts/ContactsListModel.hpp"
 #include "components/contacts/ContactsImporterListModel.hpp"
@@ -95,14 +91,14 @@ CoreManager::~CoreManager(){
 // -----------------------------------------------------------------------------
 
 void CoreManager::initCoreManager(){
+	qInfo() << "Init CoreManager";
+	mAccountSettingsModel = new AccountSettingsModel(this);
+	mSettingsModel = new SettingsModel(this);
 	mCallsListModel = new CallsListModel(this);
 	mChatModel = new ChatModel(this);
-	mChatRoomListModel = new ChatRoomListModel(this);
 	mContactsListModel = new ContactsListModel(this);
 	mContactsImporterListModel = new ContactsImporterListModel(this);
-	mAccountSettingsModel = new AccountSettingsModel(this);
 	mLdapListModel = new LdapListModel(this);
-	mSettingsModel = new SettingsModel(this);
 	mSipAddressesModel = new SipAddressesModel(this);
 	mEventCountNotifier = new EventCountNotifier(this);
 	mTimelineListModel = new TimelineListModel(this);
@@ -149,20 +145,15 @@ void CoreManager::init (QObject *parent, const QString &configPath) {
 
 void CoreManager::uninit () {
 	if (mInstance) {
-		connect(mInstance, &QObject::destroyed, []()mutable{
-			mInstance = nullptr;
-			qInfo() << "Core is correctly destroyed";
-		});
-		QObject::connect(mInstance->getHandlers().get(), &CoreHandlers::coreStopped, mInstance, &QObject::deleteLater); // Delete data only when the core is Off
-		
+		mInstance->stopIterate();
+		auto core = mInstance->mCore;
 		mInstance->lockVideoRender();// Stop do iterations. We have to protect GUI.
-		mInstance->mCore->stop();
 		mInstance->unlockVideoRender();
-		QTest::qWaitFor([&]() {return mInstance == nullptr;},10000);
-		if( mInstance){
-			qWarning() << "Core couldn't destroy in time. It may lead to have multiple session of Core";
-			mInstance = nullptr;
-		}
+		delete mInstance;	// This will also remove stored Linphone objects.
+		mInstance = nullptr;
+		core->stop();
+		if( core->getGlobalState() != linphone::GlobalState::Off)
+			qWarning() << "Core is not off after stopping it. It may result to have multiple core instance.";
 	}
 }
 
@@ -222,7 +213,7 @@ void CoreManager::cleanLogs () const {
 
 void CoreManager::setDatabasesPaths () {
 	SET_DATABASE_PATH(Friends, Paths::getFriendsListFilePath());
-	SET_DATABASE_PATH(CallLogs, Paths::getCallHistoryFilePath());
+	linphone_core_set_call_logs_database_path(mCore->cPtr(), Paths::getCallHistoryFilePath().c_str());// Setting the message database let SDK to migrate data
 	if(QFile::exists(Utils::coreStringToAppString(Paths::getMessageHistoryFilePath()))){
 		linphone_core_set_chat_database_path(mCore->cPtr(), Paths::getMessageHistoryFilePath().c_str());// Setting the message database let SDK to migrate data
 		QFile::remove(Utils::coreStringToAppString(Paths::getMessageHistoryFilePath()));
@@ -269,8 +260,9 @@ void CoreManager::createLinphoneCore (const QString &configPath) {
 				Paths::getFactoryConfigFilePath(),
 				nullptr
 				);
+	setDatabasesPaths();
 	// Enable LIME on your core to use encryption.
-	mCore->enableLimeX3Dh(mCore->getLimeX3DhServerUrl() != "");
+	mCore->enableLimeX3Dh(mCore->limeX3DhAvailable());
 	// Now see the CoreService.CreateGroupChatRoom to see how to create a secure chat room
 	
 	mCore->addListener(mHandlers);
@@ -288,24 +280,37 @@ void CoreManager::createLinphoneCore (const QString &configPath) {
 	QString userAgent = Utils::computeUserAgent(config);
 	mCore->setUserAgent(Utils::appStringToCoreString(userAgent), mCore->getVersion());
 	mCore->start();
-	setDatabasesPaths();
 	setOtherPaths();
 	mCore->enableFriendListSubscription(true);
+	mCore->enableRecordAware(true);
+	if(mCore->getAccountCreatorUrl() == "")
+		mCore->setAccountCreatorUrl(Constants::DefaultFlexiAPIURL);
+	if( mCore->getAccountList().size() == 0)
+		mCore->setLogCollectionUploadServerUrl(Constants::DefaultUploadLogsServer);
 }
 
 void CoreManager::updateUserAgent(){
 	mCore->setUserAgent(Utils::appStringToCoreString(Utils::computeUserAgent(mCore->getConfig())), mCore->getVersion());
 	forceRefreshRegisters(); 	// After setting a new device name, REGISTER need to take account it.
 }
+void CoreManager::addingAccount(const std::shared_ptr<const linphone::AccountParams> params) {
+	if( params->getDomain() == Constants::LinphoneDomain) {// Special case for Linphone
+		// It has been decided that if the core encryption is None, new Linphone accounts will reset it to SRTP.
+			if( CoreManager::getInstance()->getSettingsModel()->getMediaEncryption() == SettingsModel::MediaEncryptionNone){
+				CoreManager::getInstance()->getSettingsModel()->setMediaEncryption(SettingsModel::MediaEncryptionSrtp);
+			}
+		}
+}
 
-void CoreManager::handleChatRoomCreated(const std::shared_ptr<ChatRoomModel> &chatRoomModel){
+void CoreManager::handleChatRoomCreated(const QSharedPointer<ChatRoomModel> &chatRoomModel){
 	emit chatRoomModelCreated(chatRoomModel);
 }
 
 void CoreManager::migrate () {
 	shared_ptr<linphone::Config> config = mCore->getConfig();
+	auto oldLimeServerUrl = mCore->getLimeX3DhServerUrl();// core url is deprecated : If core url exists, it must be copied to all linphone accounts.
 	int rcVersion = config->getInt(SettingsModel::UiSection, Constants::RcVersionName, 0);
-	if (rcVersion == Constants::RcVersionCurrent)
+	if (oldLimeServerUrl.empty() && rcVersion == Constants::RcVersionCurrent)
 		return;
 	if (rcVersion > Constants::RcVersionCurrent) {
 		qWarning() << QStringLiteral("RC file version (%1) is more recent than app rc file version (%2)!!!")
@@ -316,17 +321,8 @@ void CoreManager::migrate () {
 	qInfo() << QStringLiteral("Migrate from old rc file (%1 to %2).")
 			   .arg(rcVersion).arg(Constants::RcVersionCurrent);
 	
-	// Add message_expires param on old proxy configs.
-	/*
-  for (const auto &proxyConfig : mCore->getProxyConfigList()) {
-	if (proxyConfig->getDomain() == Constants::LinphoneDomain) {
-	  proxyConfig->setContactParameters(Constants::DefaultContactParameters);
-	  proxyConfig->setExpires(Constants::DefaultExpires);
-	  proxyConfig->done();
-	}
-  }*/
-	bool setlimeServerUrl = false;
-	for(const auto &account : mCore->getAccountList()){
+	bool setLimeServerUrl = false;
+	for(const auto &account : getAccountList()){
 		auto params = account->getParams();
 		if( params->getDomain() == Constants::LinphoneDomain) {
 			auto newParams = params->clone();
@@ -334,26 +330,48 @@ void CoreManager::migrate () {
 			if( rcVersion < 1) {
 				newParams->setContactParameters(Constants::DefaultContactParameters);
 				newParams->setExpires(Constants::DefaultExpires);
-				qInfo() << "Migrating " << accountIdentity << " for version 1. contact parameters = " << Constants::DefaultContactParameters << ", expires = " << Constants::DefaultExpires;
+				qInfo() << "Migrating" << accountIdentity << "for version 1. contact parameters =" << Constants::DefaultContactParameters << ", expires =" << Constants::DefaultExpires;
 			}
 			if( rcVersion < 2) {
-				newParams->setConferenceFactoryUri(Constants::DefaultConferenceURI);
-				setlimeServerUrl = true;
-				qInfo() << "Migrating " << accountIdentity << " for version 2. conference factory URI = " << Constants::DefaultConferenceURI;
+				bool exists = newParams->getConferenceFactoryUri() != "";
+				setLimeServerUrl = true;
+				if(!exists )
+					newParams->setConferenceFactoryUri(Constants::DefaultConferenceURI);
+				qInfo() << "Migrating" << accountIdentity << "for version 2. Conference factory URI" << (exists ? std::string("unchanged") : std::string("= ") +Constants::DefaultConferenceURI).c_str();
+				// note: using std::string.c_str() to avoid having double quotes in qInfo()
 			}
 			if( rcVersion < 3){
 				newParams->enableCpimInBasicChatRoom(true);
-				qInfo() << "Migrating " << accountIdentity << " for version 3. enable Cpim in basic chat rooms";
+				qInfo() << "Migrating" << accountIdentity << "for version 3. Enable Cpim in basic chat rooms";
 			}
+			if( rcVersion < 4){
+				newParams->enableRtpBundle(true);
+				qInfo() << "Migrating" << accountIdentity << "for version 4. Enable RTP bundle mode";
+			}
+			if( rcVersion < 5) {
+				bool exists = !!newParams->getAudioVideoConferenceFactoryAddress();
+				setLimeServerUrl = true;
+				if( !exists)
+					newParams->setAudioVideoConferenceFactoryAddress(Utils::interpretUrl(Constants::DefaultVideoConferenceURI));
+				qInfo() << "Migrating" << accountIdentity << "for version 5. Video conference factory URI" << (exists ? std::string("unchanged") : std::string("= ") +Constants::DefaultVideoConferenceURI).c_str();
+				// note: using std::string.c_str() to avoid having double quotes in qInfo()
+			}
+			
+			if(!oldLimeServerUrl.empty())
+				newParams->setLimeServerUrl(oldLimeServerUrl);
+			else if( setLimeServerUrl)
+				newParams->setLimeServerUrl(Constants::DefaultLimeServerURL);
+			
 			account->setParams(newParams);
 		}
 	}
-	if(setlimeServerUrl) {
-		mCore->setLimeX3DhServerUrl(Constants::DefaultLimeServerURL);
+	if( !oldLimeServerUrl.empty()) {
+		mCore->setLimeX3DhServerUrl("");
+		mCore->enableLimeX3Dh(true);
+	}else if(setLimeServerUrl) {
 		mCore->enableLimeX3Dh(true);
 	}
 	
-	
 	config->setInt(SettingsModel::UiSection, Constants::RcVersionName, Constants::RcVersionCurrent);
 }
 
@@ -377,32 +395,14 @@ int CoreManager::getMissedCallCount(const QString &peerAddress, const QString &l
 int CoreManager::getMissedCallCountFromLocal( const QString &localAddress)const{
 	return mEventCountNotifier ? mEventCountNotifier->getMissedCallCountFromLocal(localAddress) : 0;
 }
-int CoreManager::getUnreadChatMessage(const std::shared_ptr<const linphone::Address>& accountAddress)const{
-// Workaround : getUnreadMessagesCount(à doesn't check the sate of chat room so they can be left and still count in unread message (for example because of a bug on ack timeout). Remove these counts from the unread count.
-	std::list<std::shared_ptr<linphone::ChatRoom>> allChatRooms = mCore->getChatRooms();
-	std::list<std::shared_ptr<linphone::Account>> accountsList;
-	int unreadChatMessageCount;
-	if( accountAddress)
-		unreadChatMessageCount = mCore->getUnreadChatMessageCountFromLocal(accountAddress);
-	else {
-		accountsList = mCore->getAccountList();
-		unreadChatMessageCount = mCore->getUnreadChatMessageCountFromActiveLocals();
-	}
-	for(auto chatRoom : allChatRooms){
-		auto account = accountsList.begin();
-		if(!accountAddress){
-			while(account != accountsList.end() && !(*account)->getParams()->getIdentityAddress()->weakEqual(chatRoom->getLocalAddress()))
-				++account;
-		}
-		if( ((!accountAddress && account != accountsList.end()) || (accountAddress && accountAddress->weakEqual(chatRoom->getLocalAddress()) ))
-				&& (chatRoom->getState() == linphone::ChatRoom::State::Terminated || chatRoom->getState() == linphone::ChatRoom::State::Deleted))
-			unreadChatMessageCount -= chatRoom->getUnreadMessagesCount();
-	}
-	unreadChatMessageCount = std::max(0,unreadChatMessageCount);
-	
-	return unreadChatMessageCount;
-}
 
+std::list<std::shared_ptr<linphone::Account>> CoreManager::getAccountList()const{
+	std::list<std::shared_ptr<linphone::Account>> accounts;
+	for(auto account : mCore->getAccountList())
+		if( account->getCustomParam("hidden") != "1")
+			accounts.push_back(account);
+	return accounts;
+}
 // -----------------------------------------------------------------------------
 
 void CoreManager::startIterate(){
