@@ -68,7 +68,9 @@ AccountSettingsModel::AccountSettingsModel (QObject *parent) : QObject(parent) {
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::sipAddressChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::fullSipAddressChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::registrationStateChanged);
-	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::conferenceURIChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::conferenceUriChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::videoConferenceUriChanged);
+	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::limeServerUrlChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primaryDisplayNameChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primaryUsernameChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primarySipAddressChanged);
@@ -79,16 +81,22 @@ AccountSettingsModel::AccountSettingsModel (QObject *parent) : QObject(parent) {
 
 shared_ptr<const linphone::Address> AccountSettingsModel::getUsedSipAddress () const {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	shared_ptr<linphone::ProxyConfig> proxyConfig = core->getDefaultProxyConfig();
-	
-	return proxyConfig?proxyConfig->getIdentityAddress():core->createPrimaryContactParsed();
+	shared_ptr<linphone::Account> account = core->getDefaultAccount();
+	return account ? account->getParams()->getIdentityAddress() : core->createPrimaryContactParsed();
 }
 
 void AccountSettingsModel::setUsedSipAddress (const shared_ptr<const linphone::Address> &address) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	shared_ptr<linphone::ProxyConfig> proxyConfig = core->getDefaultProxyConfig();
-	
-	proxyConfig ? proxyConfig->setIdentityAddress(address) : core->setPrimaryContact(address->asString());
+	shared_ptr<linphone::Account> account = core->getDefaultAccount();
+	if( account){
+		auto params = account->getParams()->clone();
+		if(!params->setIdentityAddress(address)) {
+			account->setParams(params);
+			emit sipAddressChanged();
+		}
+		return;
+	}
+	core->setPrimaryContact(address->asString());
 	emit sipAddressChanged();
 }
 
@@ -101,67 +109,73 @@ QString AccountSettingsModel::getUsedSipAddressAsString () const {
 }
 // -----------------------------------------------------------------------------
 
-bool AccountSettingsModel::addOrUpdateProxyConfig (const shared_ptr<linphone::ProxyConfig> &proxyConfig) {
-	Q_CHECK_PTR(proxyConfig);
+bool AccountSettingsModel::addOrUpdateAccount (std::shared_ptr<linphone::Account> account, const std::shared_ptr<linphone::AccountParams>& accountParams) {
 	
 	CoreManager *coreManager = CoreManager::getInstance();
 	shared_ptr<linphone::Core> core = coreManager->getCore();
-	
-	list<shared_ptr<linphone::ProxyConfig>> proxyConfigs = core->getProxyConfigList();
-	if (find(proxyConfigs.cbegin(), proxyConfigs.cend(), proxyConfig) != proxyConfigs.cend()) {
-		if (proxyConfig->done() == -1) {
-			qWarning() << QStringLiteral("Unable to update proxy config: `%1`.")
-						  .arg(QString::fromStdString(proxyConfig->getIdentityAddress()->asString()));
-			return false;
-		}
-		coreManager->getSettingsModel()->configureRlsUri();
-	} else {
-		if (core->addProxyConfig(proxyConfig) == -1) {
-			qWarning() << QStringLiteral("Unable to add proxy config: `%1`.")
-						  .arg(QString::fromStdString(proxyConfig->getIdentityAddress()->asString()));
-			return false;
-		}
-		coreManager->getSettingsModel()->configureRlsUri(proxyConfig);
+	list<shared_ptr<linphone::Account>> accounts = coreManager->getAccountList();
+	if(!account)
+		account = core->createAccount(accountParams);
+	if (account->setParams(accountParams) == -1) {
+		qWarning() << QStringLiteral("Unable to update account: `%1`.")
+					  .arg(QString::fromStdString(account->getParams()->getIdentityAddress()->asString()));
+		return false;
 	}
+	if (find(accounts.cbegin(), accounts.cend(), account) == accounts.cend()) {
+		if (core->addAccount(account) == -1) {
+			qWarning() << QStringLiteral("Unable to add account: `%1`.")
+						  .arg(QString::fromStdString(account->getParams()->getIdentityAddress()->asString()));
+			return false;
+		}
+		
+		coreManager->addingAccount(account->getParams());
+		coreManager->getSettingsModel()->configureRlsUri(account);
+	}else
+		coreManager->getSettingsModel()->configureRlsUri();
+	
 	emit accountSettingsUpdated();
 	
 	return true;
 }
 
-QVariantMap AccountSettingsModel::getProxyConfigDescription (const shared_ptr<linphone::ProxyConfig> &proxyConfig) {
-	Q_CHECK_PTR(proxyConfig);
-	
+QVariantMap AccountSettingsModel::getAccountDescription (const shared_ptr<linphone::Account> &account) {
 	QVariantMap map;
+	auto accountParams = account->getParams();
 	
 	{
-		const shared_ptr<const linphone::Address> address = proxyConfig->getIdentityAddress();
+		const shared_ptr<const linphone::Address> address = accountParams->getIdentityAddress();
 		map["sipAddress"] = address
-				? Utils::coreStringToAppString(proxyConfig->getIdentityAddress()->asString())
+				? Utils::coreStringToAppString(accountParams->getIdentityAddress()->asString())
 				: QString("");
 	}
-	map["serverAddress"] = Utils::coreStringToAppString(proxyConfig->getServerAddr());
-	map["registrationDuration"] = proxyConfig->getPublishExpires();
+	map["serverAddress"] = Utils::coreStringToAppString(accountParams->getServerAddress()->asString());
+	map["registrationDuration"] = accountParams->getPublishExpires();
 	
 	if( map["serverAddress"].toString().toUpper().contains("TRANSPORT="))// transport has been specified : let the RFC select the transport
-		map["transport"] = Utils::coreStringToAppString(proxyConfig->getTransport());
+		map["transport"] = LinphoneEnums::toString(LinphoneEnums::fromLinphone(accountParams->getTransport()));
 	else// Set to TLS as default
-		map["transport"] = "tls";
-	if( proxyConfig->getRoutes().size() > 0)
-		map["route"] = Utils::coreStringToAppString(proxyConfig->getRoutes().front());
+		map["transport"] = "TLS";
+		auto routes = accountParams->getRoutesAddresses();
+	if( routes.size() > 0)
+		map["route"] = Utils::coreStringToAppString(routes.front()->asString());
 	else
 		map["route"] = "";
-	map["conferenceUri"] = Utils::coreStringToAppString(proxyConfig->getConferenceFactoryUri());
-	map["contactParams"] = Utils::coreStringToAppString(proxyConfig->getContactParameters());
-	map["avpfInterval"] = proxyConfig->getAvpfRrInterval();
-	map["registerEnabled"] = proxyConfig->registerEnabled();
-	map["publishPresence"] = proxyConfig->publishEnabled();
-	map["avpfEnabled"] = proxyConfig->getAvpfMode() == linphone::AVPFMode::Enabled;
-	map["registrationState"] = mapLinphoneRegistrationStateToUi(proxyConfig->getState());
+	map["conferenceUri"] = Utils::coreStringToAppString(accountParams->getConferenceFactoryUri());
+	auto address = accountParams->getAudioVideoConferenceFactoryAddress();
+	map["videoConferenceUri"] = address ? Utils::coreStringToAppString(address->asString()) : "";
+	map["limeServerUrl"] = Utils::coreStringToAppString(accountParams->getLimeServerUrl());
+	map["videoConferenceUri"] = address ? Utils::coreStringToAppString(address->asString()) : "";
+	map["contactParams"] = Utils::coreStringToAppString(accountParams->getContactParameters());
+	map["avpfInterval"] = accountParams->getAvpfRrInterval();
+	map["registerEnabled"] = accountParams->registerEnabled();
+	map["publishPresence"] = accountParams->publishEnabled();
+	map["avpfEnabled"] = accountParams->getAvpfMode() == linphone::AVPFMode::Enabled;
+	map["registrationState"] = mapLinphoneRegistrationStateToUi(account->getState());
 	
-	shared_ptr<linphone::NatPolicy> natPolicy = proxyConfig->getNatPolicy();
+	shared_ptr<linphone::NatPolicy> natPolicy = accountParams->getNatPolicy();
 	bool createdNat = !natPolicy;
 	if (createdNat)
-		natPolicy = proxyConfig->getCore()->createNatPolicy();
+		natPolicy = CoreManager::getInstance()->getCore()->createNatPolicy();
 	map["iceEnabled"] = natPolicy->iceEnabled();
 	map["turnEnabled"] = natPolicy->turnEnabled();
 	
@@ -171,8 +185,11 @@ QVariantMap AccountSettingsModel::getProxyConfigDescription (const shared_ptr<li
 	map["turnUser"] = Utils::coreStringToAppString(turnUser);
 	map["stunServer"] = Utils::coreStringToAppString(stunServer);
 	
-	if (createdNat)
-		proxyConfig->setNatPolicy(natPolicy);
+	if (createdNat){
+		auto accountParamsUpdated = accountParams->clone();
+		accountParamsUpdated->setNatPolicy(natPolicy);
+		account->setParams(accountParamsUpdated);
+	}
 	
 	shared_ptr<const linphone::AuthInfo> authInfo = CoreManager::getInstance()->getCore()->findAuthInfo(
 				"", turnUser, stunServer
@@ -182,83 +199,97 @@ QVariantMap AccountSettingsModel::getProxyConfigDescription (const shared_ptr<li
 	return map;
 }
 
-QString AccountSettingsModel::getConferenceURI() const{
+QString AccountSettingsModel::getConferenceUri() const{
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	shared_ptr<linphone::ProxyConfig> proxyConfig = core->getDefaultProxyConfig();
-	return proxyConfig ? Utils::coreStringToAppString(proxyConfig->getConferenceFactoryUri()) : "";
+	shared_ptr<linphone::Account> account = core->getDefaultAccount();
+	return account ? Utils::coreStringToAppString(account->getParams()->getConferenceFactoryUri()) : "";
 }
 
-void AccountSettingsModel::setDefaultProxyConfig (const shared_ptr<linphone::ProxyConfig> &proxyConfig) {
+QString AccountSettingsModel::getVideoConferenceUri() const{
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	if (core->getDefaultProxyConfig() != proxyConfig) {
-		core->setDefaultProxyConfig(proxyConfig);
+	shared_ptr<linphone::Account> account = core->getDefaultAccount();
+	if(account) {
+		auto address = account->getParams()->getAudioVideoConferenceFactoryAddress();		
+		return address ? Utils::coreStringToAppString(address->asString()) : "";
+	}else
+		return "";
+}
+
+QString AccountSettingsModel::getLimeServerUrl() const{
+	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
+	shared_ptr<linphone::Account> account = core->getDefaultAccount();
+	return account ? Utils::coreStringToAppString(account->getParams()->getLimeServerUrl()) : "";
+}
+
+void AccountSettingsModel::setDefaultAccount (const shared_ptr<linphone::Account> &account) {
+	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
+	if (mSelectedAccount != account) {
+		core->setDefaultAccount(account);
+		mSelectedAccount = account;
 		emit accountSettingsUpdated();
-		emit defaultProxyChanged();
+		emit defaultAccountChanged();
 	}
 }
 
-void AccountSettingsModel::setDefaultProxyConfigFromSipAddress (const QString &sipAddress) {
+void AccountSettingsModel::setDefaultAccountFromSipAddress (const QString &sipAddress) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	auto address = Utils::interpretUrl(sipAddress);
 	if ( core->createPrimaryContactParsed()->weakEqual(address)) {
-		setDefaultProxyConfig(nullptr);
+		setDefaultAccount(nullptr);
 		return;
 	}
 	
-	for (const auto &proxyConfig : core->getProxyConfigList())
-		if (proxyConfig->getIdentityAddress()->weakEqual(address)) {
-			setDefaultProxyConfig(proxyConfig);
+	for (const auto &account : CoreManager::getInstance()->getAccountList())
+		if (account->getParams()->getIdentityAddress()->weakEqual(address)) {
+			setDefaultAccount(account);
 			return;
 		}
 	
-	qWarning() << "Unable to set default proxy config from:" << sipAddress;
+	qWarning() << "Unable to set default account from:" << sipAddress;
 }
-void AccountSettingsModel::removeProxyConfig (const shared_ptr<linphone::ProxyConfig> &proxyConfig) {
-	Q_CHECK_PTR(proxyConfig);
+void AccountSettingsModel::removeAccount (const shared_ptr<linphone::Account> &account) {
 	
 	CoreManager *coreManager = CoreManager::getInstance();
-	std::shared_ptr<linphone::ProxyConfig> newProxy = nullptr;
-	std::list<std::shared_ptr<linphone::ProxyConfig>> allProxies = coreManager->getCore()->getProxyConfigList();
-	if( proxyConfig == coreManager->getCore()->getDefaultProxyConfig()){
-		for(auto proxy : allProxies){
-			if( proxy != proxyConfig ){
-				newProxy = proxy;
+	std::shared_ptr<linphone::Account> newAccount = nullptr;
+	std::list<std::shared_ptr<linphone::Account>> allAccounts = coreManager->getAccountList();
+	if( account == coreManager->getCore()->getDefaultAccount()){
+		for(auto nextAccount : allAccounts){
+			if( nextAccount != account){
+				newAccount = nextAccount;
 				break;
 			}
 		}
-		setDefaultProxyConfig(newProxy);
+		setDefaultAccount(newAccount);
 	}
 // "message-expires" is used to keep contact for messages. Setting to 0 will remove the contact for messages too.
 // Check if a "message-expires" exists and set it to 0
-	QStringList parameters = Utils::coreStringToAppString(proxyConfig->getContactParameters()).split(";");
+	QStringList parameters = Utils::coreStringToAppString(account->getParams()->getContactParameters()).split(";");
 	for(int i = 0 ; i < parameters.size() ; ++i){
 		QStringList fields = parameters[i].split("=");
 		if( fields.size() > 1 && fields[0].simplified() == "message-expires"){
 			parameters[i] = Constants::DefaultContactParametersOnRemove;
 		}
 	}
-	proxyConfig->edit();
-	proxyConfig->setContactParameters(Utils::appStringToCoreString(parameters.join(";")));
-	if (proxyConfig->done() == -1) {
-		qWarning() << QStringLiteral("Unable to reset message-expiry property before removing proxy config: `%1`.")
-				  .arg(QString::fromStdString(proxyConfig->getIdentityAddress()->asString()));
-	}else if(proxyConfig->registerEnabled()) { // Wait for update
-		mRemovingProxies.push_back(proxyConfig);
+	auto accountParams = account->getParams()->clone();
+	accountParams->setContactParameters(Utils::appStringToCoreString(parameters.join(";")));	
+	if (account->setParams(accountParams) == -1) {
+		qWarning() << QStringLiteral("Unable to reset message-expiry property before removing account: `%1`.")
+				  .arg(QString::fromStdString(account->getParams()->getIdentityAddress()->asString()));
+	}else if(account->getParams()->registerEnabled()) { // Wait for update
+		mRemovingAccounts.push_back(account);
 	}else{// Registration is not enabled : Removing without wait.
-		CoreManager::getInstance()->getCore()->removeProxyConfig(proxyConfig);
+		CoreManager::getInstance()->getCore()->removeAccount(account);
 	}
 	
 	emit accountSettingsUpdated();
 }
 
-bool AccountSettingsModel::addOrUpdateProxyConfig (
-		const shared_ptr<linphone::ProxyConfig> &proxyConfig,
+bool AccountSettingsModel::addOrUpdateAccount(
+		const shared_ptr<linphone::Account> &account,
 		const QVariantMap &data
 		) {
-	Q_CHECK_PTR(proxyConfig);
 	bool newPublishPresence = false;
-	
-	proxyConfig->edit();
+	auto accountParams = account->getParams()->clone();
 	
 	QString literal = data["sipAddress"].toString();
 	
@@ -271,7 +302,7 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 			return false;
 		}
 		
-		if (proxyConfig->setIdentityAddress(address)) {
+		if (accountParams->setIdentityAddress(address)) {
 			qWarning() << QStringLiteral("Unable to set identity address: `%1`.")
 						  .arg(Utils::coreStringToAppString(address->asStringUriOnly()));
 			return false;
@@ -280,42 +311,48 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 	
 	// Server address.
 	{
-		QString serverAddress = data["serverAddress"].toString();
+		auto serverAddress = Utils::interpretUrl(data["serverAddress"].toString());
 		
-		if (proxyConfig->setServerAddr(Utils::appStringToCoreString(serverAddress))) {
-			qWarning() << QStringLiteral("Unable to add server address: `%1`.").arg(serverAddress);
+		if (accountParams->setServerAddress(serverAddress)) {
+			qWarning() << QStringLiteral("Unable to add server address: `%1`.").arg(serverAddress->asString().c_str());
 			return false;
 		}
 	}
 	
 	if(data.contains("registrationDuration"))
-		proxyConfig->setPublishExpires(data["registrationDuration"].toInt());
-	if(data.contains("route"))
-		proxyConfig->setRoute(Utils::appStringToCoreString(data["route"].toString()));
-	QString conferenceURI = data["conferenceUri"].toString();
-	if(!conferenceURI.isEmpty())
-		proxyConfig->setConferenceFactoryUri(Utils::appStringToCoreString(conferenceURI));
+		accountParams->setPublishExpires(data["registrationDuration"].toInt());
+	if(data.contains("route")) {
+		std::list<std::shared_ptr<linphone::Address>> routes;
+		routes.push_back(Utils::interpretUrl(data["route"].toString()));
+		accountParams->setRoutesAddresses(routes);
+	}
+	QString txt = data["conferenceUri"].toString();// Var is used for debug
+	accountParams->setConferenceFactoryUri(Utils::appStringToCoreString(txt));
+	txt = data["videoConferenceUri"].toString();
+	accountParams->setAudioVideoConferenceFactoryAddress(Utils::interpretUrl(txt));
+	accountParams->setLimeServerUrl(Utils::appStringToCoreString(data["limeServerUrl"].toString()));
+		
 	if(data.contains("contactParams"))
-		proxyConfig->setContactParameters(Utils::appStringToCoreString(data["contactParams"].toString()));
+		accountParams->setContactParameters(Utils::appStringToCoreString(data["contactParams"].toString()));
 	if(data.contains("avpfInterval"))
-		proxyConfig->setAvpfRrInterval(uint8_t(data["avpfInterval"].toInt()));
+		accountParams->setAvpfRrInterval(uint8_t(data["avpfInterval"].toInt()));
 	if(data.contains("registerEnabled"))
-		proxyConfig->enableRegister(data.contains("registerEnabled") ? data["registerEnabled"].toBool() : true);
+		accountParams->enableRegister(data.contains("registerEnabled") ? data["registerEnabled"].toBool() : true);
 	if(data.contains("publishPresence")) {
-		newPublishPresence = proxyConfig->publishEnabled() != data["publishPresence"].toBool();
-		proxyConfig->enablePublish(data["publishPresence"].toBool());
+		newPublishPresence = accountParams->publishEnabled() != data["publishPresence"].toBool();
+		accountParams->enablePublish(data["publishPresence"].toBool());
 	}else
-		newPublishPresence = proxyConfig->publishEnabled();
+		newPublishPresence = accountParams->publishEnabled();
 	if(data.contains("avpfEnabled"))
-		proxyConfig->setAvpfMode(data["avpfEnabled"].toBool()
+		accountParams->setAvpfMode(data["avpfEnabled"].toBool()
 			? linphone::AVPFMode::Enabled
 			: linphone::AVPFMode::Default
 			  );
 	
-	shared_ptr<linphone::NatPolicy> natPolicy = proxyConfig->getNatPolicy();
+	shared_ptr<linphone::NatPolicy> natPolicy = accountParams->getNatPolicy();
 	bool createdNat = !natPolicy;
 	if (createdNat)
-		natPolicy = proxyConfig->getCore()->createNatPolicy();
+		natPolicy = CoreManager::getInstance()->getCore()->createNatPolicy();
 	if(data.contains("iceEnabled"))
 		natPolicy->enableIce(data["iceEnabled"].toBool());
 	if(data.contains("iceEnabled"))
@@ -331,9 +368,9 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
 	natPolicy->setStunServer(stunServer);
 	
 	if( createdNat)
-		proxyConfig->setNatPolicy(natPolicy);
+		accountParams->setNatPolicy(natPolicy);
 	
-	shared_ptr<linphone::Core> core(proxyConfig->getCore());
+	shared_ptr<linphone::Core> core(CoreManager::getInstance()->getCore());
 	shared_ptr<const linphone::AuthInfo> authInfo(core->findAuthInfo("", turnUser, stunServer));
 	if (authInfo) {
 		shared_ptr<linphone::AuthInfo> clonedAuthInfo(authInfo->clone());
@@ -353,31 +390,30 @@ bool AccountSettingsModel::addOrUpdateProxyConfig (
     ));
 	if( newPublishPresence)
 		emit publishPresenceChanged();
-	return addOrUpdateProxyConfig(proxyConfig);
+	return addOrUpdateAccount(account, accountParams);
 }
 
-bool AccountSettingsModel::addOrUpdateProxyConfig (
+bool AccountSettingsModel::addOrUpdateAccount (
   const QVariantMap &data
 ) {
-	shared_ptr<linphone::ProxyConfig> proxyConfig;
+	shared_ptr<linphone::Account> account;
 	QString sipAddress = data["sipAddress"].toString();
 	shared_ptr<linphone::Address> address = CoreManager::getInstance()->getCore()->interpretUrl(sipAddress.toStdString());
 	
-	for (const auto &databaseProxyConfig : CoreManager::getInstance()->getCore()->getProxyConfigList())
-	  if (databaseProxyConfig->getIdentityAddress()->weakEqual(address)) {
-		proxyConfig = databaseProxyConfig;
+	for (const auto &databaseAccount : CoreManager::getInstance()->getAccountList())
+	  if (databaseAccount->getParams()->getIdentityAddress()->weakEqual(address)) {
+		account = databaseAccount;
 	  }
-	if(!proxyConfig)
-		proxyConfig = createProxyConfig(data.contains("configFilename") ? data["configFilename"].toString() : "create-app-sip-account.rc" );
-	return addOrUpdateProxyConfig(proxyConfig, data);
+	if(!account)
+		account = createAccount(data.contains("configFilename") ? data["configFilename"].toString() : "create-app-sip-account.rc" );
+	return addOrUpdateAccount(account, data);
 }
 
-shared_ptr<linphone::ProxyConfig> AccountSettingsModel::createProxyConfig (const QString& assistantFile) {
+shared_ptr<linphone::Account> AccountSettingsModel::createAccount(const QString& assistantFile) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	qInfo() << QStringLiteral("Set config on assistant: `%1`.").arg(assistantFile);
 	core->getConfig()->loadFromXmlFile(Paths::getAssistantConfigDirPath() + assistantFile.toStdString());
-	core->enableLimeX3Dh(core->getLimeX3DhServerUrl() != "");
-	return core->createProxyConfig();
+	return core->createAccount(core->createAccountParams());
 }
 
 void AccountSettingsModel::addAuthInfo (
@@ -422,8 +458,8 @@ void AccountSettingsModel::setUsername (const QString &username) {
 }
 
 AccountSettingsModel::RegistrationState AccountSettingsModel::getRegistrationState () const {
-	shared_ptr<linphone::ProxyConfig> proxyConfig = CoreManager::getInstance()->getCore()->getDefaultProxyConfig();
-	return proxyConfig ? mapLinphoneRegistrationStateToUi(proxyConfig->getState()) : RegistrationStateNoProxy;
+	shared_ptr<linphone::Account> account = CoreManager::getInstance()->getCore()->getDefaultAccount();
+	return account ? mapLinphoneRegistrationStateToUi(account->getState()) : RegistrationStateNoAccount;
 }
 
 // -----------------------------------------------------------------------------
@@ -470,6 +506,14 @@ QString AccountSettingsModel::getPrimarySipAddress () const {
 				);
 }
 
+QString AccountSettingsModel::getDefaultAccountDomain() const{
+	auto account = CoreManager::getInstance()->getCore()->getDefaultAccount();
+	if(account)
+		return Utils::coreStringToAppString(account->getParams()->getDomain());
+	else
+		return "";
+}
+
 // -----------------------------------------------------------------------------
 
 QVariantList AccountSettingsModel::getAccounts () const {
@@ -478,28 +522,22 @@ QVariantList AccountSettingsModel::getAccounts () const {
 	
 	if(CoreManager::getInstance()->getSettingsModel()->getShowLocalSipAccount()) {
 		QVariantMap account;
-		auto address = core->createPrimaryContactParsed();
-		int unreadChatMessageCount = CoreManager::getInstance()->getUnreadChatMessage(address);
-		
-		account["sipAddress"] = Utils::coreStringToAppString(address->asStringUriOnly());
-		account["fullSipAddress"] = Utils::coreStringToAppString(address->asString());
-		account["unreadMessageCount"] = unreadChatMessageCount;
+		account["sipAddress"] = Utils::coreStringToAppString(core->createPrimaryContactParsed()->asStringUriOnly());
+		account["fullSipAddress"] = Utils::coreStringToAppString(core->createPrimaryContactParsed()->asString());
+		account["unreadMessageCount"] = core->getUnreadChatMessageCountFromLocal(core->createPrimaryContactParsed());
 		account["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(account["sipAddress"].toString());
-		account["proxyConfig"].setValue(nullptr);
+		account["account"].setValue(nullptr);
 		accounts << account;
 	}
 	
-	for (const auto &proxyConfig : core->getProxyConfigList()) {
-		QVariantMap account;
-		
-		auto proxyAddress = proxyConfig->getIdentityAddress();
-		int unreadChatMessageCount = CoreManager::getInstance()->getUnreadChatMessage(proxyAddress);
-		account["sipAddress"] = Utils::coreStringToAppString(proxyAddress->asStringUriOnly());
-		account["fullSipAddress"] = Utils::coreStringToAppString(proxyAddress->asString());
-		account["proxyConfig"].setValue(proxyConfig);
-		account["unreadMessageCount"] = unreadChatMessageCount;
-		account["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(account["sipAddress"].toString());
-		accounts << account;
+	for (const auto &account : CoreManager::getInstance()->getAccountList()) {
+		QVariantMap accountMap;
+		accountMap["sipAddress"] = Utils::coreStringToAppString(account->getParams()->getIdentityAddress()->asStringUriOnly());
+		accountMap["fullSipAddress"] = Utils::coreStringToAppString(account->getParams()->getIdentityAddress()->asString());
+		accountMap["account"].setValue(account);
+		accountMap["unreadMessageCount"] = account->getUnreadChatMessageCount();
+		accountMap["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(accountMap["sipAddress"].toString());
+		accounts << accountMap;
 	}
 	
 	return accounts;
@@ -508,28 +546,27 @@ QVariantList AccountSettingsModel::getAccounts () const {
 // -----------------------------------------------------------------------------
 
 void AccountSettingsModel::handleRegistrationStateChanged (
-		const shared_ptr<linphone::ProxyConfig> & proxy,
+		const shared_ptr<linphone::Account> & account,
 		linphone::RegistrationState state
 		) {
-	Q_UNUSED(proxy)
 	Q_UNUSED(state)
 	auto coreManager = CoreManager::getInstance();
-	shared_ptr<linphone::ProxyConfig> defaultProxyConfig = coreManager->getCore()->getDefaultProxyConfig();
+	shared_ptr<linphone::Account> defaultAccount = coreManager->getCore()->getDefaultAccount();
 	if( state == linphone::RegistrationState::Cleared){
-		auto authInfo = proxy->findAuthInfo();
+		auto authInfo = account->findAuthInfo();
 		if(authInfo)
-			QTimer::singleShot(60000, [authInfo](){// 60s is just to be sure. proxy_update remove deleted proxy only after 32s
+			QTimer::singleShot(60000, [authInfo](){// 60s is just to be sure. account_update remove deleted account only after 32s
 				CoreManager::getInstance()->getCore()->removeAuthInfo(authInfo);
 			});
 		coreManager->getSettingsModel()->configureRlsUri();
-	}else if(mRemovingProxies.contains(proxy)){
-		mRemovingProxies.removeAll(proxy);
-		QTimer::singleShot(100, [proxy, this](){// removeProxyConfig cannot be called from callback
-				CoreManager::getInstance()->getCore()->removeProxyConfig(proxy);
+	}else if(mRemovingAccounts.contains(account)){
+		mRemovingAccounts.removeAll(account);
+		QTimer::singleShot(100, [account, this](){// removeAccount cannot be called from callback
+				CoreManager::getInstance()->getCore()->removeAccount(account);
 				emit accountsChanged();
 		});
 	}
-	if(defaultProxyConfig == proxy)
+	if(defaultAccount == account)
 		emit defaultRegistrationChanged();
 	emit registrationStateChanged();
 }
