@@ -31,12 +31,14 @@
 #include "app/App.hpp"
 #include "app/logger/Logger.hpp"
 #include "app/paths/Paths.hpp"
+
 #include "components/core/CoreManager.hpp"
 #include "components/tunnel/TunnelModel.hpp"
 #include "include/LinphoneApp/PluginNetworkHelper.hpp"
 #include "utils/Utils.hpp"
 #include "utils/Constants.hpp"
 #include "utils/MediastreamerUtils.hpp"
+#include "AccountSettingsModel.hpp"
 #include "SettingsModel.hpp"
 
 
@@ -57,20 +59,42 @@ SettingsModel::SettingsModel (QObject *parent) : QObject(parent) {
 			 this, &SettingsModel::handleCallStateChanged);
 	QObject::connect(coreManager->getHandlers().get(), &CoreHandlers::ecCalibrationResult,
 			 this, &SettingsModel::handleEcCalibrationResult);
-
+			 
+// Readonly state that can change from default account
+	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::defaultAccountChanged, this, &SettingsModel::groupChatEnabledChanged);
+	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::defaultAccountChanged, this, &SettingsModel::videoConferenceEnabledChanged);
+	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::defaultAccountChanged, this, &SettingsModel::secureChatEnabledChanged);
+	
+	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::accountSettingsUpdated, this, &SettingsModel::groupChatEnabledChanged);
+	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::accountSettingsUpdated, this, &SettingsModel::videoConferenceEnabledChanged);
+	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::accountSettingsUpdated, this, &SettingsModel::secureChatEnabledChanged);
+	
 	configureRlsUri();
 }
+
 SettingsModel::~SettingsModel()
 {
-	if(mSimpleCaptureGraph )
-	{
+	if(mSimpleCaptureGraph ) {
 		delete mSimpleCaptureGraph;
 		mSimpleCaptureGraph = nullptr;
 	}
 }
+
 void SettingsModel::settingsWindowClosing(void) {
 	onSettingsTabChanged(-1);
 }
+
+void SettingsModel::reloadDevices(){
+	CoreManager::getInstance()->getCore()->reloadSoundDevices();
+	emit captureDevicesChanged(getCaptureDevices());
+	emit playbackDevicesChanged(getPlaybackDevices());
+	emit playbackDeviceChanged(getPlaybackDevice());
+	emit captureDeviceChanged(getCaptureDevice());
+	emit ringerDeviceChanged(getRingerDevice());
+	CoreManager::getInstance()->getCore()->reloadVideoDevices();
+	emit videoDevicesChanged(getVideoDevices());
+}
+
 //Provides tabbar per-tab setup/teardown mechanism for specific settings views
 void SettingsModel::onSettingsTabChanged(int idx) {
 	int prevIdx = mCurrentSettingsTab;
@@ -234,19 +258,36 @@ void SettingsModel::setDeviceName(const QString& deviceName){
 // Audio.
 // =============================================================================
 
+void SettingsModel::resetCaptureGraph() {
+	deleteCaptureGraph();
+	createCaptureGraph();
+}
 void SettingsModel::createCaptureGraph() {
-	if (mSimpleCaptureGraph)  {
-		delete mSimpleCaptureGraph;
-		mSimpleCaptureGraph = nullptr;
-	}
-	if (!mSimpleCaptureGraph) {
-		mSimpleCaptureGraph =
+	mSimpleCaptureGraph =
 			new MediastreamerUtils::SimpleCaptureGraph(Utils::appStringToCoreString(getCaptureDevice()), Utils::appStringToCoreString(getPlaybackDevice()));
-	}
 	mSimpleCaptureGraph->start();
 	emit captureGraphRunningChanged(getCaptureGraphRunning());
 }
-
+void SettingsModel::startCaptureGraph(){
+	if(!mSimpleCaptureGraph)
+		createCaptureGraph();
+	++mCaptureGraphListenerCount;
+}
+void SettingsModel::stopCaptureGraph(){
+	if(mCaptureGraphListenerCount > 0 ){
+		if(--mCaptureGraphListenerCount == 0)
+			deleteCaptureGraph();
+	}
+}
+void SettingsModel::deleteCaptureGraph(){
+	if (mSimpleCaptureGraph) {
+		if (mSimpleCaptureGraph->isRunning()) {
+			mSimpleCaptureGraph->stop();
+		}
+		delete mSimpleCaptureGraph;
+		mSimpleCaptureGraph = nullptr;
+	}
+}
 //Force a call on the 'detect' method of all audio filters, updating new or removed devices
 void SettingsModel::accessAudioSettings() {	
 	CoreManager::getInstance()->getCore()->reloadSoundDevices();
@@ -255,20 +296,16 @@ void SettingsModel::accessAudioSettings() {
 	emit playbackDeviceChanged(getPlaybackDevice());
 	emit captureDeviceChanged(getCaptureDevice());
 	emit ringerDeviceChanged(getRingerDevice());
+	emit playbackGainChanged(getPlaybackGain());
+	emit captureGainChanged(getCaptureGain());
 
-	if (!getIsInCall()) {
-		createCaptureGraph();
-	}
+	//if (!getIsInCall()) {
+		startCaptureGraph();
+	//}
 }
 
 void SettingsModel::closeAudioSettings() {
-	if (mSimpleCaptureGraph) {
-		if (mSimpleCaptureGraph->isRunning()) {
-			mSimpleCaptureGraph->stop();
-		}
-		delete mSimpleCaptureGraph;
-		mSimpleCaptureGraph = nullptr;
-	}
+	stopCaptureGraph();
 	emit captureGraphRunningChanged(getCaptureGraphRunning());
 }
 
@@ -291,10 +328,13 @@ float SettingsModel::getPlaybackGain() const {
 }
 
 void SettingsModel::setPlaybackGain(float gain) {
+	float oldGain = getPlaybackGain();
 	CoreManager::getInstance()->getCore()->setPlaybackGainDb(MediastreamerUtils::linearToDb(gain));
 	if (mSimpleCaptureGraph && mSimpleCaptureGraph->isRunning()) {
 		mSimpleCaptureGraph->setPlaybackGain(gain);
 	}
+	if((int)(oldGain*1000) != (int)(gain*1000))
+		emit playbackGainChanged(gain);
 }
 
 float SettingsModel::getCaptureGain() const {
@@ -303,10 +343,13 @@ float SettingsModel::getCaptureGain() const {
 }
 
 void SettingsModel::setCaptureGain(float gain) {
+	float oldGain = getCaptureGain();
 	CoreManager::getInstance()->getCore()->setMicGainDb(MediastreamerUtils::linearToDb(gain));
 	if (mSimpleCaptureGraph && mSimpleCaptureGraph->isRunning()) {
 		mSimpleCaptureGraph->setCaptureGain(gain);
 	}
+	if((int)(oldGain *1000) != (int)(gain *1000))
+		emit captureGainChanged(gain);
 }
 
 QStringList SettingsModel::getCaptureDevices () const {
@@ -350,7 +393,7 @@ void SettingsModel::setCaptureDevice (const QString &device) {
 		CoreManager::getInstance()->getCore()->setCaptureDevice(devId);
 		CoreManager::getInstance()->getCore()->setInputAudioDevice(*audioDevice);
 		emit captureDeviceChanged(device);
-		createCaptureGraph();
+		resetCaptureGraph();
 	}else
 		qWarning() << "Cannot set Capture device. The ID cannot be matched with an existant device : " << device;
 }
@@ -374,7 +417,7 @@ void SettingsModel::setPlaybackDevice (const QString &device) {
 		CoreManager::getInstance()->getCore()->setPlaybackDevice(devId);
 		CoreManager::getInstance()->getCore()->setOutputAudioDevice(*audioDevice);
 		emit playbackDeviceChanged(device);
-		createCaptureGraph();
+		resetCaptureGraph();
 	}else
 		qWarning() << "Cannot set Playback device. The ID cannot be matched with an existant device : " << device;
 }
@@ -443,7 +486,7 @@ void SettingsModel::setShowAudioCodecs (bool status) {
 
 //Force a call on the 'detect' method of all video filters, updating new or removed devices
 void SettingsModel::accessVideoSettings() {
-	if(!getIsInCall())// TODO : This is a workaround to a crash when reloading video devices while in call. Spotted on Macos.
+	//if(!getIsInCall())// TODO : This is a workaround to a crash when reloading video devices while in call. Spotted on Macos.
 		CoreManager::getInstance()->getCore()->reloadVideoDevices();
 	emit videoDevicesChanged(getVideoDevices());
 }
@@ -504,12 +547,9 @@ static inline QVariantMap createMapFromVideoDefinition (const shared_ptr<const l
 	QVariantMap map;
 
 	if (!definition) {
-		Q_ASSERT(!CoreManager::getInstance()->getCore()->videoSupported());
-
 		map["name"] = QStringLiteral("Bad EGG");
 		map["width"] = QStringLiteral("?????");
 		map["height"] = QStringLiteral("?????");
-
 		return map;
 	}
 
@@ -532,6 +572,18 @@ QVariantMap SettingsModel::getVideoDefinition () const {
 	return createMapFromVideoDefinition(CoreManager::getInstance()->getCore()->getPreferredVideoDefinition());
 }
 
+QVariantMap SettingsModel::getCurrentPreviewVideoDefinition () const {
+	auto definition = CoreManager::getInstance()->getCore()->getCurrentPreviewVideoDefinition();
+	if(definition)
+		return createMapFromVideoDefinition(definition);
+	else {
+		QVariantMap map;
+		map["width"] = 0;
+		map["height"] = 0;
+		return map;
+	}
+}
+
 void SettingsModel::setVideoDefinition (const QVariantMap &definition) {
 	CoreManager::getInstance()->getCore()->setPreferredVideoDefinition(
 									   definition.value("__definition").value<shared_ptr<const linphone::VideoDefinition>>()->clone()
@@ -543,7 +595,12 @@ void SettingsModel::setVideoDefinition (const QVariantMap &definition) {
 bool SettingsModel::getVideoSupported () const {
 	return CoreManager::getInstance()->getCore()->videoSupported();
 }
-
+void SettingsModel::setHighMosaicQuality(){
+	mConfig->setString("video", "max_mosaic_size", "");
+}
+void SettingsModel::setLimitedMosaicQuality(){
+	mConfig->setString("video", "max_mosaic_size", "vga");
+}
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getShowVideoCodecs () const {
@@ -555,6 +612,80 @@ void SettingsModel::setShowVideoCodecs (bool status) {
 	emit showVideoCodecsChanged(status);
 }
 
+// =============================================================================
+void SettingsModel::updateCameraMode(){
+	auto mode = mConfig->getString("video", "main_display_mode", "OccupyAllSpace");	
+	mConfig->setString("video", "main_display_mode", mode);
+	mConfig->setString("video", "other_display_mode", mode);
+}
+
+SettingsModel::CameraMode SettingsModel::cameraModefromString(const std::string& mode){
+	if( mode == "Hybrid")
+		return CameraMode::CameraMode_Hybrid;
+	else if( mode == "BlackBars")
+		return CameraMode::CameraMode_BlackBars;
+	else
+		return CameraMode::CameraMode_OccupyAllSpace;
+}
+std::string SettingsModel::toString(const CameraMode& mode){
+	std::string modeStr;
+	switch(mode){
+		case CameraMode::CameraMode_Hybrid : modeStr = "Hybrid";break;
+		case CameraMode::CameraMode_BlackBars: modeStr = "BlackBars";break;
+		default: modeStr = "OccupyAllSpace";
+	}
+	return modeStr;
+}
+SettingsModel::CameraMode SettingsModel::getCameraMode() const{
+	return cameraModefromString(mConfig->getString("video", "main_display_mode", "OccupyAllSpace"));
+}
+
+void SettingsModel::setCameraMode(CameraMode mode){
+	std::string modeToSet;
+	switch(mode){
+		case CameraMode::CameraMode_Hybrid : modeToSet = "Hybrid";break;
+		case CameraMode::CameraMode_BlackBars: modeToSet = "BlackBars";break;
+		default: modeToSet = "OccupyAllSpace";
+	}
+	mConfig->setString("video", "main_display_mode", modeToSet);
+	mConfig->setString("video", "other_display_mode", modeToSet);
+	emit cameraModeChanged();
+}
+
+SettingsModel::CameraMode SettingsModel::getGridCameraMode() const{
+	return cameraModefromString(mConfig->getString(UiSection, "main_grid_display_mode", "OccupyAllSpace"));
+}
+void SettingsModel::setGridCameraMode(CameraMode mode){
+	auto modeStd = toString(mode);
+	mConfig->setString(UiSection, "main_grid_display_mode", modeStd);
+	emit gridCameraModeChanged();
+}
+SettingsModel::CameraMode SettingsModel::getActiveSpeakerCameraMode() const{
+	return cameraModefromString(mConfig->getString(UiSection, "main_active_speaker_display_mode", "Hybrid"));
+}
+void SettingsModel::setActiveSpeakerCameraMode(CameraMode mode){
+	auto modeStd = toString(mode);
+	mConfig->setString(UiSection, "main_active_speaker_display_mode", modeStd);
+	emit activeSpeakerCameraModeChanged();
+}
+SettingsModel::CameraMode SettingsModel::getCallCameraMode() const{
+	return cameraModefromString(mConfig->getString(UiSection, "main_call_display_mode", "Hybrid"));
+}
+void SettingsModel::setCallCameraMode(CameraMode mode){
+	auto modeStd = toString(mode);
+	mConfig->setString(UiSection, "main_call_display_mode", modeStd);
+	emit callCameraModeChanged();
+}
+
+LinphoneEnums::ConferenceLayout SettingsModel::getVideoConferenceLayout() const{
+	return (LinphoneEnums::ConferenceLayout) mConfig->getInt(UiSection, "video_conference_layout", (int)LinphoneEnums::ConferenceLayoutActiveSpeaker);
+}
+
+void SettingsModel::setVideoConferenceLayout(LinphoneEnums::ConferenceLayout layout){
+	mConfig->setInt(UiSection, "video_conference_layout", (int)layout);
+	emit videoConferenceLayoutChanged();
+}
+
 // =============================================================================
 // Chat & calls.
 // =============================================================================
@@ -689,13 +820,22 @@ void SettingsModel::setStandardChatEnabled (bool status) {
 }
 
 bool SettingsModel::getSecureChatEnabled () const {
-	return !!mConfig->getInt(UiSection, getEntryFullName(UiSection, "secure_chat_enabled"), 1);
+	return !!mConfig->getInt(UiSection, getEntryFullName(UiSection, "secure_chat_enabled"), 1)
+		&& getLimeIsSupported()
+		&& CoreManager::getInstance()->getCore()->getDefaultAccount() && !CoreManager::getInstance()->getCore()->getDefaultAccount()->getParams()->getLimeServerUrl().empty()
+		//&& !CoreManager::getInstance()->getCore()->getLimeX3DhServerUrl().empty()
+		&& getGroupChatEnabled();
+	;
 }
 
 void SettingsModel::setSecureChatEnabled (bool status) {
 	if(!isReadOnly(UiSection, "secure_chat_enabled"))
 		mConfig->setInt(UiSection, "secure_chat_enabled", status);
-	emit secureChatEnabledChanged(getSecureChatEnabled () );
+	emit secureChatEnabledChanged();
+}
+
+bool SettingsModel::getGroupChatEnabled() const{
+	return CoreManager::getInstance()->getCore()->getDefaultAccount() && !CoreManager::getInstance()->getCore()->getDefaultAccount()->getParams()->getConferenceFactoryUri().empty();
 }
 
 // -----------------------------------------------------------------------------
@@ -722,7 +862,16 @@ void SettingsModel::setWaitRegistrationForCall(const bool& status){
 	mConfig->setInt(UiSection, "call_wait_registration", status);
 	emit waitRegistrationForCallChanged(status);
 }
-	
+
+bool SettingsModel::getIncallScreenshotEnabled() const{
+	return !!mConfig->getInt(UiSection, "show_take_screenshot_button_in_call", 0);
+}
+
+void SettingsModel::setIncallScreenshotEnabled(const bool& status){
+	mConfig->setInt(UiSection, "show_take_screenshot_button_in_call", status);
+	emit incallScreenshotEnabledChanged(status);
+}
+
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getConferenceEnabled () const {
@@ -734,6 +883,9 @@ void SettingsModel::setConferenceEnabled (bool status) {
 	emit conferenceEnabledChanged(status);
 }
 
+bool SettingsModel::getVideoConferenceEnabled() const{
+	return CoreManager::getInstance()->getCore()->getDefaultAccount() && !!CoreManager::getInstance()->getCore()->getDefaultAccount()->getParams()->getAudioVideoConferenceFactoryAddress();
+}
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getChatNotificationsEnabled () const {
@@ -793,7 +945,10 @@ bool SettingsModel::getLimeIsSupported () const {
 // -----------------------------------------------------------------------------
 
 static inline QVariant buildEncryptionDescription (SettingsModel::MediaEncryption encryption, const char *description) {
-	return QVariantList() << encryption << description;
+	QVariantMap m;
+	m["key"] = description;
+	m["value"] = encryption;
+	return m;
 }
 
 QVariantList SettingsModel::getSupportedMediaEncryptions () const {
@@ -803,8 +958,12 @@ QVariantList SettingsModel::getSupportedMediaEncryptions () const {
 	if (core->mediaEncryptionSupported(linphone::MediaEncryption::SRTP))
 		list << buildEncryptionDescription(MediaEncryptionSrtp, "SRTP");
 
-	if (core->mediaEncryptionSupported(linphone::MediaEncryption::ZRTP))
-		list << buildEncryptionDescription(MediaEncryptionZrtp, "ZRTP");
+	if (core->mediaEncryptionSupported(linphone::MediaEncryption::ZRTP)){
+		if( core->getPostQuantumAvailable())
+			list << buildEncryptionDescription(MediaEncryptionZrtp, "Post Quantum ZRTP");
+		else
+			list << buildEncryptionDescription(MediaEncryptionZrtp, "ZRTP");
+	}
 	
 	if (core->mediaEncryptionSupported(linphone::MediaEncryption::DTLS))
 		list << buildEncryptionDescription(MediaEncryptionDtls, "DTLS");
@@ -824,9 +983,6 @@ void SettingsModel::setMediaEncryption (MediaEncryption encryption) {
 	if (encryption == getMediaEncryption())
 		return;
 
-	if (encryption != SettingsModel::MediaEncryptionZrtp)
-        setLimeState(false);
-
 	CoreManager::getInstance()->getCore()->setMediaEncryption(
 								  static_cast<linphone::MediaEncryption>(encryption)
 								  );
@@ -855,6 +1011,10 @@ void SettingsModel::enableMandatoryMediaEncryption(bool mandatory) {
 	}
 }
 
+bool SettingsModel::getPostQuantumAvailable() const{
+	return CoreManager::getInstance()->getCore() && CoreManager::getInstance()->getCore()->getPostQuantumAvailable();
+}
+
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getLimeState () const {
@@ -865,10 +1025,7 @@ void SettingsModel::setLimeState (const bool& state) {
 	if (state == getLimeState())
 		return;
 
-    if (state)
-		setMediaEncryption(SettingsModel::MediaEncryptionZrtp);
-
-    CoreManager::getInstance()->getCore()->enableLimeX3Dh(!state);
+    CoreManager::getInstance()->getCore()->enableLimeX3Dh(state);
 
 	emit limeStateChanged(state);
 }
@@ -1212,8 +1369,8 @@ void SettingsModel::configureRlsUri () {
 
 	// Set rls uri if necessary.
 	const string domain = getRlsUriDomain();
-	for (const auto &proxyConfig : CoreManager::getInstance()->getCore()->getProxyConfigList())
-		if (proxyConfig->getDomain() == domain) {
+	for (const auto &account : CoreManager::getInstance()->getAccountList())
+		if (account->getParams()->getDomain() == domain) {
 			mConfig->setString("sip", "rls_uri", Constants::DefaultRlsUri);
 			return;
 		}
@@ -1221,21 +1378,23 @@ void SettingsModel::configureRlsUri () {
 	mConfig->setString("sip", "rls_uri", "");
 }
 
-void SettingsModel::configureRlsUri (const shared_ptr<const linphone::ProxyConfig> &proxyConfig) {
+void SettingsModel::configureRlsUri (const std::string& domain) {
 	if (!getRlsUriEnabled()) {
 		mConfig->setString("sip", "rls_uri", "");
 		return;
 	}
 
-	const string domain = getRlsUriDomain();
-	if (proxyConfig->getDomain() == domain) {
+	const string currentDomain = getRlsUriDomain();
+	if (domain == currentDomain) {
 		mConfig->setString("sip", "rls_uri", Constants::DefaultRlsUri);
 		return;
 	}
 
 	mConfig->setString("sip", "rls_uri", "");
 }
-
+void SettingsModel::configureRlsUri (const shared_ptr<const linphone::Account> &account) {
+	configureRlsUri(account->getParams()->getDomain());
+}
 //------------------------------------------------------------------------------
 
 bool SettingsModel::tunnelAvailable() const{
@@ -1323,6 +1482,10 @@ void SettingsModel::setDownloadFolder (const QString &folder) {
 
 // -----------------------------------------------------------------------------
 
+QString SettingsModel::getRemoteProvisioningRootUrl() const{
+	return Utils::coreStringToAppString(mConfig->getString(UiSection, "remote_provisioning_root", Constants::RemoteProvisioningURL));
+}
+
 QString SettingsModel::getRemoteProvisioning () const {
 	return Utils::coreStringToAppString(CoreManager::getInstance()->getCore()->getProvisioningUri());
 }
@@ -1330,7 +1493,7 @@ QString SettingsModel::getRemoteProvisioning () const {
 void SettingsModel::setRemoteProvisioning (const QString &remoteProvisioning) {
 	QString urlRemoteProvisioning = remoteProvisioning;
 	if( QUrl(urlRemoteProvisioning).isRelative()) {
-		urlRemoteProvisioning = QString(Constants::RemoteProvisioningURL) +"/"+ remoteProvisioning;
+		urlRemoteProvisioning = getRemoteProvisioningRootUrl() +"/"+ remoteProvisioning;
 	}
 	if (!CoreManager::getInstance()->getCore()->setProvisioningUri(Utils::appStringToCoreString(urlRemoteProvisioning)))
 		emit remoteProvisioningChanged(urlRemoteProvisioning);
@@ -1338,6 +1501,18 @@ void SettingsModel::setRemoteProvisioning (const QString &remoteProvisioning) {
 		emit remoteProvisioningNotChanged(urlRemoteProvisioning);
 }
 
+bool SettingsModel::isQRCodeAvailable() const{
+	return linphone::Factory::get()->isQrcodeAvailable() && !!mConfig->getInt(UiSection, "use_qrcode", 1);
+}
+
+QString SettingsModel::getFlexiAPIUrl() const{
+	return Utils::coreStringToAppString(CoreManager::getInstance()->getCore()->getAccountCreatorUrl());
+}
+void SettingsModel::setFlexiAPIUrl (const QString &url){
+	CoreManager::getInstance()->getCore()->setAccountCreatorUrl(Utils::appStringToCoreString(url));
+	emit flexiAPIUrlChanged(url);
+}
+
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getExitOnClose () const {
@@ -1364,7 +1539,8 @@ QString SettingsModel::getVersionCheckUrl() const{
 
 void SettingsModel::setVersionCheckUrl(const QString& url){
 	if( url != getVersionCheckUrl()){
-		mConfig->setString("misc", "version_check_url_root", Utils::appStringToCoreString(url));
+	// Do not trim the url before because we want to update GUI from potential auto fix.
+		mConfig->setString("misc", "version_check_url_root", Utils::appStringToCoreString(url.trimmed()));
 		if( url == Constants::VersionCheckReleaseUrl)
 			setVersionCheckType(VersionCheckType_Release);
 		else if( url == Constants::VersionCheckNightlyUrl)
@@ -1437,6 +1613,10 @@ void SettingsModel::accessAdvancedSettings() {
 
 //------------------------------------------------------------------------------
 
+QString SettingsModel::getLogText()const{
+	return Logger::getInstance()->getLogText();
+}
+
 QString SettingsModel::getLogsFolder () const {
 	return getLogsFolder(mConfig);
 }
