@@ -29,6 +29,7 @@
 
 #include "components/core/CoreHandlers.hpp"
 #include "components/contacts/ContactsImporterModel.hpp"
+#include "utils/LinphoneEnums.hpp"
 
 // =============================================================================
 class TunnelModel;
@@ -48,10 +49,11 @@ class SettingsModel : public QObject {
 	Q_PROPERTY(bool useOtherSipAccountEnabled READ getUseOtherSipAccountEnabled WRITE setUseOtherSipAccountEnabled NOTIFY useOtherSipAccountEnabledChanged)
 	
 	Q_PROPERTY(bool assistantSupportsPhoneNumbers READ getAssistantSupportsPhoneNumbers WRITE setAssistantSupportsPhoneNumbers NOTIFY assistantSupportsPhoneNumbersChanged)
+// Webviews config
 	Q_PROPERTY(QString assistantRegistrationUrl READ getAssistantRegistrationUrl WRITE setAssistantRegistrationUrl NOTIFY assistantRegistrationUrlChanged)
 	Q_PROPERTY(QString assistantLoginUrl READ getAssistantLoginUrl WRITE setAssistantLoginUrl NOTIFY assistantLoginUrlChanged)
 	Q_PROPERTY(QString assistantLogoutUrl READ getAssistantLogoutUrl WRITE setAssistantLogoutUrl NOTIFY assistantLogoutUrlChanged)
-	
+//----
 	Q_PROPERTY(bool cguAccepted READ isCguAccepted WRITE acceptCgu NOTIFY cguAcceptedChanged)
 	
 	// SIP Accounts. -------------------------------------------------------------
@@ -95,6 +97,12 @@ class SettingsModel : public QObject {
 	
 	Q_PROPERTY(bool showVideoCodecs READ getShowVideoCodecs WRITE setShowVideoCodecs NOTIFY showVideoCodecsChanged)
 	
+	Q_PROPERTY(CameraMode gridCameraMode READ getGridCameraMode WRITE setGridCameraMode NOTIFY gridCameraModeChanged)
+	Q_PROPERTY(CameraMode activeSpeakerCameraMode READ getActiveSpeakerCameraMode WRITE setActiveSpeakerCameraMode NOTIFY activeSpeakerCameraModeChanged)
+	Q_PROPERTY(CameraMode callCameraMode READ getCallCameraMode WRITE setCallCameraMode NOTIFY callCameraModeChanged)
+	Q_PROPERTY(LinphoneEnums::ConferenceLayout videoConferenceLayout READ getVideoConferenceLayout WRITE setVideoConferenceLayout NOTIFY videoConferenceLayoutChanged)
+	
+	
 	// Chat & calls. -------------------------------------------------------------
 	
 	Q_PROPERTY(bool autoAnswerStatus READ getAutoAnswerStatus WRITE setAutoAnswerStatus NOTIFY autoAnswerStatusChanged)
@@ -116,12 +124,15 @@ class SettingsModel : public QObject {
 	
 	Q_PROPERTY(bool standardChatEnabled READ getStandardChatEnabled WRITE setStandardChatEnabled NOTIFY standardChatEnabledChanged)
 	Q_PROPERTY(bool secureChatEnabled READ getSecureChatEnabled WRITE setSecureChatEnabled NOTIFY secureChatEnabledChanged)
+	Q_PROPERTY(bool groupChatEnabled READ getGroupChatEnabled NOTIFY groupChatEnabledChanged)
 	Q_PROPERTY(bool hideEmptyChatRooms READ getHideEmptyChatRooms WRITE setHideEmptyChatRooms NOTIFY hideEmptyChatRoomsChanged)
 	
+	
 	Q_PROPERTY(bool waitRegistrationForCall READ getWaitRegistrationForCall WRITE setWaitRegistrationForCall NOTIFY waitRegistrationForCallChanged)// Allow call only if the current proxy has been registered
+	Q_PROPERTY(bool incallScreenshotEnabled READ getIncallScreenshotEnabled WRITE setIncallScreenshotEnabled NOTIFY incallScreenshotEnabledChanged)
 	
 	Q_PROPERTY(bool conferenceEnabled READ getConferenceEnabled WRITE setConferenceEnabled NOTIFY conferenceEnabledChanged)
-	
+	Q_PROPERTY(bool videoConferenceEnabled READ getVideoConferenceEnabled NOTIFY videoConferenceEnabledChanged)
 	
 	Q_PROPERTY(bool chatNotificationsEnabled READ getChatNotificationsEnabled WRITE setChatNotificationsEnabled NOTIFY chatNotificationsEnabledChanged)
 	Q_PROPERTY(bool chatNotificationSoundEnabled READ getChatNotificationSoundEnabled WRITE setChatNotificationSoundEnabled NOTIFY chatNotificationSoundEnabledChanged)
@@ -134,6 +145,7 @@ class SettingsModel : public QObject {
 	
 	Q_PROPERTY(MediaEncryption mediaEncryption READ getMediaEncryption WRITE setMediaEncryption NOTIFY mediaEncryptionChanged)
 	Q_PROPERTY(bool mediaEncryptionMandatory READ mandatoryMediaEncryptionEnabled WRITE enableMandatoryMediaEncryption NOTIFY mediaEncryptionChanged)
+	Q_PROPERTY(bool isPostQuantumAvailable READ getPostQuantumAvailable CONSTANT)
 	
 	Q_PROPERTY(bool limeState READ getLimeState WRITE setLimeState NOTIFY limeStateChanged)
 	
@@ -184,6 +196,7 @@ class SettingsModel : public QObject {
 	Q_PROPERTY(int textMessageFontSize READ getTextMessageFontSize WRITE setTextMessageFontSize NOTIFY textMessageFontSizeChanged)
 	
 	Q_PROPERTY(QString remoteProvisioning READ getRemoteProvisioning WRITE setRemoteProvisioning NOTIFY remoteProvisioningChanged)
+	Q_PROPERTY(QString flexiAPIUrl READ getFlexiAPIUrl WRITE setFlexiAPIUrl NOTIFY flexiAPIUrlChanged)
 	
 	Q_PROPERTY(QString savedScreenshotsFolder READ getSavedScreenshotsFolder WRITE setSavedScreenshotsFolder NOTIFY savedScreenshotsFolderChanged)
 	Q_PROPERTY(QString savedCallsFolder READ getSavedCallsFolder WRITE setSavedCallsFolder NOTIFY savedCallsFolderChanged)
@@ -228,6 +241,15 @@ public:
 	};
 	Q_ENUM(VersionCheckType);
 	
+	enum CameraMode{
+		CameraMode_Hybrid = 0,
+		CameraMode_OccupyAllSpace = 1, 
+		CameraMode_BlackBars = 2
+	};
+	Q_ENUM(CameraMode);
+	static SettingsModel::CameraMode cameraModefromString(const std::string& mode);
+	static std::string toString(const CameraMode& mode);
+	
 	
 	SettingsModel (QObject *parent = Q_NULLPTR);
 	virtual ~SettingsModel ();
@@ -238,6 +260,7 @@ public:
 	
 	Q_INVOKABLE void onSettingsTabChanged(int idx);
 	Q_INVOKABLE void settingsWindowClosing(void);
+	Q_INVOKABLE void reloadDevices();
 	
 	// Assistant. ----------------------------------------------------------------
 	
@@ -277,8 +300,12 @@ public:
 	void setDeviceName(const QString& deviceName);
 
 	// Audio. --------------------------------------------------------------------
-	
+
+	Q_INVOKABLE void startCaptureGraph();
+	Q_INVOKABLE void stopCaptureGraph();
+	Q_INVOKABLE void resetCaptureGraph();
 	void createCaptureGraph();
+	void deleteCaptureGraph();
 	bool getCaptureGraphRunning();
 	void accessAudioSettings();
 	void closeAudioSettings();
@@ -332,7 +359,11 @@ public:
 	
 	QVariantList getSupportedVideoDefinitions () const;
 	
+	Q_INVOKABLE void setHighMosaicQuality();
+	Q_INVOKABLE void setLimitedMosaicQuality();
+	
 	QVariantMap getVideoDefinition () const;
+	Q_INVOKABLE QVariantMap getCurrentPreviewVideoDefinition () const;
 	void setVideoDefinition (const QVariantMap &definition);
 	
 	bool getVideoSupported () const;
@@ -340,6 +371,21 @@ public:
 	bool getShowVideoCodecs () const;
 	void setShowVideoCodecs (bool status);
 	
+	void updateCameraMode();
+	CameraMode getCameraMode() const;
+	Q_INVOKABLE void setCameraMode(CameraMode mode);
+	// Custom modes to set default for setCameraMode
+	CameraMode getGridCameraMode() const;
+	void setGridCameraMode(CameraMode mode);
+	CameraMode getActiveSpeakerCameraMode() const;
+	void setActiveSpeakerCameraMode(CameraMode mode);
+	CameraMode getCallCameraMode() const;
+	void setCallCameraMode(CameraMode mode);
+	
+	LinphoneEnums::ConferenceLayout getVideoConferenceLayout() const;
+	void setVideoConferenceLayout(LinphoneEnums::ConferenceLayout layout);
+	
+	
 	// Chat & calls. -------------------------------------------------------------
 	
 	bool getAutoAnswerStatus () const;
@@ -385,10 +431,16 @@ public:
 	void setHideEmptyChatRooms(const bool& data);
 	
 	bool getWaitRegistrationForCall() const;
-	void setWaitRegistrationForCall(const bool& data);
+	void setWaitRegistrationForCall(const bool& status);
+	
+	bool getIncallScreenshotEnabled() const;
+	void setIncallScreenshotEnabled(const bool& status);
+	
+	bool getGroupChatEnabled()const;
 	
 	bool getConferenceEnabled () const;
 	void setConferenceEnabled (bool status);
+	bool getVideoConferenceEnabled()const;
 	
 	bool getChatNotificationsEnabled () const;
 	void setChatNotificationsEnabled (bool status);
@@ -411,6 +463,8 @@ public:
 	bool mandatoryMediaEncryptionEnabled () const;
 	void enableMandatoryMediaEncryption(bool mandatory);
 	
+	bool getPostQuantumAvailable() const;
+	
 	bool getLimeState () const;
 	void setLimeState (const bool& state);
 	
@@ -482,7 +536,8 @@ public:
 	void setRlsUriEnabled (bool status);
 	
 	void configureRlsUri ();
-	void configureRlsUri (const std::shared_ptr<const linphone::ProxyConfig> &proxyConfig);
+	void configureRlsUri (const std::string& domain);
+	void configureRlsUri (const std::shared_ptr<const linphone::Account> &account);
 	
 	Q_INVOKABLE bool tunnelAvailable() const;
 	Q_INVOKABLE TunnelModel * getTunnel() const;
@@ -504,9 +559,14 @@ public:
 	QString getDownloadFolder () const;
 	void setDownloadFolder (const QString &folder);
 	
+	QString getRemoteProvisioningRootUrl() const;
 	QString getRemoteProvisioning () const;
 	void setRemoteProvisioning (const QString &remoteProvisioning);
 	
+	Q_INVOKABLE bool isQRCodeAvailable() const;
+	QString getFlexiAPIUrl() const;
+	void setFlexiAPIUrl (const QString &url);
+	
 	bool getExitOnClose () const;
 	void setExitOnClose (bool value);
 	
@@ -536,6 +596,8 @@ public:
 	
 	void accessAdvancedSettings();
 	
+	Q_INVOKABLE QString getLogText()const;
+	
 	QString getLogsFolder () const;
 	void setLogsFolder (const QString &folder);
 	
@@ -629,6 +691,12 @@ signals:
 	
 	void showVideoCodecsChanged (bool status);
 	
+	void cameraModeChanged();
+	void gridCameraModeChanged();
+	void activeSpeakerCameraModeChanged();
+	void callCameraModeChanged();
+	void videoConferenceLayoutChanged();
+	
 	// Chat & calls. -------------------------------------------------------------
 	
 	void autoAnswerStatusChanged (bool status);
@@ -649,11 +717,14 @@ signals:
 	void muteMicrophoneEnabledChanged (bool status);
 	
 	void standardChatEnabledChanged (bool status);
-	void secureChatEnabledChanged (bool status);
+	void secureChatEnabledChanged ();
+	void groupChatEnabledChanged();
 	void hideEmptyChatRoomsChanged (bool status);
 	void waitRegistrationForCallChanged (bool status);
+	void incallScreenshotEnabledChanged(bool status);
 	
 	void conferenceEnabledChanged (bool status);
+	void videoConferenceEnabledChanged ();
 	
 	void chatNotificationsEnabledChanged (bool status);
 	void chatNotificationSoundEnabledChanged (bool status);
@@ -710,6 +781,7 @@ signals:
 	
 	void remoteProvisioningChanged (const QString &remoteProvisioning);
 	void remoteProvisioningNotChanged (const QString &remoteProvisioning);
+	void flexiAPIUrlChanged (const QString &url);
 	
 	void exitOnCloseChanged (bool value);
 	void mipmapEnabledChanged();
@@ -735,6 +807,7 @@ signals:
 private:
 	int mCurrentSettingsTab = 0;
 	MediastreamerUtils::SimpleCaptureGraph *mSimpleCaptureGraph = nullptr;
+	int mCaptureGraphListenerCount = 0;
 	
 	std::shared_ptr<linphone::Config> mConfig;
 };
