@@ -38,12 +38,13 @@
 
 // =============================================================================
 
-TimelineListModel::TimelineListModel (QObject *parent) : QAbstractListModel(parent) {
+TimelineListModel::TimelineListModel (QObject *parent) : ProxyListModel(parent) {
 	mSelectedCount = 0;
 	CoreHandlers* coreHandlers= CoreManager::getInstance()->getHandlers().get();
+	connect(coreHandlers, &CoreHandlers::chatRoomRead, this, &TimelineListModel::onChatRoomRead);
 	connect(coreHandlers, &CoreHandlers::chatRoomStateChanged, this, &TimelineListModel::onChatRoomStateChanged);
-	connect(coreHandlers, &CoreHandlers::messageReceived, this, &TimelineListModel::update);
-	connect(coreHandlers, &CoreHandlers::messageReceived, this, &TimelineListModel::updated);
+	connect(coreHandlers, &CoreHandlers::messagesReceived, this, &TimelineListModel::update);
+	connect(coreHandlers, &CoreHandlers::messagesReceived, this, &TimelineListModel::updated);
 	
 	QObject::connect(coreHandlers, &CoreHandlers::callStateChanged, this, &TimelineListModel::onCallStateChanged);
 	QObject::connect(coreHandlers, &CoreHandlers::callCreated, this, &TimelineListModel::onCallCreated);
@@ -53,12 +54,35 @@ TimelineListModel::TimelineListModel (QObject *parent) : QAbstractListModel(pare
 	updateTimelines ();
 }
 
-// -----------------------------------------------------------------------------
-
-TimelineModel * TimelineListModel::getAt(const int& index){
-	return mTimelines[index].get();
+TimelineListModel::TimelineListModel(const TimelineListModel* model){
+	mSelectedCount = model->mSelectedCount;
+	CoreHandlers* coreHandlers= CoreManager::getInstance()->getHandlers().get();
+	connect(coreHandlers, &CoreHandlers::chatRoomRead, this, &TimelineListModel::onChatRoomRead);
+	connect(coreHandlers, &CoreHandlers::chatRoomStateChanged, this, &TimelineListModel::onChatRoomStateChanged);
+	connect(coreHandlers, &CoreHandlers::messagesReceived, this, &TimelineListModel::update);
+	connect(coreHandlers, &CoreHandlers::messagesReceived, this, &TimelineListModel::updated);
+	
+	QObject::connect(coreHandlers, &CoreHandlers::callStateChanged, this, &TimelineListModel::onCallStateChanged);
+	QObject::connect(coreHandlers, &CoreHandlers::callCreated, this, &TimelineListModel::onCallCreated);
+	
+	connect(CoreManager::getInstance()->getSettingsModel(), &SettingsModel::hideEmptyChatRoomsChanged, this, &TimelineListModel::update);
+	connect(CoreManager::getInstance()->getAccountSettingsModel(), &AccountSettingsModel::defaultRegistrationChanged, this, &TimelineListModel::update);
+	for(auto item : model->mList) {
+		auto newItem = qobject_cast<TimelineModel*>(item)->clone();
+		connect(newItem.get(), SIGNAL(selectedChanged(bool)), this, SLOT(onSelectedHasChanged(bool)));
+		connect(newItem.get(), &TimelineModel::chatRoomDeleted, this, &TimelineListModel::onChatRoomDeleted);
+		mList << newItem;
+	}
 }
 
+TimelineListModel::~TimelineListModel(){
+}
+
+TimelineListModel* TimelineListModel::clone() const{
+	return new TimelineListModel(this);
+}
+// -----------------------------------------------------------------------------
+
 void TimelineListModel::reset(){
 	updateTimelines ();
 }
@@ -68,62 +92,35 @@ void TimelineListModel::update(){
 }
 
 void TimelineListModel::selectAll(const bool& selected){
-	for(auto it = mTimelines.begin() ; it != mTimelines.end() ; ++it)
-		(*it)->setSelected(selected);
-}
-int TimelineListModel::rowCount (const QModelIndex &) const {
-	return mTimelines.count();
-}
-
-QHash<int, QByteArray> TimelineListModel::roleNames () const {
-	QHash<int, QByteArray> roles;
-	roles[Qt::DisplayRole] = "$timelines";
-	return roles;
-}
-
-QVariant TimelineListModel::data (const QModelIndex &index, int role) const {
-	int row = index.row();
-	
-	if (!index.isValid() || row < 0 || row >= mTimelines.count())
-		return QVariant();
-	
-	if (role == Qt::DisplayRole)// && !mTimelines[row]->getChatRoomModel()->mDeleteChatRoom)
-		return QVariant::fromValue(mTimelines[row].get());
-	
-	return QVariant();
+	for(auto it = mList.begin() ; it != mList.end() ; ++it)
+		it->objectCast<TimelineModel>()->setSelected(selected);
 }
 
 // -----------------------------------------------------------------------------
 
-
-
-// -----------------------------------------------------------------------------
-
-bool TimelineListModel::removeRow (int row, const QModelIndex &parent) {
-	return removeRows(row, 1, parent);
-}
-
 bool TimelineListModel::removeRows (int row, int count, const QModelIndex &parent) {
-	QVector<std::shared_ptr<TimelineModel> > oldTimelines;
+	QVector<QSharedPointer<TimelineModel> > oldTimelines;
 	oldTimelines.reserve(count);
 	int limit = row + count - 1;
 	
-	if (row < 0 || count < 0 || limit >= mTimelines.count())
+	if (row < 0 || count < 0 || limit >= mList.count())
 		return false;
 	
 	beginRemoveRows(parent, row, limit);
 	
 	for (int i = 0; i < count; ++i){
-		auto timeline = mTimelines.takeAt(row);
-		timeline->getChatRoomModel()->getChatRoom()->removeListener(timeline);
+		auto timeline = mList.takeAt(row).objectCast<TimelineModel>();
+		timeline->disconnectChatRoomListener();
 		oldTimelines.push_back(timeline);
 	}
 	
 	endRemoveRows();
 	
 	for(auto timeline : oldTimelines)
-		if(timeline->mSelected)
+		if(timeline->mSelected) {
 			timeline->setSelected(false);
+				
+		}
 	emit countChanged();
 	return true;
 }
@@ -131,21 +128,19 @@ bool TimelineListModel::removeRows (int row, int count, const QModelIndex &paren
 
 // -----------------------------------------------------------------------------
 
-std::shared_ptr<TimelineModel> TimelineListModel::getTimeline(std::shared_ptr<linphone::ChatRoom> chatRoom, const bool &create){
+QSharedPointer<TimelineModel> TimelineListModel::getTimeline(std::shared_ptr<linphone::ChatRoom> chatRoom, const bool &create){
 	if(chatRoom){
-		for(auto it = mTimelines.begin() ; it != mTimelines.end() ; ++it){
-			if( (*it)->getChatRoomModel()->getChatRoom() == chatRoom){
-				return *it;
+		for(auto it = mList.begin() ; it != mList.end() ; ++it){
+			auto timeline = it->objectCast<TimelineModel>();
+			if( timeline->getChatRoomModel()->getChatRoom() == chatRoom){
+				return timeline;
 			}
 		}
 		if(create){
-			std::shared_ptr<TimelineModel> model = TimelineModel::create(chatRoom);
+			QSharedPointer<TimelineModel> model = TimelineModel::create(this, chatRoom);
 			if(model){
-			//std::shared_ptr<TimelineModel> model = std::make_shared<TimelineModel>(chatRoom);
 				connect(model.get(), SIGNAL(selectedChanged(bool)), this, SLOT(onSelectedHasChanged(bool)));
-				connect(model->getChatRoomModel(), &ChatRoomModel::allEntriesRemoved, this, &TimelineListModel::removeChatRoomModel);
 				add(model);
-			//connect(model.get(), SIGNAL(conferenceLeft()), this, SLOT(selectedHasChanged(bool)));
 				return model;
 			}
 		}
@@ -159,9 +154,9 @@ QVariantList TimelineListModel::getLastChatRooms(const int& maxCount) const{
 	QDateTime currentDateTime = QDateTime::currentDateTime();
 	bool doTest = true;
 	
-	for(auto timeline : mTimelines){
-		auto chatRoom = timeline->getChatRoomModel();
-		if(chatRoom && chatRoom->isCurrentProxy() && chatRoom->isOneToOne() && !chatRoom->haveEncryption()) {
+	for(auto timeline : mList){
+		auto chatRoom = timeline.objectCast<TimelineModel>()->getChatRoomModel();
+		if(chatRoom && chatRoom->isCurrentAccount() && chatRoom->isOneToOne() && !chatRoom->haveEncryption()) {
 			sortedData.insert(chatRoom->mLastUpdateTime.secsTo(currentDateTime),chatRoom);
 		}
 	}
@@ -181,19 +176,17 @@ QVariantList TimelineListModel::getLastChatRooms(const int& maxCount) const{
 	return contacts;
 }
 
-std::shared_ptr<ChatRoomModel> TimelineListModel::getChatRoomModel(std::shared_ptr<linphone::ChatRoom> chatRoom, const bool& create){
+QSharedPointer<ChatRoomModel> TimelineListModel::getChatRoomModel(std::shared_ptr<linphone::ChatRoom> chatRoom, const bool& create){
 	if(chatRoom ){
-		for(auto timeline : mTimelines){
-			if(timeline->mChatRoomModel->getChatRoom() == chatRoom)
-				return timeline->mChatRoomModel;
+		for(auto timeline : mList){
+			auto model = timeline.objectCast<TimelineModel>()->mChatRoomModel;
+			if(model->getChatRoom() == chatRoom)
+				return model;
 		}
 		if(create){
-			std::shared_ptr<TimelineModel> model = TimelineModel::create(chatRoom);
+			QSharedPointer<TimelineModel> model = TimelineModel::create(this, chatRoom);
 			if(model){
 				connect(model.get(), SIGNAL(selectedChanged(bool)), this, SLOT(onSelectedHasChanged(bool)));
-				connect(model->getChatRoomModel(), &ChatRoomModel::allEntriesRemoved, this, &TimelineListModel::removeChatRoomModel);
-				
-				//connect(model.get(), SIGNAL(conferenceLeft()), this, SLOT(selectedHasChanged(bool)));
 				add(model);
 				return model->mChatRoomModel;
 			}
@@ -202,18 +195,15 @@ std::shared_ptr<ChatRoomModel> TimelineListModel::getChatRoomModel(std::shared_p
 	return nullptr;
 }
 
-std::shared_ptr<ChatRoomModel> TimelineListModel::getChatRoomModel(ChatRoomModel * chatRoom){
-	for(auto timeline : mTimelines){
-		if(timeline->mChatRoomModel.get() == chatRoom)
-			return timeline->mChatRoomModel;
+QSharedPointer<ChatRoomModel> TimelineListModel::getChatRoomModel(ChatRoomModel * chatRoom){
+	for(auto timeline : mList){
+		auto model = timeline.objectCast<TimelineModel>()->mChatRoomModel;
+		if(model == chatRoom)
+			return model;
 	}
 	return nullptr;
 }
 
-int TimelineListModel::getCount() const{
-	return mTimelines.size();
-}
-
 //-------------------------------------------------------------------------------------------------
 
 void TimelineListModel::setSelectedCount(int selectedCount){
@@ -225,34 +215,56 @@ void TimelineListModel::setSelectedCount(int selectedCount){
 }
 
 void TimelineListModel::onSelectedHasChanged(bool selected){
-	if(selected) {
-		if(mSelectedCount >= 1){// We have more selection than wanted : count select first and unselect after : the final signal will be send only on limit
-			setSelectedCount(mSelectedCount+1);// It will not send a change signal
-			for(auto it = mTimelines.begin() ; it != mTimelines.end() ; ++it)
-				if(it->get() != sender())
-					(*it)->setSelected(false);
-		}else
-			setSelectedCount(mSelectedCount+1);
-		emit selectedChanged(qobject_cast<TimelineModel*>(sender()));
-	} else
-		setSelectedCount(mSelectedCount-1);
+	if( mSelectedCount == 1){//swap
+		setSelectedCount(0);
+		for(auto it = mList.begin() ; it != mList.end() ; ++it)
+			if(it->get() != sender())
+				it->objectCast<TimelineModel>()->setSelected(false);
+		if(!selected){
+			if( this ==  CoreManager::getInstance()->getTimelineListModel()) {// Clean memory only if the selection is about the main list.
+				auto timeline = qobject_cast<TimelineModel*>(sender());
+				timeline->getChatRoomModel()->resetData();// Cleanup leaving chat room
+			}
+		}else{
+			setSelectedCount(1);
+			emit selectedChanged(qobject_cast<TimelineModel*>(sender()));
+		}
+	}else if( mSelectedCount <1){//Select
+		if(selected){
+			setSelectedCount(1);
+			emit selectedChanged(qobject_cast<TimelineModel*>(sender()));
+		}
+	}else{// Do nothing
+	}
 }
 
 void TimelineListModel::updateTimelines () {
 	CoreManager *coreManager = CoreManager::getInstance();
 	std::list<std::shared_ptr<linphone::ChatRoom>> allChatRooms = coreManager->getCore()->getChatRooms();
 
-// Clean terminated chat rooms.
+// Clean terminated chat rooms and conferences from timeline.
 	allChatRooms.remove_if([](std::shared_ptr<linphone::ChatRoom> chatRoom){
-		return chatRoom->getConferenceAddress() && chatRoom->getHistoryEventsSize() == 0;
+		if( ChatRoomModel::isTerminated(chatRoom) && chatRoom->getUnreadMessagesCount() > 0)
+			chatRoom->markAsRead();
+		if(chatRoom->getState() == linphone::ChatRoom::State::Deleted)
+			return true;
+		if(!chatRoom->hasCapability((int)linphone::ChatRoomCapabilities::Basic)){
+			auto conferenceAddress = chatRoom->getConferenceAddress();
+			if( conferenceAddress && conferenceAddress->getDomain() == Constants::LinphoneDomain) {
+				QString conferenceAddressStr = Utils::coreStringToAppString(conferenceAddress->asStringUriOnly());
+				if( conferenceAddressStr.contains("conf-id"))
+					return true;
+			}
+		}
+		return false;
 	}); 
 	
 //Remove no more chat rooms
-	auto itTimeline = mTimelines.begin();
-	while(itTimeline != mTimelines.end()) {
+	auto itTimeline = mList.begin();
+	while(itTimeline != mList.end()) {
 		auto itDbTimeline = allChatRooms.begin();
 		if(*itTimeline) {
-			auto chatRoomModel = (*itTimeline)->getChatRoomModel();
+			auto chatRoomModel = itTimeline->objectCast<TimelineModel>()->getChatRoomModel();
 			if(chatRoomModel) {
 				auto timeline = chatRoomModel->getChatRoom();
 				if( timeline ) {
@@ -266,14 +278,14 @@ void TimelineListModel::updateTimelines () {
 		}else
 			itDbTimeline = allChatRooms.end();
 		if( itDbTimeline == allChatRooms.end()){
-			int index = itTimeline - mTimelines.begin();
+			int index = itTimeline - mList.begin();
 			if(index>0){
 				--itTimeline;
-				removeRow(index);
+				removeRow(index);// This will call removeRows()
 				++itTimeline;
 			}else{
-				removeRow(0);
-				itTimeline = mTimelines.begin();
+				removeRow(0);// This will call removeRows()
+				itTimeline = mList.begin();
 			}
 		}else
 			++itTimeline;
@@ -286,10 +298,9 @@ void TimelineListModel::updateTimelines () {
 		auto haveTimeline = getTimeline(dbChatRoom, false);
 		if(!haveTimeline && dbChatRoom){// Create a new Timeline if needed
 			
-			std::shared_ptr<TimelineModel> model = TimelineModel::create(dbChatRoom, callLogs);
+			QSharedPointer<TimelineModel> model = TimelineModel::create(this, dbChatRoom, callLogs);
 			if( model){
 				connect(model.get(), SIGNAL(selectedChanged(bool)), this, SLOT(onSelectedHasChanged(bool)));
-				connect(model->getChatRoomModel(), &ChatRoomModel::allEntriesRemoved, this, &TimelineListModel::removeChatRoomModel);
 				add(model);
 			}
 		}
@@ -297,32 +308,25 @@ void TimelineListModel::updateTimelines () {
 	CoreManager::getInstance()->updateUnreadMessageCount();
 }
 
-void TimelineListModel::add (std::shared_ptr<TimelineModel> timeline){
-	connect(timeline->getChatRoomModel(), &ChatRoomModel::lastUpdateTimeChanged, this, &TimelineListModel::updated);
-	int row = mTimelines.count();
-	beginInsertRows(QModelIndex(), row, row);
-	mTimelines << timeline;
-	endInsertRows();
+void TimelineListModel::add (QSharedPointer<TimelineModel> timeline){
+	auto chatRoomModel = timeline->getChatRoomModel();
+	auto chatRoom = chatRoomModel->getChatRoom();
+	connect(timeline.get(), &TimelineModel::chatRoomDeleted, this, &TimelineListModel::onChatRoomDeleted);
+	connect(chatRoomModel, &ChatRoomModel::lastUpdateTimeChanged, this, &TimelineListModel::updated);
+	ProxyListModel::add(timeline);
 	emit layoutChanged();
 	emit countChanged();
 }
 
-void TimelineListModel::remove (TimelineModel* model) {
-}
-void TimelineListModel::remove(std::shared_ptr<TimelineModel> model){
-	int index = mTimelines.indexOf(model);
-	if (index >=0){
-		removeRow(index);
-	}
-}
-void TimelineListModel::removeChatRoomModel(std::shared_ptr<ChatRoomModel> model){
+void TimelineListModel::removeChatRoomModel(QSharedPointer<ChatRoomModel> model){
 	if(!model || (model->getChatRoom()->isEmpty() && (model->isReadOnly() || !model->isGroupEnabled()))){
-		auto itTimeline = mTimelines.begin();
-		while(itTimeline != mTimelines.end()) {
-			if((*itTimeline)->mChatRoomModel == model){
+		auto itTimeline = mList.begin();
+		while(itTimeline != mList.end()) {
+			auto timeline = itTimeline->objectCast<TimelineModel>();
+			if(timeline->mChatRoomModel == model){
 				if(model)
-					model->deleteChatRoom();
-				remove(*itTimeline);
+					model->markAsToDelete();
+				remove(*itTimeline);// This will call removeRows()
 				return;
 			}else
 				++itTimeline;
@@ -334,7 +338,21 @@ void TimelineListModel::select(ChatRoomModel * chatRoomModel){
 	if(chatRoomModel) {
 		auto timeline = getTimeline(chatRoomModel->getChatRoom(), false);
 		if(timeline){
-			timeline->setSelected(true);
+			if(timeline->isUpdating())
+				timeline->delaySelected();
+			else
+				timeline->setSelected(true);
+		}
+	}
+}
+
+void TimelineListModel::onChatRoomRead(const std::shared_ptr<linphone::ChatRoom> &chatRoom){
+	auto timeline = getTimeline(chatRoom, false);
+	if(timeline) {
+		if(timeline->getChatRoomModel()){
+			timeline->getChatRoomModel()->enableMarkAsRead(true);
+			timeline->getChatRoomModel()->resetMessageCount();
+			timeline->getChatRoomModel()->enableMarkAsRead(false);
 		}
 	}
 }
@@ -342,10 +360,9 @@ void TimelineListModel::select(ChatRoomModel * chatRoomModel){
 void TimelineListModel::onChatRoomStateChanged(const std::shared_ptr<linphone::ChatRoom> &chatRoom,linphone::ChatRoom::State state){
 	if( state == linphone::ChatRoom::State::Created
 			&& !getTimeline(chatRoom, false)){// Create a new Timeline if needed
-		std::shared_ptr<TimelineModel> model = TimelineModel::create(chatRoom);
+		QSharedPointer<TimelineModel> model = TimelineModel::create(this, chatRoom);
 		if(model){
 			connect(model.get(), SIGNAL(selectedChanged(bool)), this, SLOT(onSelectedHasChanged(bool)));
-			connect(model->getChatRoomModel(), &ChatRoomModel::allEntriesRemoved, this, &TimelineListModel::removeChatRoomModel);
 			add(model);			
 		}
 	}else if(state == linphone::ChatRoom::State::Deleted || state == linphone::ChatRoom::State::Terminated){
@@ -353,7 +370,14 @@ void TimelineListModel::onChatRoomStateChanged(const std::shared_ptr<linphone::C
 		if(timeline) {
 			if(timeline->getChatRoomModel())
 				timeline->getChatRoomModel()->resetMessageCount();
-			remove(timeline);
+			if(state == linphone::ChatRoom::State::Deleted){
+				remove(timeline);// This will call removeRows()
+			}
+		}
+	}else if(state == linphone::ChatRoom::State::CreationFailed){
+		auto timeline = getTimeline(chatRoom, false);
+		if(timeline) {
+			remove(timeline);// This will call removeRows()
 		}
 	}
 }
@@ -362,11 +386,11 @@ void TimelineListModel::onCallStateChanged (const std::shared_ptr<linphone::Call
 }
 
 void TimelineListModel::onCallCreated(const std::shared_ptr<linphone::Call> &call){
-		std::shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-		std::shared_ptr<linphone::ChatRoomParams> params = core->createDefaultChatRoomParams();
-		std::list<std::shared_ptr<linphone::Address>> participants;
-		
-// Find all chat rooms with local address. If not, create one.
+	std::shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
+	std::shared_ptr<linphone::ChatRoomParams> params = core->createDefaultChatRoomParams();
+	std::list<std::shared_ptr<linphone::Address>> participants;
+	if( !call->getConference() && false ){
+	// Find all chat rooms with local address. If not, create one.
 		bool isOutgoing = (call->getDir() == linphone::Call::Dir::Outgoing) ;
 		bool found = false;
 		auto callLog = call->getCallLog();
@@ -377,8 +401,6 @@ void TimelineListModel::onCallCreated(const std::shared_ptr<linphone::Call> &cal
 		bool createSecureChatRoom = false;
 		SettingsModel * settingsModel = CoreManager::getInstance()->getSettingsModel();
 		
-		
-		
 		if( settingsModel->getSecureChatEnabled() && 
 			(!settingsModel->getStandardChatEnabled() || (settingsModel->getStandardChatEnabled() && isEncrypted))
 			){
@@ -391,7 +413,8 @@ void TimelineListModel::onCallCreated(const std::shared_ptr<linphone::Call> &cal
 											 , nullptr//callLog->getRemoteAddress()
 											 , participants);
 		if(chatRoom){
-			for(auto timeline : mTimelines){
+			for(auto item : mList){
+				auto timeline = item.objectCast<TimelineModel>();
 				if( chatRoom == timeline->mChatRoomModel->getChatRoom()){
 					found = true;
 					if(isOutgoing)// If outgoing, we switch to this chat room
@@ -407,9 +430,9 @@ void TimelineListModel::onCallCreated(const std::shared_ptr<linphone::Call> &cal
 			participants << Utils::coreStringToAppString(remoteAddress->asStringUriOnly());
 			CoreManager::getInstance()->getCallsListModel()->createChatRoom("", (createSecureChatRoom?1:0),  callLocalAddress, participants, isOutgoing);
 		}
+	}
 }
 
-/*
-void TimelineListModel::onConferenceLeft(const std::shared_ptr<linphone::ChatRoom> &chatRoom, , const std::shared_ptr<const linphone::EventLog> & eventLog){
-	remove(getTimeline(chatRoom, false).get());
-}*/
\ No newline at end of file
+void TimelineListModel::onChatRoomDeleted(){
+	remove(sender());// This will call removeRows()
+}
