@@ -37,38 +37,14 @@
 // -----------------------------------------------------------------------------
 
 TimelineProxyModel::TimelineProxyModel (QObject *parent) : QSortFilterProxyModel(parent) {
-	CoreManager *coreManager = CoreManager::getInstance();
-	AccountSettingsModel *accountSettingsModel = coreManager->getAccountSettingsModel();
-	TimelineListModel * model = CoreManager::getInstance()->getTimelineListModel();
 	
-	connect(model, SIGNAL(selectedCountChanged(int)), this, SIGNAL(selectedCountChanged(int)));
-	connect(model, &TimelineListModel::updated, this, &TimelineProxyModel::invalidate);
-	connect(model, &TimelineListModel::selectedChanged, this, &TimelineProxyModel::selectedChanged);
-	connect(model, &TimelineListModel::countChanged, this, &TimelineProxyModel::countChanged);
-
-	QObject::connect(accountSettingsModel, &AccountSettingsModel::defaultProxyChanged, this, [this]() {
-		dynamic_cast<TimelineListModel*>(sourceModel())->update();
-		invalidate();
-		//updateCurrentSelection();
-	});
-	QObject::connect(coreManager->getSipAddressesModel(), &SipAddressesModel::sipAddressReset, this, [this]() {
-		dynamic_cast<TimelineListModel*>(sourceModel())->reset();
-		invalidate();// Invalidate and reload GUI if the model has been reset
-		//updateCurrentSelection();
-	});
-
-	setSourceModel(model);
-	sort(0);
 }
 
 // -----------------------------------------------------------------------------
 
-int TimelineProxyModel::getCount() const{
-	return dynamic_cast<TimelineListModel*>(sourceModel())->getCount();
-}
-
 void TimelineProxyModel::unselectAll(){
-	dynamic_cast<TimelineListModel*>(sourceModel())->selectAll(false);
+	if( sourceModel())
+		qobject_cast<TimelineListModel*>(sourceModel())->selectAll(false);
 }
 
 void TimelineProxyModel::setFilterFlags(const int& filterFlags){
@@ -85,12 +61,52 @@ void TimelineProxyModel::setFilterText(const QString& text){
 		emit filterTextChanged();
 	}
 }
+	
+TimelineProxyModel::TimelineListSource TimelineProxyModel::getListSource() const{
+	return mListSource;
+}
+
+void TimelineProxyModel::setListSource(const TimelineListSource& source){
+	if(source != mListSource) {
+		TimelineListModel * model = nullptr;
+		if( source != Undefined){
+			CoreManager *coreManager = CoreManager::getInstance();
+			AccountSettingsModel *accountSettingsModel = coreManager->getAccountSettingsModel();
+			model = source == Main ? CoreManager::getInstance()->getTimelineListModel() : CoreManager::getInstance()->getTimelineListModel()->clone();
+		
+			connect(model, SIGNAL(selectedCountChanged(int)), this, SIGNAL(selectedCountChanged(int)));
+			connect(model, &TimelineListModel::updated, this, &TimelineProxyModel::invalidate);
+			connect(model, &TimelineListModel::selectedChanged, this, &TimelineProxyModel::selectedChanged);
+			connect(model, &TimelineListModel::countChanged, this, &TimelineProxyModel::countChanged);
+		
+			QObject::connect(accountSettingsModel, &AccountSettingsModel::defaultAccountChanged, this, [this]() {
+				qobject_cast<TimelineListModel*>(sourceModel())->update();
+				invalidate();
+			});
+			QObject::connect(coreManager->getSipAddressesModel(), &SipAddressesModel::sipAddressReset, this, [this]() {
+				qobject_cast<TimelineListModel*>(sourceModel())->reset();
+				invalidate();// Invalidate and reload GUI if the model has been reset
+			});
+		}
+	
+		if( mListSource != Main && sourceModel()){
+			sourceModel()->deleteLater();
+		}
+		setSourceModel(model);
+		sort(0);
+		mListSource = source;
+		emit listSourceChanged();
+	}
+}
+	
 // -----------------------------------------------------------------------------
 
 bool TimelineProxyModel::filterAcceptsRow (int sourceRow, const QModelIndex &sourceParent) const {
+	if(!sourceModel())
+		return false;
 	const QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
 	auto timeline = sourceModel()->data(index).value<TimelineModel*>();
-	if(!timeline || !timeline->getChatRoomModel() || timeline->getChatRoomModel()->getState() == (int)linphone::ChatRoom::State::Terminated)
+	if(!timeline || !timeline->getChatRoomModel() || timeline->getChatRoomModel()->getState() == (int)linphone::ChatRoom::State::Deleted)
 		return false;
 	bool haveEncryption = timeline->getChatRoomModel()->haveEncryption();
 	if(!CoreManager::getInstance()->getSettingsModel()->getStandardChatEnabled() && !haveEncryption)
@@ -117,11 +133,13 @@ bool TimelineProxyModel::filterAcceptsRow (int sourceRow, const QModelIndex &sou
 			//|| timeline->getChatRoomModel()->getFullPeerAddress().contains(search); not enough significant?
 	}
 	if(show)
-		show = timeline->getChatRoomModel()->isCurrentProxy();
+		show = timeline->getChatRoomModel()->isCurrentAccount();
 	return show;
 }
 
 bool TimelineProxyModel::lessThan (const QModelIndex &left, const QModelIndex &right) const {
+	if( !sourceModel())
+		return false;
 	const TimelineModel* a = sourceModel()->data(left).value<TimelineModel*>();
 	const TimelineModel* b = sourceModel()->data(right).value<TimelineModel*>();
 	bool aHaveUnread = a->getChatRoomModel()->getAllUnreadCount() > 0;
