@@ -45,18 +45,27 @@ public:
 	};
 	Q_ENUM(TimelineFilter)
 	
+	enum TimelineListSource{
+		Undefined, 
+		Main,	// Timeline list comes from the singleton stored in CoreManager.
+		Copy	// Timeline list is created from Main but have no attach to the main list (aside of root items).
+	};
+	Q_ENUM(TimelineListSource)
+	
 	TimelineProxyModel (QObject *parent = Q_NULLPTR);
 	
+	Q_PROPERTY(TimelineListSource listSource READ getListSource WRITE setListSource NOTIFY listSourceChanged)
+	
 	Q_PROPERTY(int filterFlags MEMBER mFilterFlags WRITE setFilterFlags NOTIFY filterFlagsChanged)
 	Q_PROPERTY(QString filterText MEMBER mFilterText WRITE setFilterText NOTIFY filterTextChanged)
-	Q_PROPERTY(int count READ getCount NOTIFY countChanged)
+	Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
 		
-	int getCount() const;
-	
 	Q_INVOKABLE void unselectAll();
 	Q_INVOKABLE void setFilterFlags(const int& filterFlags);
 	Q_INVOKABLE void setFilterText(const QString& text);
-	//Q_INVOKABLE TimelineModel * getTimeline();
+	
+	TimelineListSource getListSource() const;
+	void setListSource(const TimelineListSource& source);
 	
 signals:
 	void countChanged();
@@ -64,6 +73,7 @@ signals:
 	void selectedChanged(TimelineModel * timelineModel);
 	void filterFlagsChanged();
 	void filterTextChanged();
+	void listSourceChanged();
 	
 protected:
 	
@@ -77,9 +87,7 @@ protected:
 private:
 	int mFilterFlags = 0;
 	QString mFilterText;
-	
-	//std::shared_ptr<ChatRoomModel> mCurrentChatRoomModel;
-	
+	TimelineListSource mListSource = Undefined;
 };
 
 #endif // TIMELINE_PROXY_MODEL_H_
