@@ -27,6 +27,7 @@ constexpr char Constants::DefaultFont[];
 constexpr char Constants::QtDomain[];
 constexpr size_t Constants::MaxLogsCollectionSize;
 constexpr char Constants::SrcPattern[];
+constexpr char Constants::LinphoneLocaleEncoding[];
 
 constexpr char Constants::PathAssistantConfig[];
 constexpr char Constants::PathAvatars[];
@@ -64,8 +65,11 @@ constexpr int Constants::ThumbnailImageFileHeight;
 constexpr qint64 Constants::FileSizeLimit;
 
 constexpr char Constants::DefaultXmlrpcUri[];
+constexpr char Constants::DefaultUploadLogsServer[];
 constexpr char Constants::DefaultConferenceURI[];
+constexpr char Constants::DefaultVideoConferenceURI[];
 constexpr char Constants::DefaultLimeServerURL[];
+constexpr char Constants::DefaultFlexiAPIURL[];
 constexpr char Constants::RemoteProvisioningURL[];
 constexpr char Constants::DefaultAssistantRegistrationUrl[];
 constexpr char Constants::DefaultAssistantLoginUrl[];
@@ -80,16 +84,20 @@ constexpr char Constants::LibraryExtension[];
 constexpr char Constants::H264InstallName[];
 #ifdef Q_PROCESSOR_X86_64
 constexpr char Constants::PluginUrlH264[];
+constexpr char Constants::PluginH264Check[];
 #else
 constexpr char Constants::PluginUrlH264[];
+constexpr char Constants::PluginH264Check[];
 #endif // ifdef Q_PROCESSOR_X86_64
 #elif defined(Q_OS_WIN)
 constexpr char Constants::LibraryExtension[];
 constexpr char Constants::H264InstallName[];
 #ifdef Q_OS_WIN64
 constexpr char Constants::PluginUrlH264[];
+constexpr char Constants::PluginH264Check[];
 #else
 constexpr char Constants::PluginUrlH264[];
+constexpr char Constants::PluginH264Check[];
 #endif // ifdef Q_OS_WIN64
 #endif // ifdef Q_OS_LINUX
 constexpr char Constants::VcardScheme[];
@@ -113,6 +121,7 @@ constexpr char Constants::PrivatePolicyUrl[];
 constexpr char Constants::ContactUrl[];
 constexpr char Constants::TranslationUrl[];
 
+constexpr int Constants::MaxMosaicParticipants;
 
 constexpr char Constants::LinphoneBZip2_exe[];
 constexpr char Constants::LinphoneBZip2_dll[];
