@@ -36,21 +36,17 @@ public:
 	
 	//----------------------------------------------------------------------------------	
 	
-	static constexpr char WindowIconPath[] = ":/assets/images/linphone_logo.svg";
 	static constexpr char DefaultLocale[] = "en";
-		
-	static constexpr char ApplicationMinimalQtVersion[] = "5.10.0";
 	static constexpr char DefaultFont[] = "Noto Sans";
 	
 	static constexpr size_t MaxLogsCollectionSize = 10485760*5; // 50MB.
 	
-	
 #ifdef ENABLE_UPDATE_CHECK
 	static constexpr int VersionUpdateCheckInterval = 86400000; // 24 hours in milliseconds.
 #endif // ifdef ENABLE_UPDATE_CHECK
 	
 	static constexpr char DefaultXmlrpcUri[] = "https://subscribe.linphone.org:444/wizard.php";
-	static constexpr char LinphoneDomain[] = "sip.linphone.org";
+	static constexpr char DefaultUploadLogsServer[] = "https://www.linphone.org:444/lft.php";
 	static constexpr char DefaultContactParameters[] = "message-expires=604800";
 	static constexpr char DefaultContactParametersOnRemove[] = "message-expires=0";
 	static constexpr int DefaultExpires = 3600;
@@ -63,32 +59,46 @@ public:
 	static constexpr char ContactUrl[] = "https://www.linphone.org/contact";
 	static constexpr char TranslationUrl[] = "https://weblate.linphone.org/projects/linphone-desktop/";
 	
-	
+	static constexpr int MaxMosaicParticipants = 6;// From 7, the mosaic quality will be limited to avoid useless computations
 	
 	static constexpr char LinphoneBZip2_exe[] = "https://www.linphone.org/releases/windows/tools/bzip2/bzip2.exe";
 	static constexpr char LinphoneBZip2_dll[] = "https://www.linphone.org/releases/windows/tools/bzip2/bzip2.dll";
 	static constexpr char DefaultRlsUri[] = "sips:rls@sip.linphone.org";
 	static constexpr char DefaultLogsEmail[] = "linphone-desktop@belledonne-communications.com";
-	static constexpr char DefaultConferenceURI[] = "sip:conference-factory@sip.linphone.org";
-	static constexpr char DefaultLimeServerURL[] = "https://lime.linphone.org/lime-server/lime-server.php";
-	static constexpr char RemoteProvisioningURL[] = "https://subscribe.linphone.org/flexiapi/provisioning";
-		
+	
+	static constexpr char DefaultFlexiAPIURL[] = "http://fs-test-sandbox.linphone.org/flexiapi/api/";// Need "/" at the end
+	static constexpr char RemoteProvisioningURL[] = "http://fs-test-sandbox.linphone.org/flexiapi/provisioning";
+	
 	Q_PROPERTY(QString PasswordRecoveryUrl MEMBER PasswordRecoveryUrl CONSTANT)
 	Q_PROPERTY(QString CguUrl MEMBER CguUrl CONSTANT)
 	Q_PROPERTY(QString PrivatePolicyUrl MEMBER PrivatePolicyUrl CONSTANT)
 	Q_PROPERTY(QString ContactUrl MEMBER ContactUrl CONSTANT)
 	Q_PROPERTY(QString TranslationUrl MEMBER TranslationUrl CONSTANT)
-	
+	Q_PROPERTY(int maxMosaicParticipants MEMBER MaxMosaicParticipants CONSTANT)
+
+// For Webviews
 	static constexpr char DefaultAssistantRegistrationUrl[] = "https://subscribe.linphone.org/register";
 	static constexpr char DefaultAssistantLoginUrl[] = "https://subscribe.linphone.org/login";
 	static constexpr char DefaultAssistantLogoutUrl[] = "https://subscribe.linphone.org/logout";
-	
+//--------------
+
 	// Max image size in bytes. (100Kb)
 	static constexpr qint64 MaxImageSize = 102400;// In Bytes.
 	static constexpr qint64 FileSizeLimit = 524288000;// In Bytes.
 	static constexpr int ThumbnailImageFileWidth = 100;
 	static constexpr int ThumbnailImageFileHeight = 100;
+	
+//--------------------------------------------------------------------------------
+//								LINPHONE
+//--------------------------------------------------------------------------------
 
+	static constexpr char LinphoneDomain[] = "sip.linphone.org";	// Use for checking if config are a Linphone
+	static constexpr char WindowIconPath[] = ":/assets/images/linphone_logo.svg";
+	static constexpr char ApplicationMinimalQtVersion[] = "5.10.0";
+	static constexpr char DefaultConferenceURI[] = "sip:conference-factory@sip.linphone.org";	// Default for a Linphone account
+	static constexpr char DefaultVideoConferenceURI[] = "sip:videoconference-factory@sip.linphone.org";	// Default for a Linphone account
+	static constexpr char DefaultLimeServerURL[] = "https://lime.linphone.org/lime-server/lime-server.php";	// Default for a Linphone account
+	
 	static constexpr char PathAssistantConfig[] = "/" EXECUTABLE_NAME "/assistant/";
 	static constexpr char PathAvatars[] = "/avatars/";
 	static constexpr char PathCaptures[] = "/" EXECUTABLE_NAME "/captures/";
@@ -132,13 +142,14 @@ public:
 	
 	static constexpr char QtDomain[] = "qt";
 	static constexpr char SrcPattern[] = "/src/";
-	
+	static constexpr char LinphoneLocaleEncoding[] = "UTF-8";// Alternative is to use "locale"
 	static constexpr char VcardScheme[] = EXECUTABLE_NAME "-desktop:/";
 	static constexpr int CbsCallInterval = 20;
 	static constexpr char RcVersionName[] = "rc_version";
-	static constexpr int RcVersionCurrent = 3;	// 2 = Conference URI
+	static constexpr int RcVersionCurrent = 5;	// 2 = Conference URI
 												// 3 = CPIM on basic chat rooms
-	
+												// 4 = RTP bundle mode
+												// 5 = Video Conference URI
 //--------------------------------------------------------------------------------	
 //								CISCO
 //--------------------------------------------------------------------------------
@@ -150,17 +161,21 @@ public:
 	static constexpr char LibraryExtension[] = "so";
 	static constexpr char H264InstallName[] = "libopenh264.so";
 #ifdef Q_PROCESSOR_X86_64
-	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/libopenh264-2.1.0-linux64.5.so.bz2";
+	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/libopenh264-2.2.0-linux64.6.so.bz2";
+	static constexpr char PluginH264Check[] = "45ba1aaeb6213c19cd9622b79788e16b05beabc4d16a3a74e57f046a0826fd77";
 #else
-	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/libopenh264-2.1.0-linux32.5.so.bz2";
+	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/libopenh264-2.2.0-linux32.6.so.bz2";
+	static constexpr char PluginH264Check[] = "bf18e0e79c4a23018b0ea5ad6d7dd14fd1b6a6189d2f88fd56dece019fc415c8";
 #endif // ifdef Q_PROCESSOR_X86_64
 #elif defined(Q_OS_WIN)
 	static constexpr char LibraryExtension[] = "dll";
 	static constexpr char H264InstallName[] = "openh264.dll";
 #ifdef Q_OS_WIN64
-	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/openh264-2.1.0-win64.dll.bz2";
+	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/openh264-2.2.0-win64.dll.bz2";
+	static constexpr char PluginH264Check[] = "799e08c418b6cdeadfbe18d027392158face4a5c901d41f83712a20f0d41ad7d";
 #else
-	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/openh264-2.1.0-win32.dll.bz2";
+	static constexpr char PluginUrlH264[] = "http://ciscobinary.openh264.org/openh264-2.2.0-win32.dll.bz2";
+	static constexpr char PluginH264Check[] = "2205097a3a309271e15879b25a905eb290cfdd7fd7a8a0c1037e0458e5dc1f21";
 #endif // ifdef Q_OS_WIN64
 #endif // ifdef Q_OS_LINUX
 
