@@ -60,8 +60,8 @@ enum EventLogType {
 	EventLogTypeNone = int(linphone::EventLog::Type::None),
 	EventLogTypeConferenceCreated = int(linphone::EventLog::Type::ConferenceCreated),
 	EventLogTypeConferenceTerminated = int(linphone::EventLog::Type::ConferenceTerminated),
-	EventLogTypeConferenceCallStart = int(linphone::EventLog::Type::ConferenceCallStart),
-	EventLogTypeConferenceCallEnd = int(linphone::EventLog::Type::ConferenceCallEnd),
+	EventLogTypeConferenceCallStarted = int(linphone::EventLog::Type::ConferenceCallStarted),
+	EventLogTypeConferenceCallEnded = int(linphone::EventLog::Type::ConferenceCallEnded),
 	EventLogTypeConferenceChatMessage = int(linphone::EventLog::Type::ConferenceChatMessage),
 	EventLogTypeConferenceParticipantAdded = int(linphone::EventLog::Type::ConferenceParticipantAdded),
 	EventLogTypeConferenceParticipantRemoved = int(linphone::EventLog::Type::ConferenceParticipantRemoved),
@@ -69,7 +69,7 @@ enum EventLogType {
 	EventLogTypeConferenceParticipantUnsetAdmin = int(linphone::EventLog::Type::ConferenceParticipantUnsetAdmin),
 	EventLogTypeConferenceParticipantDeviceAdded = int(linphone::EventLog::Type::ConferenceParticipantDeviceAdded),
 	EventLogTypeConferenceParticipantDeviceRemoved = int(linphone::EventLog::Type::ConferenceParticipantDeviceRemoved),
-	EventLogTypeConferenceParticipantDeviceMediaChanged = int(linphone::EventLog::Type::ConferenceParticipantDeviceMediaChanged),
+	EventLogTypeConferenceParticipantDeviceMediaAvailabilityChanged = int(linphone::EventLog::Type::ConferenceParticipantDeviceMediaAvailabilityChanged),
 	EventLogTypeConferenceSubjectChanged= int(linphone::EventLog::Type::ConferenceSubjectChanged),
 	EventLogTypeConferenceAvailableMediaChanged = int(linphone::EventLog::Type::ConferenceAvailableMediaChanged),
 	EventLogTypeConferenceSecurityEvent = int(linphone::EventLog::Type::ConferenceSecurityEvent),
@@ -95,8 +95,25 @@ enum ChatMessageState {
 };
 Q_ENUM_NS(ChatMessageState)
 
-linphone::ChatMessage::State toLinphone(const LinphoneEnums::ChatMessageState& capability);
-LinphoneEnums::ChatMessageState fromLinphone(const linphone::ChatMessage::State& capability);
+linphone::ChatMessage::State toLinphone(const LinphoneEnums::ChatMessageState& data);
+LinphoneEnums::ChatMessageState fromLinphone(const linphone::ChatMessage::State& data);
+
+enum ChatRoomState {
+	ChatRoomStateNone = int(linphone::ChatRoom::State::None),
+	ChatRoomStateInstantiated = int(linphone::ChatRoom::State::Instantiated),
+	ChatRoomStateCreationPending = int(linphone::ChatRoom::State::CreationPending),
+	ChatRoomStateCreated = int(linphone::ChatRoom::State::Created),
+	ChatRoomStateCreationFailed = int(linphone::ChatRoom::State::CreationFailed),
+	ChatRoomStateTerminationPending = int(linphone::ChatRoom::State::TerminationPending),
+	ChatRoomStateTerminated = int(linphone::ChatRoom::State::Terminated),
+	ChatRoomStateTerminationFailed = int(linphone::ChatRoom::State::TerminationFailed),
+	ChatRoomStateDeleted = int(linphone::ChatRoom::State::Deleted),
+};
+Q_ENUM_NS(ChatRoomState)
+
+linphone::ChatRoom::State toLinphone(const LinphoneEnums::ChatRoomState& data);
+LinphoneEnums::ChatRoomState fromLinphone(const linphone::ChatRoom::State& data);
+
 
 enum CallStatus {
 		CallStatusDeclined = int(linphone::Call::Status::Declined),
@@ -112,6 +129,59 @@ Q_ENUM_NS(CallStatus)
 linphone::Call::Status toLinphone(const LinphoneEnums::CallStatus& capability);
 LinphoneEnums::CallStatus fromLinphone(const linphone::Call::Status& capability);
 
+enum ConferenceLayout {
+	ConferenceLayoutGrid = int(linphone::ConferenceLayout::Grid),
+	ConferenceLayoutActiveSpeaker = int(linphone::ConferenceLayout::ActiveSpeaker),
+	ConferenceLayoutAudioOnly = ConferenceLayoutGrid + ConferenceLayoutActiveSpeaker + 1,
+};
+Q_ENUM_NS(ConferenceLayout)
+
+linphone::ConferenceLayout toLinphone(const LinphoneEnums::ConferenceLayout& layout);
+LinphoneEnums::ConferenceLayout fromLinphone(const linphone::ConferenceLayout& layout);
+
+
+enum ConferenceInfoState {
+	ConferenceInfoStateNew = int(linphone::ConferenceInfo::State::New),
+	ConferenceInfoStateUpdated = int(linphone::ConferenceInfo::State::Updated),
+	ConferenceInfoStateCancelled = int(linphone::ConferenceInfo::State::Cancelled)
+};
+Q_ENUM_NS(ConferenceInfoState)
+
+linphone::ConferenceInfo::State toLinphone(const LinphoneEnums::ConferenceInfoState& state);
+LinphoneEnums::ConferenceInfoState fromLinphone(const linphone::ConferenceInfo::State& state);
+
+enum ConferenceSchedulerState {
+	ConferenceSchedulerStateAllocationPending = int(linphone::ConferenceScheduler::State::AllocationPending),
+	ConferenceSchedulerStateError = int(linphone::ConferenceScheduler::State::Error),
+	ConferenceSchedulerStateIdle = int(linphone::ConferenceScheduler::State::Idle),
+	ConferenceSchedulerStateReady = int(linphone::ConferenceScheduler::State::Ready),
+	ConferenceSchedulerStateUpdating = int(linphone::ConferenceScheduler::State::Updating)
+};
+Q_ENUM_NS(ConferenceSchedulerState)
+
+linphone::ConferenceScheduler::State toLinphone(const LinphoneEnums::ConferenceSchedulerState& state);
+LinphoneEnums::ConferenceSchedulerState fromLinphone(const linphone::ConferenceScheduler::State& state);
+
+
+enum ParticipantDeviceState {
+	ParticipantDeviceStateJoining = int(linphone::ParticipantDeviceState::Joining),
+	ParticipantDeviceStatePresent = int(linphone::ParticipantDeviceState::Present),
+	ParticipantDeviceStateLeaving = int(linphone::ParticipantDeviceState::Leaving),
+	ParticipantDeviceStateLeft = int(linphone::ParticipantDeviceState::Left),
+	ParticipantDeviceStateScheduledForJoining = int(linphone::ParticipantDeviceState::ScheduledForJoining),
+	ParticipantDeviceStateScheduledForLeaving = int(linphone::ParticipantDeviceState::ScheduledForLeaving),
+	ParticipantDeviceStateOnHold = int(linphone::ParticipantDeviceState::OnHold),
+	ParticipantDeviceStateAlerting = int(linphone::ParticipantDeviceState::Alerting),
+	ParticipantDeviceStateMutedByFocus = int(linphone::ParticipantDeviceState::MutedByFocus),
+	
+};
+Q_ENUM_NS(ParticipantDeviceState)
+
+linphone::ParticipantDeviceState toLinphone(const LinphoneEnums::ParticipantDeviceState& state);
+LinphoneEnums::ParticipantDeviceState fromLinphone(const linphone::ParticipantDeviceState& state);
+
+
+
 enum TunnelMode {
 		TunnelModeDisable = int(linphone::Tunnel::Mode::Disable),
 		TunnelModeEnable= int(linphone::Tunnel::Mode::Enable),
@@ -131,14 +201,34 @@ Q_ENUM_NS(RecorderState)
 
 linphone::RecorderState toLinphone(const LinphoneEnums::RecorderState& state);
 LinphoneEnums::RecorderState fromLinphone(const linphone::RecorderState& state);
+
+enum TransportType{
+		TransportTypeDtls = int(linphone::TransportType::Dtls),
+		TransportTypeTcp = int(linphone::TransportType::Tcp),
+		TransportTypeTls = int(linphone::TransportType::Tls),
+		TransportTypeUdp = int(linphone::TransportType::Udp)
+};
+Q_ENUM_NS(TransportType)
+
+linphone::TransportType toLinphone(const LinphoneEnums::TransportType& type);
+LinphoneEnums::TransportType fromLinphone(const linphone::TransportType& type);
+QString toString(const LinphoneEnums::TransportType& type);
+void fromString(const QString& transportType, LinphoneEnums::TransportType *transport);
 }
 
-Q_DECLARE_METATYPE(LinphoneEnums::MediaEncryption)
-Q_DECLARE_METATYPE(LinphoneEnums::FriendCapability)
-Q_DECLARE_METATYPE(LinphoneEnums::EventLogType)
-Q_DECLARE_METATYPE(LinphoneEnums::ChatMessageState)
+
 Q_DECLARE_METATYPE(LinphoneEnums::CallStatus)
-Q_DECLARE_METATYPE(LinphoneEnums::TunnelMode)
+Q_DECLARE_METATYPE(LinphoneEnums::ChatMessageState)
+Q_DECLARE_METATYPE(LinphoneEnums::ChatRoomState)
+Q_DECLARE_METATYPE(LinphoneEnums::ConferenceLayout)
+Q_DECLARE_METATYPE(LinphoneEnums::ConferenceInfoState)
+Q_DECLARE_METATYPE(LinphoneEnums::ConferenceSchedulerState)
+Q_DECLARE_METATYPE(LinphoneEnums::EventLogType)
+Q_DECLARE_METATYPE(LinphoneEnums::FriendCapability)
+Q_DECLARE_METATYPE(LinphoneEnums::MediaEncryption)
+Q_DECLARE_METATYPE(LinphoneEnums::ParticipantDeviceState)
 Q_DECLARE_METATYPE(LinphoneEnums::RecorderState)
+Q_DECLARE_METATYPE(LinphoneEnums::TunnelMode)
+Q_DECLARE_METATYPE(LinphoneEnums::TransportType)
 
 #endif
