@@ -20,20 +20,30 @@
 
 #include <QFileInfo>
 #include <QCoreApplication>
+#include <QCryptographicHash>
+#include <QCursor>
 #include <QDir>
 #include <QFile>
 #include <QImageReader>
 #include <QDebug>
+#include <QTimeZone>
+#include <QUrl>
 
 #include "config.h"
 #include "Utils.hpp"
+#include "UriTools.hpp"
 #include "components/core/CoreManager.hpp"
 #include "components/contacts/ContactsListModel.hpp"
 #include "components/contact/ContactModel.hpp"
 #include "components/contact/VcardModel.hpp"
+#include "components/settings/AccountSettingsModel.hpp"
 #include "components/settings/SettingsModel.hpp"
 #include "app/paths/Paths.hpp"
 
+#ifdef _WIN32
+#include <time.h>
+#endif
+
 // =============================================================================
 
 namespace {
@@ -41,19 +51,16 @@ constexpr int SafeFilePathLimit = 100;
 
 }
 
-linphone::TransportType Utils::stringToTransportType (const QString &transport) {
-	if (transport == QLatin1String("TCP"))
-		return linphone::TransportType::Tcp;
-	if (transport == QLatin1String("UDP"))
-		return linphone::TransportType::Udp;
-	if (transport == QLatin1String("TLS"))
-		return linphone::TransportType::Tls;
-	
-	return linphone::TransportType::Dtls;
-}
-
 std::shared_ptr<linphone::Address> Utils::interpretUrl(const QString& address){
-	return CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(address));
+	auto interpretedAddress = CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(address), true);
+	if(!interpretedAddress){// Try by removing scheme.
+		QStringList splitted = address.split(":");
+		if(splitted.size() > 0 && splitted[0] == "sip"){
+			splitted.removeFirst();
+			interpretedAddress = CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(splitted.join(":")), true);
+		}
+	}
+	return interpretedAddress;
 }
 char *Utils::rstrstr (const char *a, const char *b) {
 	size_t a_len = strlen(a);
@@ -81,19 +88,33 @@ bool Utils::hasCapability(const QString& address, const LinphoneEnums::FriendCap
 		return false;
 }
 
+QDateTime Utils::addMinutes(QDateTime date, const int& min){
+	return date.addSecs(min*60);
+}
+
+QDateTime Utils::getOffsettedUTC(const QDateTime& date){
+	QDateTime utc = date.toUTC();// Get a date free of any offsets.
+	auto timezone = date.timeZone();
+	utc = utc.addSecs(timezone.offsetFromUtc(date));// add offset from date timezone
+	utc.setTimeSpec(Qt::UTC);// ensure to have an UTC date
+	return utc;
+}
+
 QString Utils::toDateTimeString(QDateTime date){
 	if(date.date() == QDate::currentDate())
 		return toTimeString(date);
-	else
-		return date.toString("yyyy/MM/dd hh:mm:ss");
+	else{
+		return getOffsettedUTC(date).toString("yyyy/MM/dd hh:mm:ss");
+	}
 }
 
-QString Utils::toTimeString(QDateTime date){
-	return date.toString("hh:mm:ss");
+QString Utils::toTimeString(QDateTime date, const QString& format){
+// Issue : date.toString() will not print the good time in timezones. Get it from date and add ourself the offset.
+	return getOffsettedUTC(date).toString(format);
 }
 
 QString Utils::toDateString(QDateTime date){
-	return date.toString("yyyy/MM/dd");
+	return getOffsettedUTC(date).toString("yyyy/MM/dd");
 }
 
 QString Utils::getDisplayName(const QString& address){
@@ -118,14 +139,12 @@ QString Utils::toString(const LinphoneEnums::TunnelMode& mode){
 
 QImage Utils::getImage(const QString &pUri) {
 	QImage image(pUri);
+	QImageReader reader(pUri);
+	reader.setAutoTransform(true);
 	if(image.isNull()){// Try to determine format from headers instead of using suffix
-		QImageReader reader(pUri);
 		reader.setDecideFormatFromContent(true);
-		QByteArray format = reader.format();
-		if(!format.isEmpty())
-			image = QImage(pUri, format);
 	}
-	return image;
+	return reader.read();
 }
 QString Utils::getSafeFilePath (const QString &filePath, bool *soFarSoGood) {
 	if (soFarSoGood)
@@ -151,11 +170,11 @@ QString Utils::getSafeFilePath (const QString &filePath, bool *soFarSoGood) {
 }
 std::shared_ptr<linphone::Address> Utils::getMatchingLocalAddress(std::shared_ptr<linphone::Address> p_localAddress){
 	QVector<std::shared_ptr<linphone::Address> > addresses;
-	// Get default proxy
+	// Get default account
 	addresses.push_back(CoreManager::getInstance()->getCore()->createPrimaryContactParsed());
-	auto proxyList = CoreManager::getInstance()->getCore()->getProxyConfigList();
-	foreach(auto proxy, proxyList)
-		addresses.push_back(proxy->getIdentityAddress()->clone());
+	auto accounts = CoreManager::getInstance()->getAccountList();
+	foreach(auto account, accounts)
+		addresses.push_back(account->getParams()->getIdentityAddress()->clone());
 	foreach(auto address, addresses){
 		if( address->getUsername() == p_localAddress->getUsername() && address->getDomain() == p_localAddress->getDomain())
 			return address;
@@ -491,7 +510,7 @@ QString Utils::getDisplayName(const std::shared_ptr<const linphone::Address>& ad
 		std::shared_ptr<linphone::Address> cleanAddress = address->clone();
 		cleanAddress->clean();
 		QString qtAddress = Utils::coreStringToAppString(cleanAddress->asStringUriOnly());
-		ContactModel * model = CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(qtAddress);
+		auto model = CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(qtAddress);
 		if(model && model->getVcardModel())
 			displayName = model->getVcardModel()->getUsername();
 		else{
@@ -529,4 +548,103 @@ QString Utils::computeUserAgent(const std::shared_ptr<linphone::Config>& config)
 					.arg(SettingsModel::getDeviceName(config))
 					.arg(QSysInfo::prettyProductName())
 					.arg(qVersion());
+}
+
+bool Utils::isMe(const QString& address){
+	return !address.isEmpty() ? CoreManager::getInstance()->getAccountSettingsModel()->getUsedSipAddress()->weakEqual(Utils::interpretUrl(address)) : false;
+}
+
+bool Utils::isMe(const std::shared_ptr<const linphone::Address>& address){
+	return address ? CoreManager::getInstance()->getAccountSettingsModel()->getUsedSipAddress()->weakEqual(address) : false;
+}
+
+bool Utils::isAnimatedImage(const QString& path){
+	QFileInfo info(path);
+	if( !info.exists())
+		return false;
+	QImageReader reader(path);
+	return reader.supportsAnimation() && reader.imageCount() > 1;
+}
+
+bool Utils::isPhoneNumber(const QString& txt){
+	auto core = CoreManager::getInstance()->getCore();
+	if(!core)
+		return false;
+	auto account = core->getDefaultAccount();
+	return account && account->isPhoneNumber(Utils::appStringToCoreString(txt));
+}
+
+QSize Utils::getImageSize(const QString& url){
+	QString path;
+	QUrl urlDecode(url);
+	if(urlDecode.isLocalFile())
+		path = QDir::toNativeSeparators(urlDecode.toLocalFile());
+	else
+		path = url;
+	QFileInfo info(path);
+	if( !info.exists())
+		return QSize(0,0);
+	QImageReader reader(path);
+	QSize s = reader.size();
+	if( s.isValid())
+		return s;
+	else
+		return QSize(0,0);
+}
+
+QPoint Utils::getCursorPosition(){
+	return QCursor::pos();
+}
+
+QString Utils::getFileChecksum(const QString& filePath){
+    QFile file(filePath);
+    if (file.open(QFile::ReadOnly)) {
+        QCryptographicHash hash(QCryptographicHash::Sha256);
+        if (hash.addData(&file)) {
+            return hash.result().toHex();
+        }
+    }
+    return QString();
+}
+
+QString Utils::encodeTextToQmlRichFormat(const QString& text, const QVariantMap& options){
+	
+	QString images;
+	QStringList formattedText;
+	QStringList imageFormat;
+	for(auto format : QImageReader::supportedImageFormats())
+		imageFormat.append(QString::fromLatin1(format).toUpper());
+	auto iriParsed = UriTools::parseIri(text);
+	for(int i = 0 ; i < iriParsed.size() ; ++i){
+		QString iri = iriParsed[i].second.replace('&', "&amp;")
+					.replace('<', "\u2063&lt;")
+					.replace('>', "\u2063&gt;")
+					.replace('"', "&quot;")
+					.replace('\'', "&#039;");
+		if(!iriParsed[i].first)
+			formattedText.append(iri);
+		else{
+			QString uri = iriParsed[i].second.left(3) == "www" ? "http://"+iriParsed[i].second : iriParsed[i].second ;
+			int extIndex = iriParsed[i].second.lastIndexOf('.');
+			QString ext;
+			if( extIndex >= 0)
+				ext = iriParsed[i].second.mid(extIndex+1).toUpper();
+			if(imageFormat.contains(ext.toLatin1())){// imagesHeight is not used because of bugs on display (blank image if set without width)
+				images += "<a href=\"" + uri + "\"><img" + (
+						options.contains("imagesWidth")
+							? QString(" width='") + options["imagesWidth"].toString() + "'"
+							: ""
+					) + (
+						options.contains("imagesWidth")
+						? QString(" height='auto'")
+						: ""
+					) + " src=\"" + iriParsed[i].second + "\" /></a>";
+			}else
+				formattedText.append( "<a href=\"" + uri + "\">" + iri + "</a>");
+		}
+	}
+	if(images != "")
+		images = "<div>" + images +"</div>";
+	
+	return images + "<p style=\"white-space:pre-wrap;\">" + formattedText.join("") + "</p>";
 }
\ No newline at end of file
