@@ -157,9 +157,11 @@ function getParams (call) {
 }
 
 function updateSelectedCall (call, index) {
-	calls._selectedCall = call
-	if (index != null) {
-		calls.currentIndex = index
+	if(index != undefined){
+		calls._selectedCall = call ? call : null
+		if (index != null) {
+			calls.currentIndex = index
+		}
 	}
 }
 
@@ -199,7 +201,11 @@ function handleCountChanged (count) {
 		
 		var model = calls.model
 		var index = count - 1
-		updateSelectedCall(model.data(model.index(index, 0)), index)
+		if(model){
+			var callModel = model.data(model.index(index, 0))
+			if( callModel.status === Linphone.CallModel.CallStatusConnected || callModel.isOutgoing )
+				updateSelectedCall(callModel, index)
+		}
 	} else {
 		setIndexWithCall(call)
 	}
