@@ -24,9 +24,9 @@
 .pragma library
 
 .import QtQuick 2.7 as QtQuick
+.import Linphone 1.0 as Linphone
 
 .import 'port-tools.js' as PortTools
-.import 'uri-tools.js' as UriTools
 
 // =============================================================================
 // Constants.
@@ -41,10 +41,18 @@ var SCHEME_REGEX = new RegExp('^[^:]+:')
 // QML helpers.
 // =============================================================================
 
-function buildDialogUri (component) {
+function buildCommonDialogUri (component) {
   return 'qrc:/ui/modules/Common/Dialog/' + component + '.qml'
 }
 
+function buildLinphoneDialogUri (component) {
+  return 'qrc:/ui/modules/Linphone/Dialog/' + component + '.qml'
+}
+
+function buildAppDialogUri (component) {
+  return 'qrc:/ui/views/App/Dialog/' + component + '.qml'
+}
+
 // -----------------------------------------------------------------------------
 
 // Destroy timeout.
@@ -88,51 +96,6 @@ function createObject (source, parent, options) {
 
 // -----------------------------------------------------------------------------
 
-function encodeTextToQmlRichFormat (text, options) {
-  var images = ''
-
-  if (!options) {
-    options = {}
-  }
-
-  var formattedText = execAll(UriTools.URI_REGEX, text, function (str, valid) {
-    if (!valid) {
-      return unscapeHtml(str)
-    }
-
-    var uri = startsWith(str, 'www.') ? 'http://' + str : str
-
-    var ext = getExtension(str)
-    if (includes([ 'jpg', 'jpeg', 'gif', 'png', 'svg' ], ext)) {
-      images += '<a href="' + uri + '"><img' + (
-        options.imagesWidth != null
-          ? ' width="' + options.imagesWidth + '"'
-          : ''
-      ) + (
-        options.imagesHeight != null
-        ? ' height="' + options.imagesHeight + '"'
-        : ''
-      ) + ' src="' + str + '" /></a>'
-    }
-
-    return '<a href="' + uri + '">' + unscapeHtml(str) + '</a>'
-  }).join('')
-  if (images.length > 0) {
-    images = '<div>' + images + '</div>'
-  }
-
-  return images.concat('<p style="white-space:pre-wrap;">' + formattedText + '</p>')
-}
-
-function extractFirstUri (str) {
-  var res = str.match(UriTools.URI_REGEX)
-  return res == null || startsWith(res[0], 'www')
-    ? undefined
-    : res[0]
-}
-
-// -----------------------------------------------------------------------------
-
 function getSystemPathFromUri (uri) {
   var str = uri.toString()
   if (startsWith(str, 'file://')) {
@@ -376,40 +339,6 @@ function dirname (str) {
 
 // -----------------------------------------------------------------------------
 
-function execAll (regex, text, cb) {
-  var index = 0
-  var arr = []
-  var match
-
-  if (!cb) {
-    cb = function (text) {
-      return text
-    }
-  }
-
-  while ((match = regex.exec(text))) {
-    var curIndex = match.index
-    var matchStr = match[0]
-
-    if (curIndex > index) {
-      arr.push(cb(text.substring(index, curIndex), false))
-    }
-
-    arr.push(cb(matchStr, true))
-
-    index = curIndex + matchStr.length
-  }
-
-  var length = text.length
-  if (index < length) {
-    arr.push(cb(text.substring(index, length)))
-  }
-
-  return arr
-}
-
-// -----------------------------------------------------------------------------
-
 function extractProperties (obj, pattern) {
   if (!pattern) {
     return {}
@@ -513,6 +442,64 @@ function formatElapsedTime (seconds) {
 	return (h === 0 ? '' : h + ':') + m + ':' + s
 }
 
+function formatDuration (seconds) {
+  seconds = parseInt(seconds, 10)
+//s,	m,	h,		d,		W,		M,			Y
+//1,	60,	3600,	86400,	604800,	2592000,	31104000
+	var y = Math.floor(seconds / 31104000)
+	if(y > 0)
+	//: '%1 year'
+		return qsTr('formatYears', '', y).arg(y)
+	var M = Math.floor(seconds / 2592000)
+	if(M > 0)
+		//: '%1 month'
+		return qsTr('formatMonths', '', M).arg(M)
+	var w = Math.floor(seconds / 604800)
+	if(w>0)
+		//: '%1 week'
+		return qsTr('formatWeeks', '', w).arg(w)
+	var d = Math.floor(seconds / 86400)
+	if(d>0)
+		//: '%1 day'
+		return qsTr('formatDays', '', d).arg(d)
+	var h = Math.floor(seconds / 3600)
+	var m = Math.floor((seconds - h * 3600) / 60)
+	var s = seconds - h * 3600 - m * 60
+	
+	//: '%1 hour'
+	return  (h > 0 ? qsTr('formatHours', '', h).arg(h): '')
+	//: '%1 minute'
+			+ (m > 0 ? (h > 0 ? ', ' : '') +qsTr('formatMinutes', '', m).arg(m): '')
+	//: '%1 second'
+			+ (s > 0 ? (h> 0 || m > 0 ? ', ' : '') +qsTr('formatSeconds', '', s).arg(s): '')
+}
+
+function buildDate(date, time){
+	var dateTime = new Date()
+	dateTime.setFullYear(date.getFullYear(), date.getMonth(), date.getDate())
+	dateTime.setHours(time.getHours())
+	dateTime.setMinutes(time.getMinutes())
+	dateTime.setSeconds(time.getSeconds())
+	return dateTime
+}
+
+function equalDate(date1, date2){
+    return date1.getFullYear() == date2.getFullYear() && date1.getMonth() == date2.getMonth() && date1.getDate() == date2.getDate()
+}
+
+function fromUTC(date){
+	return new Date(Date.UTC(date.getUTCFullYear(), date.getUTCMonth(),
+                date.getUTCDate(), date.getUTCHours(),
+                date.getUTCMinutes(), date.getUTCSeconds()));
+}
+// return EXACTLY what date has been set (not take account of Locale timezones, eg. Date(2000,0,1) will print january and not december if timezone lead there.)
+// Use this function for toLocaleString/toLocaleDateString or other
+function exactDate(date) {
+    var timeOffset = date.getTimezoneOffset() * 60000
+    var exactDate = new Date(date.valueOf() - timeOffset)
+    return exactDate
+}
+
 // -----------------------------------------------------------------------------
 
 function formatSize (size) {
@@ -694,6 +681,45 @@ function write (fileName, text) {
   request.send(text)
 }
 
+function computeAvatarSize (container, maxSize, ratio) {
+  var height = container.height * ratio
+  var width = container.width * ratio
+  var size = height < maxSize && height > 0 ? height : maxSize
+  return size < width ? size : width
+}
+
+// -----------------------------------------------------------------------------
+
+function openCodecOnlineInstallerDialog (window, codecInfo, cb) {
+  var VideoCodecsModel = Linphone.VideoCodecsModel
+  window.attachVirtualWindow(buildCommonDialogUri('ConfirmDialog'), {
+    descriptionText: qsTr('downloadCodecDescription')
+      .replace('%1', codecInfo.mime)
+      .replace('%2', codecInfo.encoderDescription)
+  }, function (status) {
+    if (status) {
+      window.attachVirtualWindow(buildLinphoneDialogUri('OnlineInstallerDialog'), {
+        downloadUrl: codecInfo.downloadUrl,
+        extract: true,
+        installFolder: VideoCodecsModel.codecsFolder,
+        installName: codecInfo.installName,
+        mime: codecInfo.mime,
+        checksum: codecInfo.checksum
+      }, function (status) {
+        if (status) {
+          VideoCodecsModel.reload()
+        }
+        if (cb) {
+          cb(window)
+        }
+      })
+    }
+    else if (cb) {
+      cb(window)
+    }
+  })
+}
+
 function printObject(o) {
   var out = '';
   for (var p in o) {
@@ -701,4 +727,3 @@ function printObject(o) {
   }
   return out;
 }
-
