@@ -36,7 +36,7 @@ function handleClosing (close) {
 		return
 	}
 	
-	window.attachVirtualWindow(Utils.buildDialogUri('ConfirmDialog'), {
+	window.attachVirtualWindow(Utils.buildCommonDialogUri('ConfirmDialog'), {
 								   descriptionText: qsTr('acceptClosingDescription')
 							   }, function (status) {
 								   if (status) {
@@ -44,7 +44,6 @@ function handleClosing (close) {
 									   window.close()
 								   }
 							   })
-	
 	close.accepted = false
 }
 
@@ -58,33 +57,45 @@ function openConferenceManager (params, exitHandler) {
 	window.attachVirtualWindow(Qt.resolvedUrl('Dialogs/ConferenceManager.qml'), params, exitHandler)
 }
 
+function openWaitingRoom(model){
+	calls.refreshCall()
+	if(window.conferenceInfoModel && middlePane.sourceComponent == waitingRoom)
+		middlePane.item.reset()
+	window.conferenceInfoModel = model
+}
+
 // -----------------------------------------------------------------------------
 // Used to get Component based from Call Status
-function getContent () {
-	var call = window.call
+function getContent (call, conferenceInfoModel) {
 	if (call == null) {
-		return conference
+		if(conferenceInfoModel) {
+			return waitingRoom
+		}
+		else{
+			return null
+		}
 	}
 	
 	var status = call.status
 	if (status == null) {
 		return calls.conferenceModel.count > 0 ? conference : null
 	}
-	
 	var CallModel = Linphone.CallModel
 	if (status === CallModel.CallStatusIncoming) {
-		return incomingCall
+		return null;
 	}
-	
-	if (status === CallModel.CallStatusOutgoing) {
-		return outgoingCall
+	if( window.conferenceInfoModel != call.conferenceInfoModel) {
+		Qt.callLater(function(){window.conferenceInfoModel = call.conferenceInfoModel})
+		return middlePane.sourceComponent	// unchange. Wait for later decision on conference model (avoid binding loop on sourceComponent)
+	}else{
+		if(call.isConference){
+			return incall
+		}
+		if (status === CallModel.CallStatusOutgoing || (status === CallModel.CallStatusEnded && call.callError != '' )) {
+			return waitingRoom
+		}
+		return incall
 	}
-	
-	if (status === CallModel.CallStatusEnded) {
-		return endedCall
-	}
-	
-	return incall
 }
 
 // -----------------------------------------------------------------------------
@@ -124,7 +135,7 @@ function handleCallAttendedTransferAsked (call) {
 }
 
 function windowMustBeClosed () {
-	return Linphone.CallsListModel.rowCount() === 0 && !window.virtualWindowVisible
+	return Linphone.CallsListModel.rowCount() === 0 && !window.virtualWindowVisible && middlePane.sourceComponent != waitingRoom
 }
 
 function tryToCloseWindow () {
