@@ -34,7 +34,7 @@ function editLdap (ldap) {
 }
 
 function cleanLogs () {
-  window.attachVirtualWindow(Utils.buildDialogUri('ConfirmDialog'), {
+  window.attachVirtualWindow(Utils.buildCommonDialogUri('ConfirmDialog'), {
     descriptionText: qsTr('cleanLogsDescription'),
   }, function (status) {
     if (status) {
@@ -48,7 +48,7 @@ function handleLogsUploaded (url) {
 
     if(Qt.openUrlExternally(
           'mailto:' + encodeURIComponent(Linphone.SettingsModel.logsEmail) +
-          '?subject=' + encodeURIComponent('Desktop Linphone Log') +
+          '?subject=' + encodeURIComponent( ('Desktop %1 Log').arg(applicationName)) +
           '&body=' + encodeURIComponent(url)
         ))
         sendLogsBlock.stop(qsTr('logsMailerSuccess').replace('%1', url))
